@@ -1,3 +1,28 @@
+/*
+   callbacks.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "callbacks.h"
 #include "callback_func.h"
 #include "debug.h"
@@ -5,9 +30,11 @@
 #include "game.h"
 #include "game_gui.h"
 #include "gui.h"
+#include "job.h"
 #include "league.h"
 #include "load_save.h"
 #include "main.h"
+#include "misc2_callback_func.h"
 #include "option.h"
 #include "player.h"
 #include "table.h"
@@ -34,7 +61,7 @@ void
 on_menu_new_activate                   (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-    window_destroy(&window.main, FALSE);
+    window_destroy(&window.main);
     free_memory();
     
     main_init(NULL, NULL);
@@ -149,11 +176,19 @@ on_button_transfers_clicked            (GtkButton       *button,
 	game_gui_print_message(_("Transfers are disabled in this country definition."));
     else if(week < transfer_get_deadline() || transfer_list->len > 0)
     {
-	stat0 = STATUS_SHOW_TRANSFER_LIST;
-	game_gui_print_message(_("Left click to make an offer. Right click to remove offer."));
-	game_gui_print_message_with_delay(_("Transfer deadline is Week %d"), transfer_get_deadline());
-	treeview_show_transfer_list(GTK_TREE_VIEW(lookup_widget(window.main, "treeview_right")));
-	gtk_notebook_set_current_page(GTK_NOTEBOOK(lookup_widget(window.main, "notebook_player")), 1);
+	if(stat0 != STATUS_SHOW_TRANSFER_LIST)
+	{
+	    stat0 = STATUS_SHOW_TRANSFER_LIST;
+	    game_gui_print_message(
+		_("Left click to make an offer. Right click to remove offer."));
+	    game_gui_print_message_with_delay(
+		_("Transfer deadline is Week %d"), transfer_get_deadline());
+	}
+
+	treeview_show_transfer_list(
+	    GTK_TREE_VIEW(lookup_widget(window.main, "treeview_right")));
+	gtk_notebook_set_current_page(
+	    GTK_NOTEBOOK(lookup_widget(window.main, "notebook_player")), 1);
 	
 	gui_set_arrows();
     }
@@ -394,9 +429,10 @@ void
 on_menu_season_history_activate        (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-    if(season == 1)
+    if(season_stats->len == 0)
     {
-	game_gui_print_message(_("This is your first season."));
+	game_gui_print_message(
+	    _("There are no season history elements stored yet."));
 	return;
     }
 
@@ -505,7 +541,8 @@ on_menu_move_to_youth_academy_activate (GtkMenuItem     *menuitem,
 	if(pl->age > const_float("float_player_age_lower"))
 	    game_gui_print_message(_("The player is too old for the youth academy."));
 	else if(current_user.tm->players->len <= 11)
-	    game_gui_print_message(_("You can't move the player, there are too few players in your team."));
+	    game_gui_print_message(
+		_("You can't move the player, there are too few players in your team."));
 	else if(current_user.youth_academy.players->len ==
 		const_int("int_youth_academy_max_youths"))
 	    game_gui_print_message(_("There is no room in your youth academy."));
@@ -588,7 +625,8 @@ on_treeview_right_button_press_event   (GtkWidget       *widget,
     {
 	case STATUS_SHOW_TRANSFER_LIST:
 	    if(trans(idx - 1).tm == current_user.tm ||
-	       (trans(idx - 1).offers->len > 0 && transoff(idx - 1, 0).status == TRANSFER_OFFER_ACCEPTED) ||
+	       (trans(idx - 1).offers->len > 0 && 
+		transoff(idx - 1, 0).status == TRANSFER_OFFER_ACCEPTED) ||
 	       event->button == 1)
 		callback_transfer_list_clicked(event->button, idx - 1);
 	    else if(event->button == 3)
@@ -596,7 +634,8 @@ on_treeview_right_button_press_event   (GtkWidget       *widget,
 		if(transfer_remove_offer(idx - 1, current_user.tm))
 		    game_gui_print_message(_("Your offer has been removed."));
 		else
-		    game_gui_print_message(_("You haven't made an offer for the player."));
+		    game_gui_print_message(
+			_("You haven't made an offer for the player."));
 		return TRUE;
 	    }
 	    break;
@@ -611,11 +650,28 @@ on_treeview_right_button_press_event   (GtkWidget       *widget,
 	    break;
 	case STATUS_SHOW_YA:
 	    selected_row = idx - 1;
-	    if(event->button == 3)
+	    if(event->button == 1)
 		on_menu_youth_move_to_team_activate(NULL, NULL);
-	    else
+	    else if(event->button == 3)
 		window_show_menu_youth((GdkEvent*)event);
 	    break;
+	case STATUS_SHOW_JOB_EXCHANGE:
+	    if(g_array_index(jobs, Job, idx - 1).type != JOB_TYPE_NATIONAL &&
+	       users->len > 1)
+		game_gui_show_warning(_("You can't apply for a job from abroad if there's more than one user."));
+	    else if(event->button == 1)
+		game_gui_show_job_offer(NULL, 
+					&g_array_index(jobs, Job, idx - 1),
+					STATUS_JOB_EXCHANGE_SHOW_TEAM);
+	    else if(event->button == 3)
+		if(misc2_callback_evaluate_job_application(
+		       &g_array_index(jobs, Job, idx - 1), &current_user))
+		{
+		    stat0 = STATUS_MAIN;
+		    game_gui_show_main();
+		    setsav0;
+		}
+	    break;
     }
 
     gui_set_arrows();
@@ -1151,3 +1207,39 @@ on_menu_save_window_geometry_activate  (GtkMenuItem     *menuitem,
 {
     window_main_save_geometry();
 }
+
+void
+on_menu_betting_activate               (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+    on_button_back_to_main_clicked(NULL, NULL);
+    window_show_bets();
+}
+
+void
+on_menu_show_job_exchange_activate     (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+    stat0 = STATUS_SHOW_JOB_EXCHANGE;
+
+    gui_set_arrows();
+
+    treeview2_show_job_exchange();
+
+    game_gui_print_message(
+	_("Right click to apply for job at once, left click to see team info."));
+    game_gui_print_message_with_delay(
+	_("The job exchange update interval is %d weeks."),
+	const_int("int_job_update_interval"));
+}
+
+gboolean
+on_hpaned2_button_release_event        (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data)
+{
+    window.paned_pos = 
+	gtk_paned_get_position(GTK_PANED(widget));
+
+    return FALSE;
+}
