@@ -1,3 +1,28 @@
+/*
+   callbacks.h
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #ifndef CALLBACKS_H
 #define CALLBACKS_H
 
@@ -308,4 +333,14 @@ on_menu_save_window_geometry_activate  (GtkMenuItem     *menuitem,
 void
 on_menu_season_results_activate        (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
+void
+on_menu_betting_activate               (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+void
+on_menu_show_job_exchange_activate     (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+gboolean
+on_hpaned2_button_release_event        (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
 #endif
