@@ -1,3 +1,28 @@
+/*
+   enums.h
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #ifndef ENUMS_H
 #define ENUMS_H
 
@@ -13,6 +38,7 @@ enum Counters
     COUNT_FIX_ID,
     COUNT_LG_COMM_ID,
     COUNT_SHOW_DEBUG,
+    COUNT_HINT_NUMBER,
     COUNT_END
 };
 
@@ -98,7 +124,7 @@ enum Status0Value
     STATUS_SHOW_PREVIEW,
     STATUS_SAVE_GAME,
     STATUS_LOAD_GAME,
-    STATUS_LOAD_GAME_TEAM_SELECTION,
+    STATUS_LOAD_GAME_SPLASH,
     STATUS_QUERY_UNFIT,
     STATUS_QUERY_QUIT,
     STATUS_QUERY_USER_NO_TURN,
@@ -111,6 +137,10 @@ enum Status0Value
     STATUS_SELECT_MM_FILE_ADD,
     STATUS_SELECT_MM_FILE_IMPORT,
     STATUS_SELECT_MM_FILE_EXPORT,
+    STATUS_PLACE_BET,
+    STATUS_SHOW_JOB_EXCHANGE,
+    STATUS_JOB_EXCHANGE_SHOW_TEAM,
+    STATUS_SPLASH,
     STATUS_END
 };
 
