@@ -1,9 +1,35 @@
+/*
+   file.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
 
 #include "file.h"
 #include "free.h"
+#include "language.h"
 #include "main.h"
 #include "misc.h"
 #include "option.h"
@@ -32,7 +58,6 @@ file_add_support_directory_recursive                   (const gchar     *directo
     add_pixmap_directory(directory);
     support_directories = g_list_prepend (support_directories,
 					  g_strdup (directory));
-
     while(TRUE)
     {
 	file = g_dir_read_name(newdir);
@@ -94,6 +119,13 @@ file_my_system(const gchar *command)
     if(system(command) != 0)
     {
 	g_warning("file_my_system: system returned -1 when executing '%s'.", command);
+
+	if(!os_is_unix)
+	{
+	    g_warning("Press RETURN to try to continue.");
+	    getchar();
+	}
+
 	return FALSE;
     }
 
@@ -109,26 +141,23 @@ file_my_system(const gchar *command)
 gboolean
 file_my_fopen(const gchar *filename, gchar *bits, FILE **fil, gboolean abort_program)
 {
-    gchar buf[SMALL];
-    gchar *support_file = file_find_support_file(filename, FALSE);
+    gchar *support_file = NULL;
+
     *fil = fopen(filename, bits);
 
     if(*fil != NULL)
-    {
-	g_free(support_file);
 	return TRUE;
-    }
 
+    support_file = file_find_support_file(filename, FALSE);
     *fil = fopen(support_file, bits);
+
     if(*fil != NULL)
     {
 	g_free(support_file);
 	return TRUE;
     }
 
-    sprintf(buf, "Could not open file '%s' in mode '%s'.\n", filename, bits);
-
-    g_warning(buf);
+    g_warning("Could not open file '%s' in mode '%s'.\n", filename, bits);
 
     if(abort_program)
 	main_exit_program(EXIT_FILE_OPEN_FAILED, NULL);
@@ -156,9 +185,10 @@ file_check_home_dir_create_dirs(void)
     }
 }
 
-/** Copy the basic config files into the user home dir. */
+/** Add the basic config files to the list of file to copy
+    into the user home dir. */
 void
-file_check_home_dir_copy_conf_files(void)
+file_check_home_dir_get_conf_files(GPtrArray **files_to_copy)
 {
     gint i;
     gchar *conf_files[2] =
@@ -175,14 +205,17 @@ file_check_home_dir_copy_conf_files(void)
 	if(!g_file_test(buf, G_FILE_TEST_EXISTS))
 	{
 	    conf_file = file_find_support_file(conf_files[i], TRUE);	    
-	    file_copy_file(conf_file, buf);
+	    g_ptr_array_add(files_to_copy[0], g_strdup(conf_file));
+	    g_ptr_array_add(files_to_copy[1], g_strdup(buf));
 	}
     }
 }
 
-/** Copy the xml definition files into the home dir. */
+/** Add the xml definition files to the list of files to copy
+    into the home dir. */
 void
-file_check_home_dir_copy_definition_dir(const gchar *dirname, const gchar *basename)
+file_check_home_dir_get_definition_dir(const gchar *dirname, const gchar *basename,
+				       GPtrArray **files_to_copy)
 {
     gint i;
     gchar buf[SMALL], buf2[SMALL];
@@ -209,7 +242,8 @@ file_check_home_dir_copy_definition_dir(const gchar *dirname, const gchar *basen
         
 	    sprintf(buf2, "%s%s%s", dirname, G_DIR_SEPARATOR_S,
 		    (gchar*)g_ptr_array_index(dir_contents, i));
-	    file_copy_file(buf2, buf);
+	    g_ptr_array_add(files_to_copy[0], g_strdup(buf2));
+	    g_ptr_array_add(files_to_copy[1], g_strdup(buf));
 	}
 	else
 	{
@@ -220,7 +254,7 @@ file_check_home_dir_copy_definition_dir(const gchar *dirname, const gchar *basen
 	    {
 		sprintf(buf2, "%s%s%s", basename, G_DIR_SEPARATOR_S,
 			(gchar*)g_ptr_array_index(dir_contents, i));
-		file_check_home_dir_copy_definition_dir(buf, buf2);
+		file_check_home_dir_get_definition_dir(buf, buf2, files_to_copy);
 	    }
 	}
     }
@@ -228,28 +262,97 @@ file_check_home_dir_copy_definition_dir(const gchar *dirname, const gchar *basen
     free_gchar_array(&dir_contents);
 }
 
-/** Copy the xml definition files into the home dir. */
+/** Step through the support dirs to find xml definition files
+    that get copied into the home dir. */
 void
-file_check_home_dir_copy_definition_files(void)
+file_check_home_dir_get_definition_files(GPtrArray **files_to_copy)
 {
     GList *elem = support_directories;
   
     while(elem != NULL)
     {    
 	if(g_str_has_suffix((gchar*)elem->data, "definitions"))
-	    file_check_home_dir_copy_definition_dir((const gchar*)elem->data, "definitions");
+	    file_check_home_dir_get_definition_dir((const gchar*)elem->data, 
+						   "definitions",
+						   files_to_copy);
 
 	elem = elem->next;
     }
 }
 
-/** Copy some files into the user's home directory. */
+/** Execute the copy commands on the files assembled earlier. */
 void
+file_check_home_dir_copy_files(GPtrArray **files_to_copy)
+{
+    gint i;
+    gchar buf[SMALL];
+    const gchar *filename = NULL;
+    GtkLabel *label_splash_progress =
+	GTK_LABEL(lookup_widget(window.splash, "label_splash_progress"));
+    GtkProgressBar *progressbar_splash =
+	GTK_PROGRESS_BAR(lookup_widget(window.splash, "progressbar_splash"));
+    GtkWidget *hint_buttons[2] = 
+	{lookup_widget(window.splash, "button_splash_hint_back"),
+	 lookup_widget(window.splash, "button_splash_hint_next")};
+    GtkWidget *hbox_buttons = lookup_widget(window.splash, "hbox3");
+
+    if(files_to_copy[0]->len > 0)
+    {
+	gtk_widget_set_sensitive(hint_buttons[0], FALSE);
+	gtk_widget_set_sensitive(hint_buttons[1], FALSE);
+	gtk_widget_set_sensitive(hbox_buttons, FALSE);
+    }
+
+    for(i=0;i<files_to_copy[0]->len;i++)
+    {
+	filename = g_strrstr((gchar*)g_ptr_array_index(files_to_copy[0], i), 
+			     G_DIR_SEPARATOR_S);
+	if(filename == NULL)
+	    filename = (gchar*)g_ptr_array_index(files_to_copy[0], i);
+	else
+	    filename = filename + 1;
+
+	sprintf(buf, _("Copying %s"), filename);
+	gtk_label_set_text(label_splash_progress, buf);
+	gtk_progress_bar_set_fraction(progressbar_splash, 
+				      (gdouble)i /(gdouble)files_to_copy[0]->len);
+	while(gtk_events_pending())
+	    gtk_main_iteration();
+
+	file_copy_file((gchar*)g_ptr_array_index(files_to_copy[0], i),
+		       (gchar*)g_ptr_array_index(files_to_copy[1], i));
+    }
+
+    gtk_progress_bar_set_fraction(progressbar_splash, 1);
+    gtk_label_set_text(label_splash_progress, _("Ready"));
+
+    while(gtk_events_pending())
+	gtk_main_iteration();    
+
+    if(files_to_copy[0]->len > 0)
+    {
+	gtk_widget_set_sensitive(hint_buttons[0], TRUE);
+	gtk_widget_set_sensitive(hint_buttons[1], TRUE);
+	gtk_widget_set_sensitive(hbox_buttons, TRUE);
+    }
+}
+
+/** Copy some files into the user's home directory. */
+gboolean
 file_check_home_dir(void)
 {
+    GPtrArray *files_to_copy[2] = {g_ptr_array_new(),
+				   g_ptr_array_new()};
+
     file_check_home_dir_create_dirs();
-    file_check_home_dir_copy_conf_files();
-    file_check_home_dir_copy_definition_files();
+    file_check_home_dir_get_conf_files(files_to_copy);
+    file_check_home_dir_get_definition_files(files_to_copy);
+    file_check_home_dir_copy_files(files_to_copy);
+
+    free_gchar_array(&(files_to_copy[0]));
+    free_gchar_array(&(files_to_copy[1]));
+
+    return FALSE;
 }
 
 /**
@@ -438,6 +541,26 @@ file_load_opt_file(const gchar *filename, OptionList *optionlist)
     fclose(fil);
 }
 
+/** Load the appropriate hints file. */
+void
+file_load_hints_file(void)
+{
+    gchar buf[SMALL], hints_file[SMALL];
+    gchar *hints_file_sup = NULL;
+
+    language_get_code(buf);
+
+    sprintf(hints_file, "bygfoot_hints_%s", buf);
+    hints_file_sup = file_find_support_file(hints_file, FALSE);
+
+    if(hints_file_sup != NULL)
+	g_free(hints_file_sup);
+    else
+	strcpy(hints_file, "bygfoot_hints_en");
+
+    file_load_opt_file(hints_file, &hints);
+}
+
 /** Load the options at the beginning of a new game from
     the configuration files. */
 void
@@ -451,10 +574,11 @@ file_load_conf_files(void)
 
     file_load_opt_file(opt_str("string_opt_constants_file"), &constants);
     file_load_opt_file(opt_str("string_opt_appearance_file"), &constants_app);
-    file_load_opt_file("bygfoot_lg_tokens", &lg_tokens);
+    file_load_opt_file("bygfoot_tokens", &tokens);
+    file_load_hints_file();
 
-    for(i=0;i<lg_tokens.list->len;i++)
-	g_array_index(lg_tokens.list, Option, i).value = i;
+    for(i=0;i<tokens.list->len;i++)
+	g_array_index(tokens.list, Option, i).value = i;
 }
 
 /** Load a user-specific conf file.
@@ -472,7 +596,8 @@ file_load_user_conf_file(User *user)
        !file_my_fopen(conf_file, "r", &fil, FALSE))
     {
 	g_free(conf_file);
-	conf_file = file_find_support_file(opt_str("string_opt_default_user_conf_file"), TRUE);
+	conf_file = 
+	    file_find_support_file(opt_str("string_opt_default_user_conf_file"), TRUE);
     }
 
     file_load_opt_file(conf_file, &user->options);
@@ -501,6 +626,26 @@ file_get_first_support_dir(void)
     return NULL;
 }
 
+/** Return the first support directory which has the given suffix.*/
+const gchar*
+file_get_first_support_dir_suffix(const gchar *suffix)
+{
+    GList *elem = support_directories;
+  
+    while (elem)
+    {
+	if(g_str_has_suffix((gchar*)elem->data, suffix))
+	    return (const gchar*)elem->data;
+
+	elem = elem->next;
+    }
+
+    g_warning("file_get_first_support_dir_suffix: no dir with suffix %s found.",
+	      suffix);
+
+    return NULL;    
+}
+
 /** Compress the files starting with the prefix.
     @param destfile The name of the file to create. */
 void
@@ -609,3 +754,19 @@ file_copy_file(const gchar *source_file, const gchar *dest_file)
 
     file_my_system(buf);
 }
+
+/** Find out where the Bygfoot directory we can write to resides
+    and write the location into the string. */
+void
+file_get_bygfoot_dir(gchar *dir)
+{
+    const gchar *home = g_get_home_dir();
+    gchar *pwd = g_get_current_dir();
+    
+    if(os_is_unix)
+	sprintf(dir, "%s%s%s", home, G_DIR_SEPARATOR_S, HOMEDIRNAME);
+    else
+	sprintf(dir, "%s%s", pwd, G_DIR_SEPARATOR_S);
+
+    g_free(pwd);
+}
