@@ -1,3 +1,28 @@
+/*
+   live_game.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "callbacks.h"
 #include "fixture.h"
 #include "free.h"
@@ -12,6 +37,7 @@
 #include "misc_callback_func.h"
 #include "option.h"
 #include "player.h"
+#include "strategy.h"
 #include "support.h"
 #include "team.h"
 #include "treeview.h"
@@ -29,15 +55,14 @@ gboolean show;
 #define unis match->units
 #define uni(i) g_array_index(unis, LiveGameUnit, i)
 #define last_unit uni(unis->len - 1)
-#define tm match->fix->teams
+#define tms match->fix->teams
 #define tm0 match->fix->teams[0]
 #define tm1 match->fix->teams[1]
 
 /** Calculate the result of a fixture using
     the live game variable.
     @param fix The fixture we calculate.
-    @see live_game_create_unit(), live_game_evaluate_unit(),
-    treeview_live_game_show_game_unit() */
+*/
 void
 live_game_calculate_fixture(Fixture *fix)
 {
@@ -50,14 +75,14 @@ live_game_calculate_fixture(Fixture *fix)
     game_get_values(match->fix, match->team_values,
 		    match->home_advantage);
 
-    if((debug > 80 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 80 && stat2 != -1) ||
        debug > 130)
-	printf("\n\nlive_game_calculate_fixture\n%04d %s %s %04d\n\n",
+	g_print("\n\nlive_game_calculate_fixture\n%04d %s %s %04d\n\n",
 	       tm0->id, tm0->name, tm1->name, tm1->id);
 
     do
     {
-	live_game_create_unit();	
+	live_game_create_unit();
 	live_game_evaluate_unit(&last_unit);
     }
     while(last_unit.event.type != LIVE_GAME_EVENT_END_MATCH &&
@@ -66,8 +91,8 @@ live_game_calculate_fixture(Fixture *fix)
 
     if(last_unit.event.type == LIVE_GAME_EVENT_END_MATCH)
     {
-	if(fixture_user_team_involved(match->fix) != -1 || stat5 < -1000)
-	    lg_commentary_post_match();
+	if(stat2 != -1 || stat5 < -1000)
+	    lg_commentary_free_tokens();
 	game_post_match(fix);
     }
     else if(stat0 == STATUS_LIVE_GAME_CHANGE)
@@ -78,14 +103,14 @@ live_game_calculate_fixture(Fixture *fix)
 void
 live_game_initialize(Fixture *fix)
 {
-    statp= (fixture_user_team_involved(fix) != -1) ? 
-	&usr(fixture_user_team_involved(fix)).live_game : &live_game_temp;
-    show = (fixture_user_team_involved(fix) != -1 && 
-	    option_int("int_opt_user_show_live_game", 
-		       &usr(fixture_user_team_involved(fix)).options));
-
     stat2 = fixture_user_team_involved(fix);
 
+    statp= (stat2 != -1) ? 
+	&usr(stat2).live_game : &live_game_temp;
+    show = (stat2 != -1 && 
+	    option_int("int_opt_user_show_live_game", 
+		       &usr(stat2).options));
+
     live_game_reset(match, fix, TRUE);
 
     if(show)
@@ -96,14 +121,17 @@ live_game_initialize(Fixture *fix)
 	if(window.live == NULL)
 	    window.live = window_create(WINDOW_LIVE);
 	else
-	    gtk_window_set_title(GTK_WINDOW(window.live),
-				 league_cup_get_name_string(((LiveGame*)statp)->fix->clid));
+	    gtk_window_set_title(
+		GTK_WINDOW(window.live),
+		league_cup_get_name_string(((LiveGame*)statp)->fix->clid));
 	window_live_set_up();
+	game_gui_live_game_show_opponent();
     }
 
     game_initialize(fix);
-    
-    if(fixture_user_team_involved(match->fix) != -1 || stat5 < -1000)
+    match->attendance = fix->attendance;
+
+    if(stat2 != -1 || stat5 < -1000)
 	lg_commentary_initialize(fix);
 }
 
@@ -114,9 +142,9 @@ live_game_create_unit(void)
 {
     LiveGameUnit new;
 
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("\t\tlive_game_create_unit\n");
+	g_print("\t\tlive_game_create_unit\n");
 
     if(unis->len == 0)
     {
@@ -174,9 +202,9 @@ live_game_fill_new_unit(LiveGameUnit *new)
     gfloat possession_change, scoring_chance = 0, 
 	injury_event_prob, foul_event_prob;
 
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("\t\tlive_game_fill_new_unit\n");
+	g_print("\t\tlive_game_fill_new_unit\n");
 
     possession_change = const_float("float_live_game_event_general") *
 	const_float("float_live_game_possession_changes") /
@@ -234,9 +262,9 @@ live_game_create_start_unit(void)
 {
     LiveGameUnit new;
 
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("\t\tlive_game_create_start_unit\n");
+	g_print("\t\tlive_game_create_start_unit\n");
     new.event.player =
 	new.event.player2 = -1;
 
@@ -263,9 +291,9 @@ live_game_evaluate_unit(LiveGameUnit *unit)
 {
     gint type = unit->event.type;
 
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("\t\tlive_game_evaluate_unit\n");
+	g_print("\t\tlive_game_evaluate_unit\n");
     if(type == LIVE_GAME_EVENT_FOUL)
 	live_game_event_foul();
     else if(type == LIVE_GAME_EVENT_LOST_POSSESSION)
@@ -289,7 +317,7 @@ live_game_evaluate_unit(LiveGameUnit *unit)
     {
 	live_game_finish_unit();
 	if(type != LIVE_GAME_EVENT_END_MATCH && show && 
-	   option_int("int_opt_user_pause_break", &usr(fixture_user_team_involved(match->fix)).options))
+	   option_int("int_opt_user_pause_break", &usr(stat2).options))
 	    misc_callback_pause_live_game();
     }
     else if(type != LIVE_GAME_EVENT_END_MATCH)
@@ -304,12 +332,12 @@ live_game_event_foul(void)
     gfloat rndom = math_rnd(0, 1);
     gint type, fouled_player, foul_player, foul_team;
 
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("\t\tlive_game_event_foul\n");
+	g_print("\t\tlive_game_event_foul\n");
     if(math_rnd(0, 1) > const_float("float_live_game_foul_by_possession") *
        game_get_foul_possession_factor(
-	   tm[last_unit.possession]->boost, tm[!last_unit.possession]->boost))
+	   tms[last_unit.possession]->boost, tms[!last_unit.possession]->boost))
     {	
 	foul_team = last_unit.event.team = !last_unit.possession;
 	if(uni(unis->len - 2).event.type == LIVE_GAME_EVENT_GENERAL)
@@ -317,21 +345,21 @@ live_game_event_foul(void)
 		uni(unis->len - 2).event.player;
 	else
 	    fouled_player = last_unit.event.player =
-		game_get_player(tm[last_unit.possession],
+		game_get_player(tms[last_unit.possession],
 				last_unit.area, 0, -1, FALSE);
 
 	foul_player = last_unit.event.player2 =
-	    game_get_player(tm[!last_unit.possession],
+	    game_get_player(tms[!last_unit.possession],
 			    last_unit.area, 0, -1, FALSE);
     }
     else
     {
 	foul_team = last_unit.event.team = last_unit.possession;
 	fouled_player = last_unit.event.player = 
-	    game_get_player(tm[!last_unit.possession],
+	    game_get_player(tms[!last_unit.possession],
 			    last_unit.area, 0, -1, FALSE);
 	foul_player = last_unit.event.player2 =
-	    game_get_player(tm[last_unit.possession],
+	    game_get_player(tms[last_unit.possession],
 			    last_unit.area, 0, -1, FALSE);
     }
 
@@ -342,9 +370,9 @@ live_game_event_foul(void)
     else if(rndom < const_float("float_live_game_foul_yellow"))
     {
 	type = LIVE_GAME_EVENT_FOUL_YELLOW;
-	player_card_set(player_of_id_team(tm[foul_team], foul_player),
+	player_card_set(player_of_id_team(tms[foul_team], foul_player),
 			match->fix->clid, PLAYER_VALUE_CARD_YELLOW, 1, TRUE);
-	player_of_id_team(tm[foul_team], foul_player)->career[PLAYER_VALUE_CARD_YELLOW]++;
+	player_of_id_team(tms[foul_team], foul_player)->career[PLAYER_VALUE_CARD_YELLOW]++;
     }
     else
 	type = LIVE_GAME_EVENT_FOUL;
@@ -383,11 +411,11 @@ live_game_event_foul(void)
 void
 live_game_event_lost_possession(void)
 {
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("\t\tlive_game_event_lost_possession\n");
+	g_print("\t\tlive_game_event_lost_possession\n");
     last_unit.event.player =
-	game_get_player(tm[last_unit.possession], 
+	game_get_player(tms[last_unit.possession], 
 			last_unit.area, 0, -1, TRUE);
 	
     if(uni(unis->len - 2).event.type == LIVE_GAME_EVENT_GENERAL)
@@ -395,7 +423,7 @@ live_game_event_lost_possession(void)
 	    uni(unis->len - 2).event.player;
     else
 	last_unit.event.player2 =
-	    game_get_player(tm[!last_unit.possession], 
+	    game_get_player(tms[!last_unit.possession], 
 			    uni(unis->len - 2).area, 0, -1, FALSE);
 
     live_game_finish_unit();
@@ -413,11 +441,13 @@ void
 live_game_event_injury(gint team, gint player, gboolean create_new)
 {
     LiveGameUnit new;
-    gint old_structure = -1;
+    gint old_structure = -1, sub_in = -1;
+    gint usr_idx = -1;
 
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("\t\tlive_game_event_injury\n");
+	g_print("\t\tlive_game_event_injury\n");
+
     if(create_new)
     {
 	new = last_unit;
@@ -430,6 +460,8 @@ live_game_event_injury(gint team, gint player, gboolean create_new)
     }
     else
 	live_game_injury_get_player();
+
+    usr_idx = team_is_user(tms[last_unit.event.team]);
     
     last_unit.minute = -1;
     last_unit.event.type = LIVE_GAME_EVENT_INJURY;
@@ -439,52 +471,53 @@ live_game_event_injury(gint team, gint player, gboolean create_new)
 	last_unit.event.type = LIVE_GAME_EVENT_TEMP_INJURY;
 
 	if(debug < 50 ||
-	   team_is_user(tm[last_unit.event.team]) == -1)
-	    player_of_id_team(tm[last_unit.event.team],
+	   usr_idx == -1)
+	    player_of_id_team(tms[last_unit.event.team],
 			      last_unit.event.player)->fitness =
-		MAX(0, player_of_id_team(tm[last_unit.event.team],
+		MAX(0, player_of_id_team(tms[last_unit.event.team],
 					 last_unit.event.player)->fitness -
-		    math_rnd(const_float("float_live_game_temp_injury_fitness_decrease_lower"),
-			     const_float("float_live_game_temp_injury_fitness_decrease_upper")));
+		    math_rnd(
+			const_float("float_live_game_temp_injury_fitness_decrease_lower"),
+			const_float("float_live_game_temp_injury_fitness_decrease_upper")));
     }
     
     live_game_finish_unit();
 
     if(debug >= 50 &&
-       team_is_user(tm[last_unit.event.team]) != -1)
+       usr_idx != -1)
 	return;
 
     if(last_unit.event.type == LIVE_GAME_EVENT_INJURY)
     {
-	game_player_injury(player_of_id_team(tm[last_unit.event.team],
+	game_player_injury(player_of_id_team(tms[last_unit.event.team],
 					     last_unit.event.player));
 
 	if(match->subs_left[last_unit.event.team] > 0)
 	{
 	    if(show && 
-	       team_is_user(tm[last_unit.event.team]) != -1 && 
+	       usr_idx != -1 && 
 	       ((option_int("int_opt_user_pause_injury",
-			    &usr(team_is_user(tm[last_unit.event.team])).options) &&
+			    &usr(usr_idx).options) &&
 		 !option_int("int_opt_user_auto_sub",
-			     &usr(team_is_user(tm[last_unit.event.team])).options)) ||
-		tm[last_unit.event.team]->players->len == 11))
+			     &usr(usr_idx).options)) ||
+		tms[last_unit.event.team]->players->len == 11))
 		misc_callback_pause_live_game();
-	    else if(tm[last_unit.event.team]->players->len > 11)
+	    else if(tms[last_unit.event.team]->players->len > 11)
 	    {
-		old_structure = tm[last_unit.event.team]->structure;
-		live_game_event_substitution(
-		    last_unit.event.team,
-		    game_substitute_player(
-			tm[last_unit.event.team],
-			player_id_index(tm[last_unit.event.team],
-					last_unit.event.player)),
-		    last_unit.event.player);
-
-		match->subs_left[last_unit.event.team]--;
-
-		if(old_structure != tm[last_unit.event.team]->structure)
+		sub_in = game_substitute_player(tms[last_unit.event.team],
+						player_id_index(tms[last_unit.event.team],
+								last_unit.event.player));
+		if(sub_in != -1)
+		{
+		    old_structure = tms[last_unit.event.team]->structure;
+		    live_game_event_substitution(
+			last_unit.event.team, sub_in,
+			last_unit.event.player);
+		    
+		if(old_structure != tms[last_unit.event.team]->structure)
 		    live_game_event_team_change(last_unit.event.team,
 						LIVE_GAME_EVENT_STRUCTURE_CHANGE);
+		}
 	    }
 	}
     }
@@ -507,9 +540,9 @@ live_game_event_stadium(void)
     for(i=1;i<3;i++)
 	probs[i] += probs[i - 1];
 
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("\t\tlive_game_event_stadium\n");
+	g_print("\t\tlive_game_event_stadium\n");
     if(rndom <= probs[0])
 	last_unit.event.type = LIVE_GAME_EVENT_STADIUM_BREAKDOWN;
     else if(rndom <= probs[1])
@@ -538,20 +571,20 @@ live_game_event_scoring_chance(void)
     else
 	res_idx = 0;
 
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("\t\tlive_game_event_scoring_chance\n");
+	g_print("\t\tlive_game_event_scoring_chance\n");
 
     if(math_rnd(0, 1) < const_float("float_live_game_scoring_chance_is_own_goal"))
     {
 	last_unit.event.type = LIVE_GAME_EVENT_OWN_GOAL;
 	last_unit.event.player =
-	    game_get_player(tm[!last_unit.possession], GAME_PLAYER_TYPE_DEFEND, 0, -1, FALSE);
+	    game_get_player(tms[!last_unit.possession], GAME_PLAYER_TYPE_DEFEND, 0, -1, FALSE);
 	last_unit.event.team = !last_unit.possession;
 	match->fix->result[last_unit.possession][res_idx]++;
 	last_unit.result[last_unit.possession]++;
 
-	player_streak_add_to_prob(player_of_id_team(tm[last_unit.event.team],
+	player_streak_add_to_prob(player_of_id_team(tms[last_unit.event.team],
 						    last_unit.event.player),
 				  const_float("float_player_streak_add_own_goal"));
     }
@@ -562,17 +595,17 @@ live_game_event_scoring_chance(void)
 	if(uni(unis->len - 2).event.player != -1 &&
 	   math_rnd(0, 1) < const_float("float_live_game_player_in_poss_shoots") &&
 	   query_player_id_in_team(uni(unis->len - 2).event.player,
-				   tm[last_unit.possession]))
+				   tms[last_unit.possession]))
 	    last_unit.event.player =
 		uni(unis->len - 2).event.player;
 	else
 	{
 	    if(uni(unis->len - 2).event.player != -1 &&
 	       query_player_id_in_team(uni(unis->len - 2).event.player,
-				       tm[last_unit.possession]))
+				       tms[last_unit.possession]))
 	    {
 		last_unit.event.player =
-		    game_get_player(tm[last_unit.possession], last_unit.area, 0, 
+		    game_get_player(tms[last_unit.possession], last_unit.area, 0, 
 				    uni(unis->len - 2).event.player,
 				    TRUE);
 
@@ -582,10 +615,11 @@ live_game_event_scoring_chance(void)
 	    else
 	    {
 		last_unit.event.player =
-		    game_get_player(tm[last_unit.possession], last_unit.area, 0, -1, TRUE);
+		    game_get_player(
+			tms[last_unit.possession], last_unit.area, 0, -1, TRUE);
 
 		last_unit.event.player2 =
-		    game_get_player(tm[last_unit.possession], last_unit.area, 0, 
+		    game_get_player(tms[last_unit.possession], last_unit.area, 0, 
 				    last_unit.event.player, TRUE);
 	    }
 	}
@@ -608,9 +642,9 @@ live_game_event_penalty(void)
 {
     LiveGameUnit new;
 
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("\t\tlive_game_event_penalty\n");
+	g_print("\t\tlive_game_event_penalty\n");
 
     if(last_unit.time != LIVE_GAME_UNIT_TIME_PENALTIES)
     {
@@ -631,21 +665,21 @@ live_game_event_penalty(void)
 	{
 	    last_unit.possession = math_rndi(0, 1);
 	    last_unit.event.player =
-		game_get_player(tm[last_unit.possession],
+		game_get_player(tms[last_unit.possession],
 				GAME_PLAYER_TYPE_PENALTY, -1, -1, FALSE);
 	}
 	else if(live_game_penalties_taken() == 2)
 	{
 	    last_unit.possession = !uni(unis->len - 3).possession;
 	    last_unit.event.player =
-		game_get_player(tm[last_unit.possession],
+		game_get_player(tms[last_unit.possession],
 				GAME_PLAYER_TYPE_PENALTY, -1, -1, FALSE);
 	}
 	else
 	{
 	    last_unit.possession = !uni(unis->len - 3).possession;
 	    last_unit.event.player =
-		game_get_player(tm[last_unit.possession],
+		game_get_player(tms[last_unit.possession],
 				GAME_PLAYER_TYPE_PENALTY,
 				uni(unis->len - 4).event.player, -1, FALSE);
 	}
@@ -656,10 +690,10 @@ live_game_event_penalty(void)
 	    last_unit.possession;
 
 	last_unit.event.player = 
-	    game_get_default_penalty_shooter(tm[last_unit.possession]);
+	    game_get_default_penalty_shooter(tms[last_unit.possession]);
 	if(last_unit.event.player == -1)
 	    last_unit.event.player =
-		game_get_player(tm[last_unit.possession], GAME_PLAYER_TYPE_PENALTY, -1, -1, FALSE);
+		game_get_player(tms[last_unit.possession], GAME_PLAYER_TYPE_PENALTY, -1, -1, FALSE);
     }
 
     live_game_finish_unit();
@@ -674,9 +708,13 @@ live_game_event_general(gboolean create_new)
 {
     LiveGameUnit new;
 
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("\t\tlive_game_event_general\n");
+	g_print("\t\tlive_game_event_general\n");
+
+    if(create_new && stat0 == STATUS_LIVE_GAME_PAUSE)
+	return;
+
     if(create_new)
     {
 	new.minute = live_game_get_minute();
@@ -699,6 +737,8 @@ live_game_event_general(gboolean create_new)
 	   last_unit.event.type == LIVE_GAME_EVENT_STADIUM_BREAKDOWN ||
 	   last_unit.event.type == LIVE_GAME_EVENT_STADIUM_FIRE ||
 	   last_unit.event.type == LIVE_GAME_EVENT_STADIUM_RIOTS ||
+	   (last_unit.event.type >= LIVE_GAME_EVENT_STRUCTURE_CHANGE &&
+	    last_unit.event.type <= LIVE_GAME_EVENT_BOOST_CHANGE_ON) ||
 	   ((last_unit.event.type == LIVE_GAME_EVENT_POST ||
 	     last_unit.event.type == LIVE_GAME_EVENT_CROSS_BAR) &&
 	    math_rnd(0, 1) < const_float("float_live_game_possession_after_post")))
@@ -734,11 +774,9 @@ live_game_event_general(gboolean create_new)
 	    new.area = LIVE_GAME_UNIT_AREA_MIDFIELD;
 	}
 	else
-	{
-	    g_warning("live_game_event_general: unknown event type: %d\n",
-		      last_unit.event.type);
-	    main_exit_program(EXIT_INT_NOT_FOUND, NULL);
-	}
+	    main_exit_program(EXIT_INT_NOT_FOUND, 
+			      "live_game_event_general: unknown event type: %d\n",
+			      last_unit.event.type);
 	
 	g_array_append_val(unis, new);
     }
@@ -746,6 +784,17 @@ live_game_event_general(gboolean create_new)
     live_game_event_general_get_players();
 
     live_game_finish_unit();
+
+    /** First, check whether CPU strategy changes are made. */
+    if(team_is_user(tm0) == -1)
+	strategy_live_game_check(match, 0);
+
+    if(team_is_user(tm1) == -1)
+	strategy_live_game_check(match, 1);
+
+    if(last_unit.event.type >= LIVE_GAME_EVENT_STRUCTURE_CHANGE &&
+       last_unit.event.type <= LIVE_GAME_EVENT_BOOST_CHANGE_ON)
+	live_game_event_general(TRUE);
 }
 
 /** Fill in the players values in a general unit. */
@@ -758,30 +807,30 @@ live_game_event_general_get_players(void)
 	uni(unis->len - 2).event.player;
     gint type = uni(unis->len - 2).event.type;
 	
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("\t\tlive_game_event_general_get_players\n");
+	g_print("\t\tlive_game_event_general_get_players\n");
     *pl1 = *pl2 = -1;
 
     if(type == LIVE_GAME_EVENT_LOST_POSSESSION)
     {
 	*pl2 = old_pl1;
-	*pl1 = game_get_player(tm[last_unit.possession], 
+	*pl1 = game_get_player(tms[last_unit.possession], 
 			       last_unit.area, 0, *pl2,
 			       TRUE);
     }
     else if(type != LIVE_GAME_EVENT_GENERAL)
     {
-	*pl1 = game_get_player(tm[last_unit.possession],
+	*pl1 = game_get_player(tms[last_unit.possession],
 			       last_unit.area, 0, -1, TRUE);
 	if(math_rnd(0, 1) < const_float("float_live_game_general_event_second_player"))
-	    *pl2 = game_get_player(tm[last_unit.possession],
+	    *pl2 = game_get_player(tms[last_unit.possession],
 				   last_unit.area, 0, *pl1, TRUE);
     }
     else
     {
-	*pl2 = query_player_id_in_team(old_pl1, tm[last_unit.possession]) ? old_pl1 : -1;
-	*pl1 = game_get_player(tm[last_unit.possession],
+	*pl2 = query_player_id_in_team(old_pl1, tms[last_unit.possession]) ? old_pl1 : -1;
+	*pl1 = game_get_player(tms[last_unit.possession],
 			       last_unit.area, 0, *pl2, TRUE);
     }
 }
@@ -792,9 +841,9 @@ live_game_event_free_kick(void)
 {
     LiveGameUnit new = last_unit;
 
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("\t\tlive_game_event_free_kick\n");
+	g_print("\t\tlive_game_event_free_kick\n");
     new.event.player =
 	new.event.player2 = -1;
 
@@ -806,11 +855,11 @@ live_game_event_free_kick(void)
     new.event.commentary = NULL;
 
     new.event.player =
-	game_get_default_penalty_shooter(tm[new.possession]);
+	game_get_default_penalty_shooter(tms[new.possession]);
 
     if(new.event.player == -1)
 	new.event.player =
-	    game_get_player(tm[new.possession], new.area, 0, -1, TRUE);
+	    game_get_player(tms[new.possession], new.area, 0, -1, TRUE);
 
     g_array_append_val(unis, new);
 
@@ -825,10 +874,11 @@ live_game_event_send_off(gint team, gint player, gboolean second_yellow)
 {
     LiveGameUnit new = last_unit;
     gint substitute = -1, to_substitute = -1;
+    gint usr_idx = team_is_user(tms[team]);
 
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("\t\tlive_game_event_send_off\n");
+	g_print("\t\tlive_game_event_send_off\n");
     new.event.player =
 	new.event.player2 = -1;
 
@@ -843,66 +893,64 @@ live_game_event_send_off(gint team, gint player, gboolean second_yellow)
 
     live_game_finish_unit();
 
-    if(debug >= 50 && team_is_user(tm[team]) != -1)
+    if(debug >= 50 && usr_idx != -1)
 	return;
 
     player_streak_add_to_prob(
-	player_of_id_team(tm[team], player),
+	player_of_id_team(tms[team], player),
 	const_float("float_player_streak_add_sendoff"));
-    if(player_of_id_team(tm[team], player)->streak == PLAYER_STREAK_HOT)
+    if(player_of_id_team(tms[team], player)->streak == PLAYER_STREAK_HOT)
     {
-	player_of_id_team(tm[team], player)->streak = PLAYER_STREAK_NONE;
-	player_streak_reset_count(player_of_id_team(tm[team], player));
+	player_of_id_team(tms[team], player)->streak = PLAYER_STREAK_NONE;
+	player_streak_reset_count(player_of_id_team(tms[team], player));
     }
 
-    player_of_id_team(tm[team], player)->cskill = 0;
+    player_of_id_team(tms[team], player)->cskill = 0;
+
     if(second_yellow)
-	player_card_set(player_of_id_team(tm[team], player), match->fix->clid, PLAYER_VALUE_CARD_RED, 2, FALSE);
+	player_card_set(player_of_id_team(tms[team], player), match->fix->clid, PLAYER_VALUE_CARD_RED, 2, FALSE);
     else
-	player_card_set(player_of_id_team(tm[team], player), match->fix->clid, PLAYER_VALUE_CARD_RED, 
+	player_card_set(player_of_id_team(tms[team], player), match->fix->clid, PLAYER_VALUE_CARD_RED, 
 			game_player_get_ban_duration(), FALSE);
 
-    player_of_id_team(tm[team], player)->career[PLAYER_VALUE_CARD_RED]++;
+    player_of_id_team(tms[team], player)->career[PLAYER_VALUE_CARD_RED]++;
     
-    if(team_is_user(tm[team]) != -1)
+    if(usr_idx != -1)
     {
-	tm[team]->structure = team_find_appropriate_structure(tm[team]);
-	team_rearrange(tm[team]);
+	tms[team]->structure = team_find_appropriate_structure(tms[team]);
+	team_rearrange(tms[team]);
 	live_game_event_team_change(team, LIVE_GAME_EVENT_STRUCTURE_CHANGE);
     }
 
     if(match->subs_left[team] > 0)
     {
-	if(show && team_is_user(tm[team]) != -1 &&
+	if(show && usr_idx != -1 &&
 	   ((option_int("int_opt_user_pause_red",
-			&usr(team_is_user(tm[team])).options) &&
+			&usr(usr_idx).options) &&
 	     !option_int("int_opt_user_auto_sub",
-			 &usr(team_is_user(tm[team])).options)) ||
-	    tm[team]->players->len == 1))
+			 &usr(usr_idx).options)) ||
+	    tms[team]->players->len == 1))
 	    misc_callback_pause_live_game();
-	else if(tm[team]->players->len > 11)
+	else if(tms[team]->players->len > 11)
 	{
 	    game_substitute_player_send_off(match->fix->clid,
-					    tm[team], player_id_index(tm[team], player),
+					    tms[team], player_id_index(tms[team], player),
 					    &to_substitute, &substitute);
 
 	    if(to_substitute != -1)
-	    {
 		live_game_event_substitution(team, substitute, to_substitute);
-		match->subs_left[team]--;
-	    }
 	    else
 	    {
-		tm[team]->structure = team_find_appropriate_structure(tm[team]);
-		team_rearrange(tm[team]);
+		tms[team]->structure = team_find_appropriate_structure(tms[team]);
+		team_rearrange(tms[team]);
 	    }
 	    live_game_event_team_change(team, LIVE_GAME_EVENT_STRUCTURE_CHANGE);
 	}
     }
-    else if(team_is_user(tm[team]) == -1)
+    else if(usr_idx == -1)
     {
-	tm[team]->structure = team_find_appropriate_structure(tm[team]);
-	team_rearrange(tm[team]);
+	tms[team]->structure = team_find_appropriate_structure(tms[team]);
+	team_rearrange(tms[team]);
 	live_game_event_team_change(team, LIVE_GAME_EVENT_STRUCTURE_CHANGE);
     }
 
@@ -928,12 +976,25 @@ live_game_event_substitution(gint team_number, gint sub_in, gint sub_out)
     new.event.player2 = sub_out;
     new.event.commentary = NULL;
 
-    if(player_of_id_team(tm[team_number], sub_in)->cskill > 0)
+    if(player_of_id_team(tms[team_number], sub_in)->cskill > 0)
     {
-	player_games_goals_set(player_of_id_team(tm[team_number], sub_in),
+	match->subs_left[team_number]--;
+
+	player_streak_add_to_prob(
+	    player_of_id_team(tms[team_number], sub_in),
+	    const_float("float_player_streak_add_sub_out"));
+	
+	player_streak_add_to_prob(
+	    player_of_id_team(tms[team_number], sub_in),
+	    const_float("float_player_streak_add_sub_in"));	
+
+	player_games_goals_set(player_of_id_team(tms[team_number], sub_in),
 			       match->fix->clid, PLAYER_VALUE_GAMES, 1);
-	player_of_id_team(tm[team_number], sub_in)->career[PLAYER_VALUE_GAMES]++;
-	player_of_id_team(tm[team_number], sub_in)->participation = TRUE;
+	player_of_id_team(tms[team_number], sub_in)->career[PLAYER_VALUE_GAMES]++;
+	player_of_id_team(tms[team_number], sub_in)->participation = TRUE;
+
+	if(show)
+	    game_gui_live_game_show_opponent();
     }
 
     g_array_append_val(unis, new);
@@ -961,6 +1022,9 @@ live_game_event_team_change(gint team_number, gint event_type)
     g_array_append_val(unis, new);
     
     live_game_finish_unit();
+
+    if(show)
+	game_gui_live_game_show_opponent();
 }
 
 /** Calculate whether a player who tries to score succeeds. */
@@ -974,25 +1038,25 @@ live_game_event_duel(void)
     Player *attacker, *goalie, *assistant;
     gint res_idx1, res_idx2;
 
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("\t\tlive_game_event_duel\n");
+	g_print("\t\tlive_game_event_duel\n");
 
     new.minute = -1;
     new.event.team = new.possession;
     new.event.commentary = NULL;
 	
-    attacker = player_of_id_team(tm[new.possession],
+    attacker = player_of_id_team(tms[new.possession],
 				 new.event.player);
-    goalie = player_of_idx_team(tm[!new.possession], 0);
+    goalie = player_of_idx_team(tms[!new.possession], 0);
 
     assistant = (new.event.player2 != -1) ? 
-	player_of_id_team(tm[new.possession], new.event.player2) : NULL;
+	player_of_id_team(tms[new.possession], new.event.player2) : NULL;
 
     new.event.player2 = goalie->id;
 
-    duel_factor = player_get_game_skill(attacker, FALSE) /
-	player_get_game_skill(goalie, FALSE);
+    duel_factor = player_get_game_skill(attacker, FALSE, TRUE) /
+	player_get_game_skill(goalie, FALSE, TRUE);
 
     res_idx1 = new.possession;
     if(new.time == LIVE_GAME_UNIT_TIME_PENALTIES)
@@ -1215,6 +1279,23 @@ live_game_get_minute(void)
     return -1;
 }
 
+/** Return the minutes remaining in the match. */
+gint
+live_game_get_minutes_remaining(const LiveGameUnit *unit)
+{
+    gint current_min = live_game_unit_get_minute(unit);
+    gint return_value = -1;
+    
+    if(unit->time == LIVE_GAME_UNIT_TIME_EXTRA_TIME)
+	return_value = 120 - current_min;
+    else if(unit->time == LIVE_GAME_UNIT_TIME_SECOND_HALF)
+	return_value = 90 - current_min;
+    else if(unit->time == LIVE_GAME_UNIT_TIME_FIRST_HALF)
+	return_value = 45 - current_min;	    
+
+    return return_value;
+}
+
 /** Return the minute of the unit (ie. look up the last unit
     with a 'normal' minute value if minute = -1).
     @param unit The unit we examine.
@@ -1338,30 +1419,33 @@ live_game_finish_unit(void)
 {
     LiveGameUnit *unit = &last_unit;
 
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("\t\tlive_game_finish_unit\n");
+	g_print("\t\tlive_game_finish_unit\n");
 
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("OOOO1 idx %d type %d poss %d team %d pl %d %d\n", unis->len - 1,
+	g_print("OOOO1 idx %d min %d type %d poss %d team %d pl %d %d\n", unis->len - 1,
+	       unit->minute,
 	       unit->event.type, unit->possession, unit->event.team,
 	       unit->event.player,
 	       unit->event.player2);
 
-    if(unit->minute != -1 && unit->time != LIVE_GAME_UNIT_TIME_PENALTIES &&
-       fixture_user_team_involved(match->fix) != -1)
+    if(unit->minute != -1 && unit->time != LIVE_GAME_UNIT_TIME_PENALTIES)
     {
-	if(debug < 50)
-	    game_decrease_fitness(match->fix);
+	if(stat2 != -1 && usr(stat2).tm->boost == 1)
+	    game_boost_cost();
+
+	game_decrease_fitness(match->fix);
 	game_get_values(match->fix, match->team_values,
 			match->home_advantage);
-	if(stat2 == cur_user && show &&
+	if(stat2 != -1 &&
+	   stat2 == cur_user && show &&
 	   unit->minute % opt_int("int_opt_live_game_player_list_refresh") == 0)
 	    treeview_show_user_player_list();
     }
 
-    if(fixture_user_team_involved(match->fix) != -1 || stat5 < -1000)
+    if(stat2 != -1 || stat5 < -1000)
     {
 	if(unit->time != LIVE_GAME_UNIT_TIME_PENALTIES)
 	{
@@ -1371,11 +1455,11 @@ live_game_finish_unit(void)
 					 match);
 	}
 
-	lg_commentary_generate(match, unit);
+	lg_commentary_generate(match, unit, NULL, -1);
 
 	if(-stat5 - 1000 == unit->event.type)
 	{
-	    printf("type %d com **%s**", unit->event.type, unit->event.commentary);
+	    g_print("type %d com **%s**", unit->event.type, unit->event.commentary);
 	    if(g_strrstr(unit->event.commentary, "[") ||
 	       g_strrstr(unit->event.commentary, "]") ||
 	       g_strrstr(unit->event.commentary, "<") ||
@@ -1385,9 +1469,9 @@ live_game_finish_unit(void)
 	       g_strrstr(unit->event.commentary, " L ") ||
 	       g_strrstr(unit->event.commentary, " GE ") ||
 	       g_strrstr(unit->event.commentary, " LE "))
-		printf(" ERROR?\n");
+		g_print(" ERROR?\n");
 	    else
-		printf("\n");
+		g_print("\n");
 	}
 
 	unit->event.verbosity = live_game_event_get_verbosity(unit->event.type);
@@ -1396,9 +1480,9 @@ live_game_finish_unit(void)
     if(show)
 	game_gui_live_game_show_unit(unit);
 
-    if((debug > 100 && fixture_user_team_involved(match->fix) != -1) ||
+    if((debug > 100 && stat2 != -1) ||
        debug > 130)
-	printf("OOOO idx %d type %d poss %d team %d pl %d %d\n", unis->len - 1,
+	g_print("OOOO idx %d type %d poss %d team %d pl %d %d\n", unis->len - 1,
 	       unit->event.type, unit->possession, unit->event.team,
 	       unit->event.player,
 	       unit->event.player2);
@@ -1419,19 +1503,19 @@ live_game_injury_get_player(void)
     
     for(j=0;j<2;j++)
     {
-	fitness_factor = (player_of_idx_team(tm[j], 0)->fitness < 0.025) ?
-	    40 : 1 / player_of_idx_team(tm[j], 0)->fitness;
+	fitness_factor = (player_of_idx_team(tms[j], 0)->fitness < 0.025) ?
+	    40 : 1 / player_of_idx_team(tms[j], 0)->fitness;
 	probs[j * 11] = goalie_factor * fitness_factor * 
-	    (player_of_idx_team(tm[j], 0)->cskill != 0) * (1 + tm[j]->boost * boost_factor);
+	    (player_of_idx_team(tms[j], 0)->cskill != 0) * (1 + tms[j]->boost * boost_factor);
 	if(j == 1)
 	    probs[11] += probs[10];
 	
 	for(i=1;i<11;i++)
 	{
-	    fitness_factor = (player_of_idx_team(tm[j], i)->fitness < 0.025) ?
-		40 : 1 / ((gfloat)player_of_idx_team(tm[j], i)->fitness);
+	    fitness_factor = (player_of_idx_team(tms[j], i)->fitness < 0.025) ?
+		40 : 1 / ((gfloat)player_of_idx_team(tms[j], i)->fitness);
 	    probs[i + j * 11] = probs[i + j * 11 - 1] + (1 - goalie_factor) * fitness_factor *
-		(player_of_idx_team(tm[j], i)->cskill != 0) * (1 + tm[j]->boost * boost_factor);
+		(player_of_idx_team(tms[j], i)->cskill != 0) * (1 + tms[j]->boost * boost_factor);
 	}
     }
     
@@ -1448,7 +1532,7 @@ live_game_injury_get_player(void)
 	    if(probs[i - 1] <= rndom && rndom < probs[i])
 	    {
 		last_unit.event.player = 
-		    player_of_idx_team(tm[(i > 10)], i % 11)->id;
+		    player_of_idx_team(tms[(i > 10)], i % 11)->id;
 		last_unit.event.team = (i > 10);
 	    }
 }
@@ -1469,22 +1553,19 @@ live_game_resume(void)
 	for(j=0;j<3;j++)
 	{
 	    if(subs_in[j] != -1)
-	    {
-		usr(stat2).live_game.subs_left[i]--;
 		live_game_event_substitution(i, subs_in[j], subs_out[j]);
-	    }
 	}
 
-	if(tm[i]->structure != usr(stat2).live_game.team_state[i].structure)
+	if(tms[i]->structure != usr(stat2).live_game.team_state[i].structure)
 	    live_game_event_team_change(i, LIVE_GAME_EVENT_STRUCTURE_CHANGE);
 
-	if(tm[i]->style != usr(stat2).live_game.team_state[i].style)
+	if(tms[i]->style != usr(stat2).live_game.team_state[i].style)
 	    live_game_event_team_change(i, LIVE_GAME_EVENT_STYLE_CHANGE_ALL_OUT_DEFEND +
-					tm[i]->style + 2);
+					tms[i]->style + 2);
 
-	if(tm[i]->boost != usr(stat2).live_game.team_state[i].boost)
+	if(tms[i]->boost != usr(stat2).live_game.team_state[i].boost)
 	    live_game_event_team_change(i, LIVE_GAME_EVENT_BOOST_CHANGE_ANTI +
-					tm[i]->boost + 1);
+					tms[i]->boost + 1);
     }
 
     live_game_calculate_fixture(usr(stat2).live_game.fix);
@@ -1504,6 +1585,8 @@ live_game_reset(LiveGame *live_game, Fixture *fix, gboolean free_variable)
 	free_live_game(live_game);
 
     live_game->units = g_array_new(FALSE, FALSE, sizeof(LiveGameUnit));
+    live_game->action_ids[0] = g_array_new(FALSE, FALSE, sizeof(gint));
+    live_game->action_ids[1] = g_array_new(FALSE, FALSE, sizeof(gint));
     
     for(i=0;i<LIVE_GAME_STAT_ARRAY_END;i++)
     {
@@ -1525,6 +1608,7 @@ live_game_reset(LiveGame *live_game, Fixture *fix, gboolean free_variable)
     else
     {
 	live_game->fix_id = -1;
+	live_game->attendance = -1;
 	live_game->team_names[0] = 
 	    live_game->team_names[1] = NULL;
     }
@@ -1591,11 +1675,9 @@ live_game_event_get_verbosity(gint event_type)
     else if(event_type == LIVE_GAME_EVENT_GENERAL)
 	return_value = 6;
     else
-    {
-	g_warning("live_game_event_get_verbosity: unknown event type %d \n",
-		  event_type);
-	main_exit_program(EXIT_INT_NOT_FOUND, NULL);
-    }
+	main_exit_program(EXIT_INT_NOT_FOUND, 
+			  "live_game_event_get_verbosity: unknown event type %d \n",
+			  event_type);
 
     return return_value;
 }
