@@ -1,3 +1,28 @@
+/*
+   live_game.h
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #ifndef LIVE_GAME_H
 #define LIVE_GAME_H
 
@@ -25,6 +50,9 @@ live_game_get_time(const LiveGameUnit *unit);
 gint
 live_game_get_minute(void);
 
+gint
+live_game_get_minutes_remaining(const LiveGameUnit *unit);
+
 void
 live_game_create_unit(void);
 
