@@ -1,3 +1,28 @@
+/*
+   live_game_struct.h
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #ifndef LIVE_GAME_STRUCT_H
 #define LIVE_GAME_STRUCT_H
 
@@ -44,14 +69,14 @@ enum LiveGameEventType
     LIVE_GAME_EVENT_STADIUM_FIRE, /* 27 */
     LIVE_GAME_EVENT_SUBSTITUTION, /* 28 */
     LIVE_GAME_EVENT_STRUCTURE_CHANGE, /* 29 */
-    LIVE_GAME_EVENT_STYLE_CHANGE_ALL_OUT_DEFEND,
-    LIVE_GAME_EVENT_STYLE_CHANGE_DEFEND,
-    LIVE_GAME_EVENT_STYLE_CHANGE_BALANCED,
-    LIVE_GAME_EVENT_STYLE_CHANGE_ATTACK,
-    LIVE_GAME_EVENT_STYLE_CHANGE_ALL_OUT_ATTACK,
-    LIVE_GAME_EVENT_BOOST_CHANGE_ANTI,
-    LIVE_GAME_EVENT_BOOST_CHANGE_OFF,
-    LIVE_GAME_EVENT_BOOST_CHANGE_ON,
+    LIVE_GAME_EVENT_STYLE_CHANGE_ALL_OUT_DEFEND, /* 30 */
+    LIVE_GAME_EVENT_STYLE_CHANGE_DEFEND, /* 31 */
+    LIVE_GAME_EVENT_STYLE_CHANGE_BALANCED, /* 32 */
+    LIVE_GAME_EVENT_STYLE_CHANGE_ATTACK, /* 33 */
+    LIVE_GAME_EVENT_STYLE_CHANGE_ALL_OUT_ATTACK, /* 34 */
+    LIVE_GAME_EVENT_BOOST_CHANGE_ANTI, /* 35 */
+    LIVE_GAME_EVENT_BOOST_CHANGE_OFF, /* 36 */
+    LIVE_GAME_EVENT_BOOST_CHANGE_ON, /* 37 */
     LIVE_GAME_EVENT_END
 };
 
@@ -178,6 +203,9 @@ typedef struct
     /** The names of the teams stored for later use (when the fixture
 	already got freed). */
     gchar *team_names[2];
+    /** Attendance stored for later use (when the fixture
+	already got freed). */
+    gint attendance;
     /** Substitutions left for the teams. */
     gint subs_left[2];
     /** The team that started the game, 0 or 1. */
@@ -195,6 +223,9 @@ typedef struct
     /** Match statistics. @see #LiveGameStats */
     LiveGameStats stats;
     LiveGameTeamState team_state[2];
+    /** Ids of strategy actions applied. 
+	Actions only get applied once. */
+    GArray *action_ids[2];
 } LiveGame;
 
 #endif
