@@ -1,9 +1,36 @@
+/*
+   misc2_callback_func.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "callbacks.h"
 #include "callback_func.h"
 #include "file.h"
 #include "finance.h"
 #include "free.h"
 #include "game_gui.h"
+#include "job.h"
+#include "league.h"
 #include "maths.h"
 #include "misc.h"
 #include "misc2_callback_func.h"
@@ -34,6 +61,11 @@ misc2_callback_transfer_user_player(void)
 	    user_from_team(new_team)->money -= transoff(stat2, 0).fee;
 	    user_from_team(new_team)->money_out[1][MON_OUT_TRANSFERS] -= 
 		transoff(stat2, 0).fee;
+
+	    if(player_of_id_team(trans(stat2).tm, trans(stat2).id)->id ==
+	       opt_user_int("int_opt_user_penalty_shooter"))
+		opt_user_set_int("int_opt_user_penalty_shooter", -1);
+
 	    player_copy(player_of_id_team(trans(stat2).tm, trans(stat2).id),
 			new_team, new_team->players->len);
 	    player_of_idx_team(new_team, new_team->players->len - 1)->contract = 
@@ -159,7 +191,7 @@ misc2_callback_contract_offer(void)
 		pl->offers = 0;
 		pl->wage = value;
 		game_gui_show_warning(_("%s accepts your offer."), pl->name);
-		window_destroy(&window.contract, FALSE);
+		window_destroy(&window.contract);
 	    }
 	    else
 	    {
@@ -172,7 +204,7 @@ misc2_callback_contract_offer(void)
 		{
 		    game_gui_show_warning(_("%s rejects your offer and won't negotiate with you anymore. You should sell him before his contract expires (he'll simply leave your team otherwise)."), 
 					  pl->name);
-		    window_destroy(&window.contract, FALSE);
+		    window_destroy(&window.contract);
 		}
 	    }
 
@@ -186,7 +218,8 @@ void
 misc2_callback_add_user(void)
 {
     GtkTreeView *treeview_user_management_teams =
-	GTK_TREE_VIEW(lookup_widget(window.user_management, "treeview_user_management_teams"));
+	GTK_TREE_VIEW(lookup_widget(window.user_management,
+				    "treeview_user_management_teams"));
     GtkEntry *entry_user_management = 
 	GTK_ENTRY(lookup_widget(window.user_management, "entry_user_management"));
     const gchar *user_name = gtk_entry_get_text(entry_user_management);
@@ -194,22 +227,27 @@ misc2_callback_add_user(void)
     Team *tm = (Team*)treeview_helper_get_pointer(treeview_user_management_teams, 2);
     
     if(strlen(user_name) > 0)
-	misc_string_assign(&new_user.name, user_name);
-    
-    gtk_entry_set_text(entry_user_management, "");
+    {
+	misc_string_assign(&new_user.name, user_name);    
+	gtk_entry_set_text(entry_user_management, "");
+    }
 
     new_user.tm = tm;
     new_user.team_id = tm->id;
 
-    user_history_add(&new_user, USER_HISTORY_START_GAME, tm->id, tm->clid, -1, "");
+    user_history_add(&new_user, USER_HISTORY_START_GAME,
+		     tm->name, league_cup_get_name_string(tm->clid),
+		     NULL, NULL);
 
     g_array_append_val(users, new_user);
 
-    user_set_up_team(&usr(users->len - 1));
-
     file_load_user_conf_file(&usr(users->len - 1));
 
-    treeview_show_users(GTK_TREE_VIEW(lookup_widget(window.user_management, "treeview_user_management_users")));
+    user_set_up_team(&usr(users->len - 1));
+
+    treeview_show_users(
+	GTK_TREE_VIEW(lookup_widget(window.user_management,
+				    "treeview_user_management_users")));
     treeview_show_team_list(treeview_user_management_teams, FALSE, FALSE);
 
     setsav0;
@@ -228,14 +266,17 @@ misc2_callback_mmatches_button_press(GtkWidget *widget, gint row_num, gint col_n
 	{
 	    stat1 = STATUS_SHOW_LAST_MATCH;
 	    stat3 = 0;
-	    callback_show_last_match(TRUE, 
-				     &g_array_index(current_user.mmatches, MemMatch, row_num).lg);
+	    callback_show_last_match(
+		TRUE, 
+		&g_array_index(current_user.mmatches, MemMatch, row_num).lg);
 	}
 	else if(col_num == TREEVIEW_MMATCH_COL_REMOVE)
 	{
 	    gtk_widget_hide(widget);
-	    free_g_string(&g_array_index(current_user.mmatches, MemMatch, row_num).competition_name);
-	    free_gchar_ptr(g_array_index(current_user.mmatches, MemMatch, row_num).country_name);
+	    free_g_string(&g_array_index(current_user.mmatches, MemMatch, row_num).
+			  competition_name);
+	    free_gchar_ptr(g_array_index(current_user.mmatches, MemMatch, row_num).
+			   country_name);
 	    free_live_game(&g_array_index(current_user.mmatches, MemMatch, row_num).lg);
 	    g_array_remove_index(current_user.mmatches, row_num);
 	    treeview2_show_mmatches();
@@ -260,3 +301,42 @@ misc2_callback_mmatches_button_press(GtkWidget *widget, gint row_num, gint col_n
 	treeview2_show_mmatches();
     }
 }
+
+/** Find out whether the user's application for the job
+    is accepted and show the appropriate popups.
+    @return TRUE if accepted, FALSE otherwise. */
+gboolean
+misc2_callback_evaluate_job_application(Job *job, User *user)
+{
+    if(!query_job_application_successful(job, user))
+    {
+	game_gui_show_warning(
+	    _("The owners of %s politely reject your application. You're not successful enough in their eyes."),
+	    job_get_team(job)->name);
+	return FALSE;
+    }
+
+    if(job->type != JOB_TYPE_NATIONAL)
+    {
+	game_gui_show_warning(
+	    /* A lame duck is someone who will quit his job soon and thus doesn't have
+	       a lot of influence/impact anymore, e.g. an American president during
+	       the last 2 years of his second presidency. */
+	    _("The owners of %s accept your application. Since %s don't want to get stuck with a lame duck, you get fired instantly and spend the rest of the current season tending your garden."),
+	    job_get_team(job)->name, user->tm->name);
+	job_change_country(job);
+    }
+    else
+	game_gui_show_warning(
+	    _("The owners of %s accept your application."),
+	    job_get_team(job)->name);
+
+    user_change_team(user, team_of_id(job->team_id));
+
+    if(job->type == JOB_TYPE_NATIONAL)
+	job_remove(job, TRUE);
+    else
+	free_jobs(TRUE);
+	    
+    return TRUE;
+}
