@@ -1,9 +1,37 @@
+/*
+   misc_callback_func.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "callbacks.h"
+#include "debug.h"
 #include "finance.h"
+#include "free.h"
 #include "game.h"
 #include "game_gui.h"
 #include "gui.h"
 #include "load_save.h"
+#include "main.h"
 #include "maths.h"
 #include "misc.h"
 #include "misc_callback_func.h"
@@ -26,7 +54,7 @@ misc_callback_show_team_list(GtkWidget *widget, const gchar *country_file)
     GtkWidget *treeview_startup =
 	lookup_widget(widget, "treeview_startup");
 
-    xml_country_read(country_file);
+    xml_country_read(country_file, NULL);
 
     treeview_show_team_list(GTK_TREE_VIEW(treeview_startup), FALSE, FALSE);
 
@@ -42,9 +70,17 @@ misc_callback_start_game(void)
 	GTK_TOGGLE_BUTTON(lookup_widget(window.startup, "radiobutton_team_def_load"));
     GtkToggleButton *radio_names = 
 	GTK_TOGGLE_BUTTON(lookup_widget(window.startup, "radiobutton_team_def_names"));	
+    GtkToggleButton *checkbutton_randomise_teams =
+	GTK_TOGGLE_BUTTON(lookup_widget(window.startup, "checkbutton_randomise_teams"));
 
     stat0 = STATUS_MAIN;
 
+    option_add(&options, "int_opt_load_defs", 1, NULL);
+    option_add(&options, "int_opt_randomise_teams", 0, NULL);
+
+    if(gtk_toggle_button_get_active(checkbutton_randomise_teams))
+	opt_set_int("int_opt_randomise_teams", 1);
+
     if(gtk_toggle_button_get_active(radio_load))
 	opt_set_int("int_opt_load_defs", 1);
     else if(gtk_toggle_button_get_active(radio_names))
@@ -53,15 +89,31 @@ misc_callback_start_game(void)
 	opt_set_int("int_opt_load_defs", 0);
 
     start_new_game();
+    window_destroy(&window.startup);
 
-    for(i=0;i<users->len;i++)
-	user_set_up_team_new_game(&usr(i));
+    if(!opt_int("int_opt_calodds"))
+    {
+	for(i=0;i<users->len;i++)
+	    user_set_up_team_new_game(&usr(i));
+	
+	window_create(WINDOW_MAIN);
+	
+	game_gui_show_main();
 
-    window_destroy(&window.startup, TRUE);
-
-    window_create(WINDOW_MAIN);
-
-    game_gui_show_main();
+	if(statp != NULL)
+	{
+	    debug_action((gchar*)statp);
+	    g_free(statp);
+	    statp = NULL;
+	}
+    }
+    else
+    {
+	free_users(TRUE);
+	debug_calibrate_betting_odds(opt_int("int_opt_calodds_skilldiffmax"),
+				     opt_int("int_opt_calodds_matches"));
+	main_exit_program(EXIT_OK, NULL);
+    }
 }
 
 /** Add a user to the users array. */
@@ -152,7 +204,6 @@ misc_callback_pause_live_game(void)
 
     gtk_widget_set_sensitive(lookup_widget(window.live, "button_pause"), FALSE);
     gtk_widget_set_sensitive(button_resume, TRUE);
-/*     gui_set_sensitive_lg_meters(FALSE); */
     gtk_widget_grab_focus(button_resume);
 
     game_gui_set_main_window_sensitivity(TRUE);
@@ -237,7 +288,7 @@ misc_callback_improve_stadium(void)
     current_user.counters[COUNT_USER_STADIUM_CAPACITY] += value_capacity;
     current_user.counters[COUNT_USER_STADIUM_SAFETY] += value_safety;
 
-    window_destroy(&window.stadium, TRUE);
+    window_destroy(&window.stadium);
     game_gui_set_main_window_header();
 
     setsav0;
@@ -247,12 +298,12 @@ misc_callback_improve_stadium(void)
 void
 misc_callback_startup_load(const gchar *filename)
 {
-    gtk_widget_hide(window.startup);
+    gtk_widget_hide(window.splash);
 
     if(load_save_load_game(filename, TRUE))
-	window_destroy(&window.startup, TRUE);
+	window_destroy(&window.splash);
     else
-	gtk_widget_show(window.startup);
+	gtk_widget_show(window.splash);
 }
 
 
