@@ -1,3 +1,28 @@
+/*
+   name.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "main.h"
 #include "name.h"
 #include "option.h"
@@ -100,10 +125,8 @@ name_get_list_from_sid(const gchar *sid)
     xml_name_read(sid, &new);
 
     if(new.sid == NULL)
-    {
-	g_warning("name_get_list_from_sid: namelist with sid %s not found", sid);
-	main_exit_program(EXIT_POINTER_NOT_FOUND, NULL);
-    }
+	main_exit_program(EXIT_POINTER_NOT_FOUND, 
+			  "name_get_list_from_sid: namelist with sid %s not found", sid);
     else
     {
 	name_shorten_list(&new);
