@@ -1,3 +1,28 @@
+/*
+   option_gui.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "callbacks.h"
 #include "file.h"
 #include "game_gui.h"
@@ -18,6 +43,7 @@ enum BooleanOptions
     BOOL_OPT_SAVE_OVERWRITE,
     BOOL_OPT_MAXIMIZE,
     BOOL_OPT_PREFER_MESS,
+    BOOL_OPT_PROGRESSBAR_PICS,
     BOOL_OPT_SKIP,
     BOOL_OPT_AUTOSAVE,
     BOOL_OPT_SHOW_LIVE,
@@ -32,6 +58,9 @@ enum BooleanOptions
     BOOL_OPT_SWAP,
     BOOL_OPT_SHOW_OVERALL,
     BOOL_OPT_SHOW_ALL_LEAGUES,
+    BOOL_OPT_BET_SHOW_ALL_LEAGUES,
+    BOOL_OPT_BET_SHOW_CUPS,
+    BOOL_OPT_BET_SHOW_MY_RECENT,
     BOOL_OPT_PL1_ATT_NAME,
     BOOL_OPT_PL1_ATT_CPOS,
     BOOL_OPT_PL1_ATT_POS,
@@ -96,6 +125,11 @@ option_gui_write_bool_widgets(gint **bool_options, GtkToggleButton **bool_widget
 	GTK_TOGGLE_BUTTON(lookup_widget(window.options, "checkbutton_pref_mess"));
     bool_options[BOOL_OPT_PREFER_MESS] = opt_intp("int_opt_prefer_messages");
 
+    bool_widgets[BOOL_OPT_PROGRESSBAR_PICS] = 
+	GTK_TOGGLE_BUTTON(lookup_widget(window.options, 
+					"checkbutton_show_progress_pics"));
+    bool_options[BOOL_OPT_PROGRESSBAR_PICS] = opt_intp("int_opt_progressbar_pics");
+
     bool_widgets[BOOL_OPT_SKIP] = 
 	GTK_TOGGLE_BUTTON(lookup_widget(window.options, "checkbutton_skip"));
     bool_options[BOOL_OPT_SKIP] = opt_intp("int_opt_skip");
@@ -148,6 +182,18 @@ option_gui_write_bool_widgets(gint **bool_options, GtkToggleButton **bool_widget
 	GTK_TOGGLE_BUTTON(lookup_widget(window.options, "checkbutton_show_all_leagues"));
     bool_options[BOOL_OPT_SHOW_ALL_LEAGUES] = opt_user_intp("int_opt_user_show_all_leagues");
 
+    bool_widgets[BOOL_OPT_BET_SHOW_ALL_LEAGUES] =
+	GTK_TOGGLE_BUTTON(lookup_widget(window.options, "checkbutton_bet_show_all_leagues"));
+    bool_options[BOOL_OPT_BET_SHOW_ALL_LEAGUES] = opt_user_intp("int_opt_user_bet_show_all_leagues");
+
+    bool_widgets[BOOL_OPT_BET_SHOW_CUPS] =
+	GTK_TOGGLE_BUTTON(lookup_widget(window.options, "checkbutton_bet_show_cups"));
+    bool_options[BOOL_OPT_BET_SHOW_CUPS] = opt_user_intp("int_opt_user_bet_show_cups");
+
+    bool_widgets[BOOL_OPT_BET_SHOW_MY_RECENT] =
+	GTK_TOGGLE_BUTTON(lookup_widget(window.options, "checkbutton_bet_show_only_recent"));
+    bool_options[BOOL_OPT_BET_SHOW_MY_RECENT] = opt_user_intp("int_opt_user_bet_show_my_recent");
+
     bool_widgets[BOOL_OPT_PL1_ATT_NAME] =
 	GTK_TOGGLE_BUTTON(lookup_widget(window.options, "checkbutton1"));
     bool_options[BOOL_OPT_PL1_ATT_NAME] = opt_user_intp("int_opt_user_pl1_att_name");
@@ -303,6 +349,7 @@ enum SpinOptions
     SPIN_OPT_LIVE_SPEED,
     SPIN_OPT_LIVE_VERBOSITY,
     SPIN_OPT_CONTRACT,
+    SPIN_OPT_BET_WAGER,
     SPIN_OPT_END
 };
 
@@ -310,7 +357,7 @@ enum SpinOptions
 void
 option_gui_write_spin_widgets(gint **spin_options, GtkSpinButton **spin_widgets)
 {
-    gint speed_val = 0;
+    gint tmp = 0;
 
     spin_widgets[SPIN_OPT_AUTOSAVE] =
 	GTK_SPIN_BUTTON(lookup_widget(window.options, "spinbutton_autosave"));
@@ -334,13 +381,13 @@ option_gui_write_spin_widgets(gint **spin_options, GtkSpinButton **spin_widgets)
 
     /** Note the spinbutton value so that it doesn't get lost
 	when setting the range. */    
-    speed_val = gtk_spin_button_get_value_as_int(spin_widgets[SPIN_OPT_LIVE_SPEED]);
+    tmp = gtk_spin_button_get_value_as_int(spin_widgets[SPIN_OPT_LIVE_SPEED]);
     gtk_spin_button_set_range(
 	spin_widgets[SPIN_OPT_LIVE_SPEED], 0,
 	-rint((gfloat)(const_int("int_game_gui_live_game_speed_max") - 10) /
 	      (gfloat)(const_int("int_game_gui_live_game_speed_grad"))));
     gtk_spin_button_set_value(spin_widgets[SPIN_OPT_LIVE_SPEED],
-			      (gfloat)speed_val);
+			      (gdouble)tmp);
 
     spin_widgets[SPIN_OPT_LIVE_VERBOSITY] =
 	GTK_SPIN_BUTTON(lookup_widget(window.options, "spinbutton_live_verbosity"));
@@ -349,6 +396,17 @@ option_gui_write_spin_widgets(gint **spin_options, GtkSpinButton **spin_widgets)
     spin_widgets[SPIN_OPT_CONTRACT] =
 	GTK_SPIN_BUTTON(lookup_widget(window.options, "spinbutton_contract"));
     spin_options[SPIN_OPT_CONTRACT] = opt_user_intp("int_opt_user_contract_limit");
+
+    spin_widgets[SPIN_OPT_BET_WAGER] =
+	GTK_SPIN_BUTTON(lookup_widget(window.options, "spinbutton_bet_wager"));
+    spin_options[SPIN_OPT_BET_WAGER] = opt_user_intp("int_opt_user_bet_default_wager");
+
+    tmp = gtk_spin_button_get_value_as_int(spin_widgets[SPIN_OPT_BET_WAGER]);
+    gtk_spin_button_set_range(
+	spin_widgets[SPIN_OPT_BET_WAGER], 1,
+	(gdouble)const_int("int_bet_wager_max"));
+    gtk_spin_button_set_value(spin_widgets[SPIN_OPT_BET_WAGER],
+			      (gdouble)tmp);
 }
 
 
