@@ -1,3 +1,28 @@
+/*
+   options_callbacks.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "file.h"
 #include "options_callbacks.h"
 #include "options_interface.h"
@@ -24,21 +49,21 @@ on_button_options_ok_clicked           (GtkButton       *button,
 
     if(save_global)
     {
-	sprintf(buf, "%s/bygfoot.conf", conf_dir);
+	sprintf(buf, "%s%sbygfoot.conf", conf_dir, G_DIR_SEPARATOR_S);
 	file_save_opt_file(buf, &options);
     }
 
     if(save_user)
     {
 	if(strcmp(current_user.name, "NONAME") == 0)
-	    sprintf(buf, "%s/bygfoot_user.conf", conf_dir);
+	    sprintf(buf, "%s%sbygfoot_user.conf", conf_dir, G_DIR_SEPARATOR_S);
 	else
-	    sprintf(buf, "%s/bygfoot_%s.conf", conf_dir, current_user.name);
+	    sprintf(buf, "%s%sbygfoot_%s.conf", conf_dir, G_DIR_SEPARATOR_S, current_user.name);
 
 	file_save_opt_file(buf, &current_user.options);
     }
 
-    window_destroy(&window.options, TRUE);
+    window_destroy(&window.options);
 }
 
 
@@ -46,7 +71,7 @@ void
 on_button_options_cancel_clicked       (GtkButton       *button,
                                         gpointer         user_data)
 {
-    window_destroy(&window.options, TRUE);
+    window_destroy(&window.options);
 }
 
 
