@@ -1,3 +1,28 @@
+/*
+   player.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "cup.h"
 #include "fixture.h"
 #include "free.h"
@@ -33,21 +58,22 @@ player_new(Team *tm, gfloat average_talent, gboolean new_id)
     new.pos = player_get_position_from_structure(tm->structure, tm->players->len);
     new.cpos = new.pos;
     new.age = math_gauss_dist(const_float("float_player_age_lower"),
-			      const_float("float_player_age_upper"));
-    new.peak_age =
+			      const_float("float_player_age_upper"));//30;
+    new.peak_age = 
 	math_rnd(const_float("float_player_peak_age_lower") +
-		 (new.pos == PLAYER_POS_GOALIE) * 
+		 (new.pos == PLAYER_POS_GOALIE) *
 		 const_float("float_player_peak_age_goalie_addition"),
 		 const_float("float_player_peak_age_upper") +
-		 (new.pos == PLAYER_POS_GOALIE) * 
-		 const_float("float_player_peak_age_goalie_addition"));
+		 (new.pos == PLAYER_POS_GOALIE) *
+		 const_float("float_player_peak_age_goalie_addition"));//30;
 
     new.peak_region = 
 	math_gauss_dist(const_float("float_player_peak_region_lower"),
-			const_float("float_player_peak_region_upper"));
+			const_float("float_player_peak_region_upper"));//2;
 
-    new.talent = CLAMP(average_talent * skill_factor, 0, 
-		       const_float("float_player_max_skill"));
+    new.talent = 
+	CLAMP(average_talent * skill_factor, 0,
+	      const_float("float_player_max_skill"));//85;
 
     new.skill = player_skill_from_talent(&new);
     new.cskill = new.skill;
@@ -289,9 +315,9 @@ player_id_index(const Team *tm, gint player_id)
 	if(g_array_index(tm->players, Player, i).id == player_id)
 	    return i;
     
-    g_warning("player_id_index: didn't find player with id %d of team %s\n", player_id, tm->name);
-    
-    main_exit_program(EXIT_INT_NOT_FOUND, NULL);
+    main_exit_program(EXIT_INT_NOT_FOUND, 
+		      "player_id_index: didn't find player with id %d of team %s\n", 
+		      player_id, tm->name);
 
     return -1;
 }
@@ -304,14 +330,9 @@ Player*
 player_of_idx_team(const Team *tm, gint number)
 {
     if(tm->players->len <= number)
-    {
-	g_warning("player_of_idx_team: Player list of team %s too short for number %d.\n",
-		  tm->name, number);
-
-	main_exit_program(EXIT_POINTER_NOT_FOUND, NULL);
-
-	return NULL;
-    }
+	main_exit_program(EXIT_POINTER_NOT_FOUND, 
+			  "player_of_idx_team: Player list of team %s too short for number %d.\n",
+			  tm->name, number);
 
     return &g_array_index(tm->players, Player, number);
 }
@@ -330,9 +351,9 @@ player_of_id_team(const Team *tm, gint id)
 	if(g_array_index(tm->players, Player, i).id == id)
 	    return &g_array_index(tm->players, Player, i);
     
-    g_warning("player_of_id_team: didn't find player with id %d of team %s\n", id, tm->name);
-    
-    main_exit_program(EXIT_POINTER_NOT_FOUND, NULL);
+    main_exit_program(EXIT_POINTER_NOT_FOUND, 
+		      "player_of_id_team: didn't find player with id %d of team %s\n", 
+		      id, tm->name);
 
     return NULL;
 }
@@ -406,14 +427,17 @@ player_compare_func(gconstpointer a, gconstpointer b, gpointer data)
 
     if(type == PLAYER_COMPARE_ATTRIBUTE_GAME_SKILL)
 	return_value = 
-	    misc_float_compare(player_get_game_skill(pl1, FALSE),
-			       player_get_game_skill(pl2, FALSE));
+	    misc_float_compare(player_get_game_skill(pl1, FALSE, TRUE),
+			       player_get_game_skill(pl2, FALSE, TRUE));
     else if(type == PLAYER_COMPARE_ATTRIBUTE_POS)
     {
-	if(MIN(player_id_index(pl1->team, pl1->id), player_id_index(pl2->team, pl2->id)) < 11 &&
-	   MAX(player_id_index(pl1->team, pl1->id), player_id_index(pl2->team, pl2->id)) >= 11)
+	if(MIN(player_id_index(pl1->team, pl1->id), 
+	       player_id_index(pl2->team, pl2->id)) < 11 &&
+	   MAX(player_id_index(pl1->team, pl1->id), 
+	       player_id_index(pl2->team, pl2->id)) >= 11)
 	    return_value = 
-		(player_id_index(pl1->team, pl1->id) > player_id_index(pl2->team, pl2->id)) ?
+		(player_id_index(pl1->team, pl1->id) > 
+		 player_id_index(pl2->team, pl2->id)) ?
 		1 : -1;
 	else if(pl1->cskill == 0)
 	    return_value = (pl2->cskill == 0) ? 0 : 1;
@@ -464,8 +488,8 @@ player_compare_substitute_func(gconstpointer a, gconstpointer b, gpointer data)
 	powf(pl1->fitness, const_float("float_player_fitness_exponent")),
 	skill_for_pos2 = player_get_cskill(pl2, position, FALSE) * 
 	powf(pl2->fitness, const_float("float_player_fitness_exponent"));
-    gfloat game_skill1 = player_get_game_skill(pl1, FALSE),
-	game_skill2 = player_get_game_skill(pl2, FALSE);
+    gfloat game_skill1 = player_get_game_skill(pl1, FALSE, TRUE),
+	game_skill2 = player_get_game_skill(pl2, FALSE, TRUE);
     gboolean good_structure1 =
 	player_substitution_good_structure(pl1->team->structure, position, pl1->pos),
 	good_structure2 =
@@ -564,13 +588,11 @@ player_move(Team *tm1, gint player_number, Team *tm2, gint insert_at)
 void
 player_swap(Team *tm1, gint player_number1, Team *tm2, gint player_number2)
 {
-    gint clid = -1;
     gint move = (tm1 == tm2 && player_number1 < player_number2) ? 
 	-1 : 1;
 
     if(stat0 == STATUS_LIVE_GAME_PAUSE)
     {
-	clid = usr(stat2).live_game.fix->clid;
 	if((player_number1 < 11 && player_is_banned(player_of_idx_team(tm1, player_number1)) > 0 &&
 	    player_of_idx_team(tm1, player_number1)->participation) ||
 	   (player_number2 < 11 && player_is_banned(player_of_idx_team(tm2, player_number2)) > 0 &&
@@ -672,14 +694,21 @@ player_is_banned(const Player *pl)
 /** Return the player's skill contribution to his team.
     @param pl The player.
     @param skill Whether to take his skill or current skill into account.
+    @param special Whether to count special influence like boost and
+    streak.
     @return A float value representing the player's contribution. */
 gfloat
-player_get_game_skill(const Player *pl, gboolean skill)
+player_get_game_skill(const Player *pl, gboolean skill, gboolean count_special)
 {
-    if(skill)
-	return pl->skill * powf(pl->fitness, const_float("float_player_fitness_exponent"));
-
-    return pl->cskill * powf(pl->fitness, const_float("float_player_fitness_exponent"));
+    gfloat boost = (count_special) ? 
+	1 + const_float("float_player_boost_skill_effect") * pl->team->boost : 1;
+    gfloat streak = (count_special) ?
+	1 + (gfloat)pl->streak * const_float("float_player_streak_influence_skill") : 1;
+    
+    return (skill) ? pl->skill * boost * streak *
+	powf(pl->fitness, const_float("float_player_fitness_exponent"))	:
+	pl->cskill * boost * streak *
+	powf(pl->fitness, const_float("float_player_fitness_exponent"));
 }
 
 /** Decrease a player's fitness during a match.
@@ -697,18 +726,24 @@ player_decrease_fitness(Player *pl)
 	const_float("float_player_streak_influence_fitness_decrease");
 
     if(pl->age < pl->peak_age - pl->peak_region)
+    {
 	pl->fitness -= (((pl->peak_age - pl->peak_region - pl->age) *
 			 const_float("float_player_fitness_decrease_younger_factor") +
 			 const_float("float_player_fitness_decrease_add")) *
 			goalie_factor * boost_factor * streak_factor);
+    }
     else if(pl->age > pl->peak_age + pl->peak_region)
+    {
 	pl->fitness -= (((pl->age - pl->peak_age - pl->peak_region) *
 			 const_float("float_player_fitness_decrease_older_factor") +
 			 const_float("float_player_fitness_decrease_add")) *
 			goalie_factor * boost_factor * streak_factor);
+    }
     else
+    {
 	pl->fitness -= (const_float("float_player_fitness_decrease_add") *
 			goalie_factor * boost_factor * streak_factor);
+    }
 
     pl->fitness = MAX(0, pl->fitness);
 }
@@ -838,10 +873,8 @@ player_games_goals_get(const Player *pl, gint clid, gint type)
 	    else if(type == PLAYER_VALUE_SHOTS)
 		return_value = g_array_index(pl->games_goals, PlayerGamesGoals, i).shots;
 	    else
-	    {
-		g_warning("player_games_goals_get: unknown type %d.\n", type);
-		main_exit_program(EXIT_INT_NOT_FOUND, NULL);
-	    }
+		main_exit_program(EXIT_INT_NOT_FOUND, 
+				  "player_games_goals_get: unknown type %d.\n", type);
 	}
 
     return return_value;
@@ -951,7 +984,8 @@ player_update_injury(Player *pl)
 {
     gint i, j;
     gfloat rndom;
-    gint physio = user_from_team(pl->team)->physio;
+    gint physio = (query_player_is_cpu(pl)) ? 
+	QUALITY_GOOD : user_from_team(pl->team)->physio;
     gfloat injury_decrease_probs[4][3] =
 	{{const_float("float_player_injury_recovery_best0"),
 	  const_float("float_player_injury_recovery_best1"),
@@ -1061,10 +1095,18 @@ player_update_streak(Player *pl)
     }
 }
 
-/** Update a player in a user team (age, skill etc.). */
+/** Update a player in a team (age, skill etc.). */
 void
 player_update_weekly(Player *pl)
 {
+    if(pl->health > 0)
+	player_update_injury(pl);
+    else
+	player_update_streak(pl);
+
+    if(query_player_is_cpu(pl))
+	return;
+    
     pl->age += 0.0192;
 
     if(debug < 50)
@@ -1080,14 +1122,12 @@ player_update_weekly(Player *pl)
 		       pl->name, pl->contract);
 
     if(pl->contract <= 0)
+    {
 	player_remove_contract(pl);
+	return;
+    }
 
     player_update_skill(pl);
-
-    if(pl->health > 0)
-	player_update_injury(pl);
-    else
-	player_update_streak(pl);
 }
 
 /** Remove a player from a user team after the contract expired.
@@ -1106,13 +1146,20 @@ player_remove_contract(Player *pl)
 void
 player_remove_from_team(Team *tm, gint idx)
 {
+    gint usr_idx = team_is_user(tm);
+
+    if(usr_idx != -1 && 
+       player_of_idx_team(tm, idx)->id ==
+       option_int("int_opt_user_penalty_shooter", &usr(usr_idx).options))
+	option_set_int("int_opt_user_penalty_shooter", &usr(usr_idx).options, -1);
+
     transfer_remove_player_ptr(player_of_idx_team(tm, idx));
     free_player(player_of_idx_team(tm, idx));
     g_array_remove_index(tm->players, idx);    
 }
 
 /** Make some player updates after a match
-    for user players.
+    for players.
     @param pl The player we update.
     @param clid The fixture clid. */
 void
@@ -1174,10 +1221,9 @@ player_replace_by_new(Player *pl, gboolean free_player)
     g_array_insert_val(tm->players, idx, new);
 }
 
-/** Update players in user teams.
+/** Update players in teams.
     @param tm The team of the player.
     @param idx The index in the players array. */
-/*d maybe argument player pointer?*/
 void
 player_update_week_roundly(Team *tm, gint idx)
 {
@@ -1244,8 +1290,8 @@ player_injury_to_char(gint injury_type)
 }
 
 /** Nullify some stuff at the beginning of the season and change the skills
-    of cpu players.
-    @param skill_change Skill change of the player in percentage. */
+    and talents of cpu players.
+    @param skill_change Skill/talent change of the player in percentage. */
 void
 player_season_start(Player *pl, gfloat skill_change)
 {
@@ -1265,10 +1311,13 @@ player_season_start(Player *pl, gfloat skill_change)
 
     if(skill_change != 0)
     {
-	pl->skill *= (1 + skill_change);
+	pl->talent *= (1 + skill_change);
+	pl->talent = CLAMP(pl->talent, 0, const_float("float_player_max_skill"));
 
+	pl->skill *= (1 + skill_change);
 	pl->skill = CLAMP(pl->skill, 0, pl->talent);
 	pl->cskill = player_get_cskill(pl, pl->cpos, TRUE);
+
 	pl->value = player_assign_value(pl);
 
 	for(i=0;i<QUALITY_END;i++)
@@ -1361,10 +1410,6 @@ player_move_from_ya(gint idx)
 void
 player_streak_add_to_prob(Player *pl, gfloat add)
 {
-    /** No streaks for CPU players (yet). */
-    if(team_is_user(pl->team) == -1)
-	return;
-
     pl->streak_prob += add;
     pl->streak_prob = CLAMP(pl->streak_prob, -1, 1);
 }
