@@ -1,3 +1,29 @@
+/*
+   start_end.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
+#include "bet.h"
 #include "cup.h"
 #include "file.h"
 #include "finance.h"
@@ -5,6 +31,7 @@
 #include "free.h"
 #include "game_gui.h"
 #include "gui.h"
+#include "job.h"
 #include "league.h"
 #include "live_game.h"
 #include "load_save.h"
@@ -13,6 +40,7 @@
 #include "misc.h"
 #include "name.h"
 #include "option.h"
+#include "player.h"
 #include "start_end.h"
 #include "stat.h"
 #include "table.h"
@@ -36,14 +64,14 @@ WeekFunc end_week_round_funcs[] =
 /** Array of functions called when a week round
     is started. */
 WeekFunc start_week_round_funcs[] =
-{start_week_round_update_user_teams , NULL};
+{start_week_round_update_teams, bet_update, NULL};
 
 /** Array of functions called when a week
     is started. */
 WeekFunc start_week_funcs[] = 
 {start_week_add_cups, start_week_update_users,
- start_week_update_user_teams, start_week_update_user_finances,
- youth_academy_update_weekly, transfer_update, NULL};
+ start_week_update_teams, start_week_update_user_finances,
+ youth_academy_update_weekly, transfer_update, job_update, NULL};
 
 WeekFunc end_week_funcs[] = {stat_update_leagues, end_week_hide_cups, NULL};
 
@@ -52,6 +80,7 @@ void
 start_new_game(void)
 {
     start_write_variables();
+
     start_generate_league_teams();
     start_new_season();
 }
@@ -61,6 +90,7 @@ void
 start_new_season(void)
 {
     gint i, j;
+    gchar buf[SMALL];
 
     week = week_round = 1;
     free_names(TRUE);
@@ -85,9 +115,13 @@ start_new_season(void)
     if(season > 1)
     {
 	for(i=0;i<users->len;i++)
+	{
+	    sprintf(buf, "%d", team_get_league_rank(usr(i).tm));
 	    user_history_add(&usr(i), USER_HISTORY_END_SEASON,
-			     usr(i).team_id, usr(i).tm->clid, 
-			     team_get_league_rank(usr(i).tm), "");
+			     usr(i).tm->name, 
+			     league_cup_get_name_string(usr(i).tm->clid), 
+			     buf, NULL);
+	}
 
 	start_new_season_league_changes();
 
@@ -97,10 +131,16 @@ start_new_season(void)
 
 	    usr(i).youth_academy.tm = usr(i).tm;
 	    for(j=0;j<usr(i).youth_academy.players->len;j++)
+	    {
 		g_array_index(usr(i).youth_academy.players, Player, j).team = usr(i).tm;
+		player_season_start(
+		    &g_array_index(usr(i).youth_academy.players, Player, j), 0);
+	    }
 
 	    live_game_reset(&usr(i).live_game, NULL, TRUE);
 	}
+
+	start_new_season_reset_ids();
     }
     else
     {
@@ -114,6 +154,7 @@ start_new_season(void)
 	    fixture_write_league_fixtures(&lig(i));
 
     for(i=cps->len - 1; i >= 0; i--)
+    {
 	if(cp(i).add_week >= 0)
 	{
 	    cup_reset(&cp(i));
@@ -131,11 +172,15 @@ start_new_season(void)
 		    team_of_id(g_array_index(cp(i).fixtures, Fixture, j).team_ids[1]);
 	    }
 	}
+    }
     
     stat5 = -1;
 
     for(i=0;i<name_lists->len;i++)
 	name_shorten_list(&nli(i));
+
+    if(season == 1)
+	bet_update();
 }
 
 /** Fill some global variables with default values at the
@@ -162,25 +207,48 @@ start_generate_league_teams(void)
 
     if(ligs->len == 0)
 	main_exit_program(EXIT_NO_LEAGUES,
-			  "start_generate_league_teams: no leagues found. there must be at least one league in the game.\n");
+			  "start_generate_league_teams: no leagues found. There must be at least one league in the game.\n");
 
     for(i=0;i<ligs->len;i++)
 	for(j=0;j<lig(i).teams->len;j++)
-	    team_generate_players_stadium(&g_array_index(lig(i).teams, Team, j));
+	    team_generate_players_stadium(&g_array_index(lig(i).teams, Team, j), 0);
 
     stat5 = -1;
 }
 
+/** Reset the cup and league ids to the smallest possible
+    value to avoid an overflow (gotta admit, the id system
+    isn't perfect). */
+void
+start_new_season_reset_ids(void)
+{
+    gint i, max;
+
+    max = -1;
+    for(i=0;i<ligs->len;i++)
+	if(lig(i).id > max)
+	    max = lig(i).id;
+
+    counters[COUNT_LEAGUE_ID] = max + 1;
+
+    max = -1;
+    for(i=0;i<cps->len;i++)
+	if(cp(i).id > max)
+	    max = cp(i).id;
+
+    counters[COUNT_CUP_ID] = max + 1;
+}
+
 /** End a week round. */
 void
 end_week_round(void)
 {
-    gint i;
+    gint i = 0;
     gboolean new_week = TRUE;
     WeekFunc *end_func = end_week_round_funcs;
 
     if(debug > 100)
-	printf("End w %d r %d \n", week, week_round);
+	g_print("End w %d r %d \n", week, week_round);
 
     while(*end_func != NULL)
     {
@@ -237,6 +305,7 @@ end_week_round_results(void)
 	(gfloat)fixture_get_number_of_matches(week, week_round);
     
     for(i=0;i<ligs->len;i++)
+    {
 	for(j=0;j<lig(i).fixtures->len;j++)
 	    if(g_array_index(lig(i).fixtures, Fixture, j).week_number == week &&
 	       g_array_index(lig(i).fixtures, Fixture, j).week_round_number == week_round &&
@@ -245,15 +314,19 @@ end_week_round_results(void)
 		live_game_calculate_fixture(&g_array_index(lig(i).fixtures, Fixture, j));
 
 		done++;
-		fixture_result_to_buf(&g_array_index(lig(i).fixtures, Fixture, j), buf, FALSE);
+		fixture_result_to_buf(&g_array_index(lig(i).fixtures, Fixture, j),
+				      buf, FALSE);
 		sprintf(buf2, "%s %s %s",
 			g_array_index(lig(i).fixtures, Fixture, j).teams[0]->name,
 			buf,
 			g_array_index(lig(i).fixtures, Fixture, j).teams[1]->name);
-		gui_show_progress((gfloat)done / num_matches, buf2);
+		gui_show_progress((gfloat)done / num_matches, buf2,
+				  PIC_TYPE_MATCHPIC);
+
 		if(debug > 120)
-		    printf("%s \n", buf2);
+		    g_print("%s \n", buf2);
 	    }
+    }
 
     for(i=0;i<acps->len;i++)
 	for(j=0;j<acp(i)->fixtures->len;j++)
@@ -265,18 +338,20 @@ end_week_round_results(void)
 		live_game_calculate_fixture(&g_array_index(acp(i)->fixtures, Fixture, j));
 
 		done++;
-		fixture_result_to_buf(&g_array_index(acp(i)->fixtures, Fixture, j), buf, FALSE);
+		fixture_result_to_buf(&g_array_index(acp(i)->fixtures, Fixture, j), 
+				      buf, FALSE);
 		sprintf(buf2, "%s %s %s",
 			g_array_index(acp(i)->fixtures, Fixture, j).teams[0]->name,
 			buf,
 			g_array_index(acp(i)->fixtures, Fixture, j).teams[1]->name);
-		gui_show_progress((gfloat)done / num_matches, buf2);
+		gui_show_progress((gfloat)done / num_matches, buf2,
+				  PIC_TYPE_MATCHPIC);
 		if(debug > 120)
-		    printf("%s \n", buf2);
+		    g_print("%s \n", buf2);
 	    }
 	}
 
-    gui_show_progress(-1, "");
+    gui_show_progress(-1, "", PIC_TYPE_MATCHPIC);
 }
 
 /** Sort league and cup tables. */
@@ -303,8 +378,9 @@ end_week_round_sort_tables(void)
 	    for(j=0;j<cup_get_last_tables(acp(i)->id)->len;j++)
 	    {
 		for(k=0;k<g_array_index(cup_get_last_tables(acp(i)->id), Table, j).elements->len;k++)
-		    g_array_index(g_array_index(cup_get_last_tables(acp(i)->id), Table, j).elements,
-				  TableElement, k).old_rank = k;
+		    g_array_index(
+			g_array_index(cup_get_last_tables(acp(i)->id), Table, j).elements,
+			TableElement, k).old_rank = k;
 
 		g_array_sort_with_data(
 		    g_array_index(cup_get_last_tables(acp(i)->id), Table, j).elements,
@@ -325,13 +401,17 @@ end_week_round_update_fixtures(void)
 	    fixture_update(acp(i));
 
     for(i=0;i<ligs->len;i++)
-	if(lig(i).active && week == g_array_index(
+	if(lig(i).active && week == 
+	   g_array_index(
 	       lig(i).fixtures, Fixture, lig(i).fixtures->len - 1).week_number && 
 	   week_round == 1 &&
 	   team_is_user(g_array_index(lig(i).table.elements, TableElement, 0).team) != -1)
 	    user_history_add(&usr(team_is_user(g_array_index(lig(i).table.elements, TableElement, 0).team)),
-			     USER_HISTORY_CHAMPION, g_array_index(lig(i).table.elements, TableElement, 0).team_id,
-			     lig(i).id, -1, "");
+			     USER_HISTORY_CHAMPION, 
+			     g_array_index(lig(i).table.elements, 
+					   TableElement, 0).team->name,
+			     league_cup_get_name_string(lig(i).id),
+			     NULL, NULL);
     
     for(i=0;i<cps->len;i++)
     {
@@ -353,7 +433,7 @@ start_week_round(void)
     WeekFunc *start_func = start_week_round_funcs;
 
     if(debug > 100)
-	printf("Start w %d r %d \n", week, week_round);
+	g_print("Start w %d r %d \n", week, week_round);
 
     while(*start_func != NULL)
     {
@@ -438,23 +518,33 @@ start_week_add_cups(void)
     CPU teams get updated at the end of their matches
     (to avoid cup teams getting updated too often). */
 void
-start_week_update_user_teams(void)
+start_week_update_teams(void)
 {
-    gint i;
+    gint i, j;
     
-    for(i=0;i<users->len;i++)
-	team_update_user_team_weekly(usr(i).tm);
+    for(i=0;i<ligs->len;i++)
+	for(j=0;j<lig(i).teams->len;j++)
+	    team_update_team_weekly(&g_array_index(lig(i).teams, Team, j));
+
+    for(i=0;i<cps->len;i++)
+	for(j=0;j<cp(i).teams->len;j++)
+	    team_update_team_weekly((Team*)g_ptr_array_index(cp(i).teams, j));
 }
 
 /** Do some things at the beginning of each new round for
     the user teams. */
 void
-start_week_round_update_user_teams(void)
+start_week_round_update_teams(void)
 {
-    gint i;
+    gint i, j;
     
-    for(i=0;i<users->len;i++)
-	team_update_user_team_week_roundly(usr(i).tm);
+    for(i=0;i<ligs->len;i++)
+	for(j=0;j<lig(i).teams->len;j++)
+	    team_update_team_week_roundly(&g_array_index(lig(i).teams, Team, j));
+
+    for(i=0;i<cps->len;i++)
+	for(j=0;j<cp(i).teams->len;j++)
+	    team_update_team_week_roundly((Team*)g_ptr_array_index(cp(i).teams, j));
 }
 
 /** Deduce wages etc. */
@@ -532,17 +622,21 @@ start_new_season_league_changes(void)
     league_team_movements_destinations(team_movements, league_size);
 
     for(i = team_movements->len - 1; i >= 0; i--)
-	if(g_array_index(team_movements, TeamMove, i).prom_rel_type == PROM_REL_RELEGATION)
+	if(g_array_index(team_movements, TeamMove, i).prom_rel_type == 
+	   PROM_REL_RELEGATION)
 	    g_array_prepend_val(
 		lig(g_array_index(
-			g_array_index(team_movements, TeamMove, i).dest_idcs, gint, 0)).teams,
+			g_array_index(team_movements, TeamMove, i).dest_idcs, 
+			gint, 0)).teams,
 		g_array_index(team_movements, TeamMove, i).tm);
     
     for(i=1;i<team_movements->len;i++)
-	if(g_array_index(team_movements, TeamMove, i).prom_rel_type != PROM_REL_RELEGATION)
+	if(g_array_index(team_movements, TeamMove, i).prom_rel_type != 
+	   PROM_REL_RELEGATION)
 	    g_array_append_val(
 		lig(g_array_index(
-			g_array_index(team_movements, TeamMove, i).dest_idcs, gint, 0)).teams,
+			g_array_index(team_movements, TeamMove, i).dest_idcs, 
+			gint, 0)).teams,
 		g_array_index(team_movements, TeamMove, i).tm);
     
     for(i=0;i<team_movements->len;i++)
@@ -555,7 +649,8 @@ start_new_season_league_changes(void)
 	{
 	    g_array_index(lig(i).teams, Team, j).clid = lig(i).id;
 	    for(k=0;k<g_array_index(lig(i).teams, Team, j).players->len;k++)
-		g_array_index(g_array_index(lig(i).teams, Team, j).players, Player, k).team =
+		g_array_index(g_array_index(lig(i).teams, Team, j).players, 
+			      Player, k).team =
 		    &g_array_index(lig(i).teams, Team, j);
 	}
 
