@@ -1,3 +1,28 @@
+/*
+   stat.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "cup.h"
 #include "free.h"
 #include "league.h"
@@ -8,13 +33,15 @@
 #include "team.h"
 #include "variables.h"
 
-/** Return a newly allocated league stat with given clid. */
+/** Return a newly allocated league stat with specified
+    league name and symbol. */
 LeagueStat
-stat_league_new(gint clid)
+stat_league_new(const gchar *league_name, const gchar *league_symbol)
 {
     LeagueStat new;
-
-    new.clid = clid;
+    
+    new.league_name = g_strdup(league_name);    
+    new.league_symbol = g_strdup(league_symbol);
     new.teams_off = g_array_new(FALSE, FALSE, sizeof(Stat));
     new.teams_def = g_array_new(FALSE, FALSE, sizeof(Stat));
     new.player_scorers = g_array_new(FALSE, FALSE, sizeof(Stat));
@@ -35,8 +62,12 @@ stat_update_leagues(void)
 	       lig(i).fixtures, Fixture, lig(i).fixtures->len - 1).week_number >= week)
 	{
 	    free_league_stats(&lig(i).stats);
-	    lig(i).stats.teams_off = stat_update_league_teams(lig(i).teams, TEAM_COMPARE_OFFENSIVE);
-	    lig(i).stats.teams_def = stat_update_league_teams(lig(i).teams, TEAM_COMPARE_DEFENSE);
+	    lig(i).stats.league_name = g_strdup(lig(i).name);
+	    lig(i).stats.league_symbol = g_strdup(lig(i).symbol);
+	    lig(i).stats.teams_off = 
+		stat_update_league_teams(lig(i).teams, TEAM_COMPARE_OFFENSIVE);
+	    lig(i).stats.teams_def = 
+		stat_update_league_teams(lig(i).teams, TEAM_COMPARE_DEFENSE);
 	    stat_update_league_players(&lig(i));
 	}
 }
@@ -78,7 +109,7 @@ stat_update_league_players(League *league)
 	for(j=0;j<maxlen;j++)
 	{
 	    pl = (Player*)g_ptr_array_index(players_sorted[i], j);
-	    new_stat.team_id = pl->team->id;
+	    new_stat.team_name = g_strdup(pl->team->name);
 	    new_stat.value_string = g_strdup(pl->name);
 	    new_stat.value1 = 
 		player_games_goals_get(pl, pl->team->clid, PLAYER_VALUE_GOALS);
@@ -113,9 +144,11 @@ stat_update_league_teams(const GArray *teams_array, gint compare_type)
 
     for(i=0;i<maxlen;i++)
     {
-	new_stat.team_id = ((Team*)g_ptr_array_index(teams, i))->id;
-	new_stat.value1 = team_get_table_value((Team*)g_ptr_array_index(teams, i), TABLE_GF);
-	new_stat.value2 = team_get_table_value((Team*)g_ptr_array_index(teams, i), TABLE_GA);
+	new_stat.team_name = g_strdup(((Team*)g_ptr_array_index(teams, i))->name);
+	new_stat.value1 = 
+	    team_get_table_value((Team*)g_ptr_array_index(teams, i), TABLE_GF);
+	new_stat.value2 = 
+	    team_get_table_value((Team*)g_ptr_array_index(teams, i), TABLE_GA);
 	new_stat.value3 = -1;
 	new_stat.value_string = NULL;
 
@@ -157,7 +190,7 @@ stat_create_season_stat(void)
 	g_array_append_val(new.league_champs, new_champ);
 
 	g_array_append_val(new.league_stats, lig(i).stats);
-	lig(i).stats = stat_league_new(lig(i).id);
+	lig(i).stats = stat_league_new(lig(i).name, lig(i).symbol);
     }
 
     for(i=0;i<acps->len;i++)
@@ -207,12 +240,12 @@ stat_show_av_goals(GArray *fixtures)
 		draw++;
 	}
 
-    printf("------------------------------------ \n");
-    printf("%s\nGoals/G HomeG/G AwayG/G Away %% GD/G \n",
+    g_print("------------------------------------ \n");
+    g_print("%s\nGoals/G HomeG/G AwayG/G Away %% GD/G \n",
 	   league_cup_get_name_string(g_array_index(fixtures, Fixture, 0).clid));
-    printf("%.2f \t %.2f \t %.2f \t %.2f \t %.2f \n", allgoals/games, homegoals/games, awaygoals/games,
+    g_print("%.2f \t %.2f \t %.2f \t %.2f \t %.2f \n", allgoals/games, homegoals/games, awaygoals/games,
 	   awaygoals / allgoals, goaldiff/games);
-    printf("Home win %%: %.2f Loss %%: %.2f Draw %%: %.2f \n",
+    g_print("Home win %%: %.2f Loss %%: %.2f Draw %%: %.2f \n",
 	   homewon / games, homeloss / games, draw / games);
 }
 
@@ -222,7 +255,7 @@ stat_show_av_league_goals(void)
 {
     gint i;
 
-    printf("\n");printf("\n");
+    g_print("\n\n");
     for(i=0;i<ligs->len;i++)
 	stat_show_av_goals(league_cup_get_fixtures(lig(i).id));
 }
