@@ -1,5 +1,31 @@
+/*
+   team.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "cup.h"
 #include "file.h"
+#include "finance.h"
 #include "fixture.h"
 #include "game.h"
 #include "game_gui.h"
@@ -9,6 +35,7 @@
 #include "misc.h"
 #include "option.h"
 #include "player.h"
+#include "strategy.h"
 #include "team.h"
 #include "transfer.h"
 #include "user.h"
@@ -25,16 +52,14 @@ team_new(gboolean new_id)
 {
     Team new;
 
-    new.name = NULL;
-    new.names_file = NULL;
-    new.symbol = NULL;
-    new.def_file = NULL;
-    new.stadium.name = NULL;
+    new.name = new.names_file = 
+	new.symbol = new.def_file = 
+	new.stadium.name = new.strategy_sid = NULL;
     
     new.clid = -1;
     new.id = (new_id) ? team_id_new : -1;
-    new.structure = team_assign_playing_structure();
-    new.style = team_assign_playing_style();
+    new.structure = 442;
+    new.style = 0;
     new.boost = 0;
     new.average_talent = 0;
 
@@ -43,65 +68,19 @@ team_new(gboolean new_id)
     return new;
 }
 
-/**
-   Return a random playing style.
-   @see The #TeamPlayingStyle enumeration.
-*/
-gint
-team_assign_playing_style(void)
-{
-  gfloat rndom;
-
-  rndom = math_rnd(0,1);
-
-  /* all out defend */
-  if(rndom < const_float("float_team_playing_style_prob1"))
-    return -2;
-  /* defend */
-  else if(rndom < const_float("float_team_playing_style_prob2"))
-    return -1;
-  /* balanced */
-  else if(rndom < const_float("float_team_playing_style_prob3"))
-    return 0;
-  /* attack */
-  else if(rndom < const_float("float_team_playing_style_prob4"))
-    return 1;
-
-  /* all out attack */
-  return 2;
-}
-
-/**
-   Return a random playing structure.
-*/
-gint
-team_assign_playing_structure(void)
-{
-  gfloat rndom = math_rnd(0,1);
-    
-  if(rndom < const_float("float_team_playing_structure_prob1"))
-    return 532;
-  else if(rndom < const_float("float_team_playing_structure_prob2"))
-    return 442;
-  else if(rndom < const_float("float_team_playing_structure_prob3"))
-    return 352;
-  else if(rndom < const_float("float_team_playing_structure_prob4"))
-    return 433;
-
-  return 343;
-}
-
 /* Fill the players array of the team and the stadium.
    @param tm The team that gets filled. */
 void
-team_generate_players_stadium(Team *tm)
+team_generate_players_stadium(Team *tm, gfloat av_talent)
 {
     gint i;    
     gfloat skill_factor = math_rnd(1 - const_float("float_team_skill_variance"),
 				   1 + const_float("float_team_skill_variance"));
     Player new;
-    gfloat wages = 0, average_talent;
-    gchar *def_file = team_has_def_file(tm);
+    gfloat wages = 0, average_talent, league_av_talent;
+    gchar *def_file = team_has_def_file(tm);    
+
+    tm->strategy_sid = strategy_get_random();
 
     tm->stadium.average_attendance = tm->stadium.possible_attendance =
 	tm->stadium.games = 0;
@@ -110,9 +89,13 @@ team_generate_players_stadium(Team *tm)
 		 const_float("float_team_stadium_safety_upper"));
 
     if(tm->clid < ID_CUP_START)
+    {
+	league_av_talent = (av_talent > 0) ?
+	    av_talent : league_from_clid(tm->clid)->average_talent;
 	average_talent = (tm->average_talent == 0) ?
-	    skill_factor * league_from_clid(tm->clid)->average_talent :
+	    skill_factor * league_av_talent :
 	    tm->average_talent;
+    }
     else
 	average_talent = 
 	    skill_factor * team_get_average_talents(lig(0).teams) *
@@ -165,8 +148,8 @@ query_team_is_in_cups(const Team *tm, gint group)
 			  (gchar*)g_ptr_array_index(cp(i).team_names, j)) == 0)
 		{
 		    if(debug > 90)
-			printf("team %s group %d found in %s \n", tm->name,
-			       group, cp(i).name);
+			g_print("team %s group %d found in %s \n", tm->name,
+				group, cp(i).name);
 		    return TRUE;
 		}
     
@@ -223,9 +206,8 @@ team_of_id(gint id)
 	    if(((Team*)g_ptr_array_index(cp(i).teams, j))->id == id)
 		return (Team*)g_ptr_array_index(cp(i).teams, j);
 
-    g_warning("team_of_id: team with id %d not found.", id);
-
-    main_exit_program(EXIT_POINTER_NOT_FOUND, NULL);
+    main_exit_program(EXIT_POINTER_NOT_FOUND, 
+		      "team_of_id: team with id %d not found.", id);
 
     return NULL;
 }
@@ -248,21 +230,22 @@ team_get_fixture(const Team *tm, gboolean last_fixture)
     
     if(!last_fixture)
     {
-	for(i=0;i<ligs->len;i++)
-	{
-	    if(lig(i).active && lig(i).id == tm->clid)
+	if(tm->clid < ID_CUP_START)
+	    for(i=0;i<ligs->len;i++)
 	    {
-		for(j=0;j<lig(i).fixtures->len;j++)
-		    if(g_array_index(lig(i).fixtures, Fixture, j).attendance == -1 &&
-		       query_fixture_team_involved((&g_array_index(lig(i).fixtures, Fixture, j)), tm->id))
-		    {
-			fix = &g_array_index(lig(i).fixtures, Fixture, j);
-			break;
-		    }
+		if(lig(i).active && lig(i).id == tm->clid)
+		{
+		    for(j=0;j<lig(i).fixtures->len;j++)
+			if(g_array_index(lig(i).fixtures, Fixture, j).attendance == -1 &&
+			   query_fixture_team_involved((&g_array_index(lig(i).fixtures, Fixture, j)), tm->id))
+			{
+			    fix = &g_array_index(lig(i).fixtures, Fixture, j);
+			    break;
+			}
 
-		break;
+		    break;
+		}
 	    }
-	}
 
 	for(i=0;i<acps->len;i++)
 	    if(fix == NULL ||
@@ -286,21 +269,22 @@ team_get_fixture(const Team *tm, gboolean last_fixture)
     }
     else
     {
-	for(i=0;i<ligs->len;i++)
-	{
-	    if(lig(i).active && lig(i).id == tm->clid)
+	if(tm->clid < ID_CUP_START)
+	    for(i=0;i<ligs->len;i++)
 	    {
-		for(j=lig(i).fixtures->len - 1;j>=0;j--)
-		    if(g_array_index(lig(i).fixtures, Fixture, j).attendance != -1 &&
-		       query_fixture_team_involved((&g_array_index(lig(i).fixtures, Fixture, j)), tm->id))
-		    {
-			fix = &g_array_index(lig(i).fixtures, Fixture, j);
-			break;
-		    }
+		if(lig(i).active && lig(i).id == tm->clid)
+		{
+		    for(j=lig(i).fixtures->len - 1;j>=0;j--)
+			if(g_array_index(lig(i).fixtures, Fixture, j).attendance != -1 &&
+			   query_fixture_team_involved((&g_array_index(lig(i).fixtures, Fixture, j)), tm->id))
+			{
+			    fix = &g_array_index(lig(i).fixtures, Fixture, j);
+			    break;
+			}
 		
-		break;
+		    break;
+		}
 	    }
-	}
 
 	for(i=0;i<acps->len;i++)
 	    if(fix == NULL ||
@@ -341,6 +325,21 @@ team_is_user(const Team *tm)
     return -1;
 }
 
+/** Check whether the team with given name is a user-managed team.
+    @param team_name The team name we examine.
+    @return The user's index in the #users array or -1.*/
+gint
+team_name_is_user(const gchar *team_name)
+{
+    gint i;
+
+    for(i=0;i<users->len;i++)
+	if(strcmp(team_name, usr(i).tm->name) == 0)
+	    return i;
+
+    return -1;
+}
+
 /** Return the overall average skill or
     the cskill of the first 11 players.
     @param tm The team we examine.
@@ -350,7 +349,7 @@ team_get_average_skill(const Team *tm, gboolean cskill)
 {
     gint i, counter = 0;
     gfloat sum = 0;
-
+    
     if(!cskill)
     {
 	for(i=0;i<tm->players->len;i++)
@@ -363,7 +362,7 @@ team_get_average_skill(const Team *tm, gboolean cskill)
     else
 	for(i=0;i<11;i++)
 	{
-	    sum += player_get_game_skill(player_of_idx_team(tm, i), FALSE);
+	    sum += (player_get_game_skill(player_of_idx_team(tm, i), FALSE, FALSE));
 	    counter++;
 	}
 
@@ -411,10 +410,9 @@ team_get_league_rank(const Team *tm)
 	if(g_array_index(elements, TableElement, i).team_id == tm->id)
 	    return i + 1;
     
-    g_warning("team_get_league_rank: no rank found for team %s in league %s. \n",
-	      tm->name, league_cup_get_name_string(tm->clid));
-
-    main_exit_program(EXIT_INT_NOT_FOUND, NULL);
+    main_exit_program(EXIT_INT_NOT_FOUND, 
+		      "team_get_league_rank: no rank found for team %s in league %s. \n",
+		      tm->name, league_cup_get_name_string(tm->clid));
 
     return -1;
 }
@@ -434,11 +432,9 @@ team_get_cup_rank(const Team *tm, const CupRound *cupround, gboolean abort)
     }
 
     if(abort)
-    {
-	g_warning("team_get_cup_rank: no rank found for team %s. \n ", tm->name);
-	
-	main_exit_program(EXIT_INT_NOT_FOUND, NULL);
-    }
+	main_exit_program(EXIT_INT_NOT_FOUND, 
+			  "team_get_cup_rank: no rank found for team %s. \n ", 
+			  tm->name);
 
     return -1;
 }
@@ -518,8 +514,9 @@ team_attribute_to_char(gint attribute, gint value)
     switch(attribute)
     {
 	default:
-	    g_warning("team_attribute_to_char: unknown attribute %d\n", attribute);
-	    main_exit_program(EXIT_INT_NOT_FOUND, NULL);
+	    main_exit_program(EXIT_INT_NOT_FOUND, 
+			      "team_attribute_to_char: unknown attribute %d\n", 
+			      attribute);
 	    break;
 	case TEAM_ATTRIBUTE_STYLE:
 	    switch(value)
@@ -568,102 +565,24 @@ team_change_attribute_with_message(Team *tm, gint attribute, gint new_value)
 	    break;
 	case TEAM_ATTRIBUTE_STYLE:
 	    current_user.tm->style = new_value;
-	    game_gui_print_message(_("Team style changed to %s."), team_attribute_to_char(attribute, new_value));
+	    game_gui_print_message(_("Team style changed to %s."), 
+				   team_attribute_to_char(attribute, new_value));
 	    break;
 	case TEAM_ATTRIBUTE_BOOST:
 	    current_user.tm->boost = new_value;
-	    game_gui_print_message(_("Boost changed to %s."), team_attribute_to_char(attribute, new_value));
+	    if(new_value == 1)
+		game_gui_print_message(
+		    _("Boost changed to %s (costs %d per minute)."), 
+		    team_attribute_to_char(attribute, new_value),
+		    (gint)rint(finance_wage_unit(current_user.tm) *
+			       const_float("float_boost_cost_factor")));
+	    else
+		game_gui_print_message(_("Boost changed to %s."), 
+				       team_attribute_to_char(attribute, new_value));
 	    break;
     }
 }
 
-/** Make cpu players healthy etc.
-    @param tm The cpu team.
-    @param reset_fitness Whether to reset the fitness values of playes. */
-void
-team_update_cpu_corrections(Team *tm, gboolean reset_fitness)
-{
-    gint i, j;
-    Player *pl;
-
-    for(i=0;i<tm->players->len;i++)
-    {
-	pl = player_of_idx_team(tm, i);
-
-	for(j=0;j<pl->cards->len;j++)
-	    g_array_index(pl->cards, PlayerCard, j).red = 0;	
-
-	if(pl->cskill == 0)
-	{
-	    pl->health = pl->recovery = 0;
-	    pl->cskill = player_get_cskill(pl, pl->cpos, FALSE);
-
-	    pl->fitness = math_rnd(const_float("float_player_fitness_lower"),
-				   const_float("float_player_fitness_upper"));
-	}
-	
-	if(pl->pos != pl->cpos)
-	{
-	    pl->pos = pl->cpos;
-	    pl->cskill = player_get_cskill(pl, pl->cpos, FALSE);
-	}
-
-	if(reset_fitness)
-	    pl->fitness = math_rnd(const_float("float_player_fitness_lower"),
-				   const_float("float_player_fitness_upper"));
-    }
-    
-    team_rearrange(tm);
-    
-    tm->structure = team_find_appropriate_structure(tm);
-
-    if(!player_substitution_good_structure(tm->structure, PLAYER_POS_DEFENDER, PLAYER_POS_DEFENDER))
-    {
-	tm->structure = team_assign_playing_structure();
-	for(i=0;i<tm->players->len;i++)
-	{
-	    pl = player_of_idx_team(tm, i);
-	    pl->pos = pl->cpos = player_get_position_from_structure(tm->structure, i);
-	}
-    }
-}
-
-/** Make some random substitutions in the cpu team. */
-void
-team_update_cpu_subs(Team *tm)
-{
-    gint i;
-    gint number_of_subs = math_rndi(const_int("int_team_subs_lower"),
-				    const_int("int_team_subs_upper"));
-    gint player_numbers[11];
-
-    math_generate_permutation(player_numbers, 0, 10);
-
-    for(i=0;i<number_of_subs;i++)
-	game_substitute_player(tm, player_numbers[i]);
-
-    if(player_get_game_skill(player_of_idx_team(tm, 0), 0) <
-       player_get_game_skill(player_of_idx_team(tm, 10), 0) &&
-       math_rnd(0, 1) < const_float("float_team_replace_worse_goalie"))
-	game_substitute_player(tm, 0);
-}
-
-/** Change a cpu team's structure. */
-void
-team_update_cpu_structure(Team *tm)
-{
-    gint i;
-    Player *pl = NULL;
-
-    tm->structure = team_assign_playing_structure();
-
-    for(i=0;i<tm->players->len;i++)
-    {
-	pl = &g_array_index(tm->players, Player, i);
-	pl->pos = pl->cpos = player_get_position_from_structure(tm->structure, i);
-    }
-}
-
 /** Replace some players by new ones in a team. */
 void
 team_update_cpu_new_players(Team *tm)
@@ -682,35 +601,19 @@ team_update_cpu_new_players(Team *tm)
     }
 }
 
-/** Heal players, re-set fitnesses, make some random subs
-    and replace some players with new ones.
-    @param tm The team we examine.
-    @param reset_fitness Whether to reset the fitness values of players. */
-void
-team_update_cpu_team(Team *tm, gboolean reset_fitness)
-{
-    team_update_cpu_corrections(tm, reset_fitness);
-    team_update_cpu_subs(tm);
-
-    if(math_rnd(0, 1) < const_float("float_team_new_player_probability"))
-	team_update_cpu_new_players(tm);
-
-    if(math_rnd(0, 1) < const_float("float_team_new_style"))
-	tm->style = team_assign_playing_style();
-
-    if(math_rnd(0, 1) < const_float("float_team_new_structure"))
-	team_update_cpu_structure(tm);
-}
-
 /** Increase player ages etc.
     @param tm The user team we examine. */
 void
-team_update_user_team_weekly(Team *tm)
+team_update_team_weekly(Team *tm)
 {
     gint i;
 
     for(i=tm->players->len - 1;i>=0;i--)
 	player_update_weekly(&g_array_index(tm->players, Player, i));
+
+    if(team_is_user(tm) == -1 &&
+       math_rnd(0, 1) < const_float("float_team_new_player_probability"))
+	team_update_cpu_new_players(tm);
 }
 
 /** Regenerate player fitness etc. after a match. 
@@ -728,12 +631,15 @@ team_update_post_match(Team *tm, const Fixture *fix)
 /** Some updates each round.
     @param tm The user team we examine. */
 void
-team_update_user_team_week_roundly(Team *tm)
+team_update_team_week_roundly(Team *tm)
 {
     gint i;
 
     for(i=0;i<tm->players->len;i++)
 	player_update_week_roundly(tm, i);
+
+    if(team_is_user(tm) == -1)
+	strategy_update_team_pre_match(tm);
 }
 
 /** Return a value from the league table element going with the team.
@@ -745,13 +651,9 @@ team_get_table_value(const Team *tm, gint type)
     const GArray *elements = NULL;
 
     if(tm->clid >= ID_CUP_START)
-    {
-	g_warning("team_get_table_value: team is not a league team: %s \n", tm->name);
-
-	main_exit_program(EXIT_INT_NOT_FOUND, NULL);
-
-	return -1;
-    }
+	main_exit_program(EXIT_INT_NOT_FOUND, 
+			  "team_get_table_value: team is not a league team: %s \n", 
+			  tm->name);
     
     elements = league_from_clid(tm->clid)->table.elements;
 
@@ -760,13 +662,9 @@ team_get_table_value(const Team *tm, gint type)
 	    break;
 
     if(i == elements->len)
-    {
-	g_warning("team_get_table_value: table entry not found for team %s \n", tm->name);
-
-	main_exit_program(EXIT_INT_NOT_FOUND, NULL);
-
-	return -1;
-    }
+	main_exit_program(EXIT_INT_NOT_FOUND, 
+			  "team_get_table_value: table entry not found for team %s \n", 
+			  tm->name);
 
     return g_array_index(elements, TableElement, i).values[type];
 }
@@ -791,8 +689,10 @@ team_compare_func(gconstpointer a, gconstpointer b, gpointer data)
 					    league_from_clid(tm1->clid)->layer);
     }
     else if(type == TEAM_COMPARE_LEAGUE_LAYER)
-	return_value = misc_int_compare(league_from_clid(tm2->clid)->layer,
-					league_from_clid(tm1->clid)->layer);
+	return_value = 
+	    (tm1->clid >= ID_CUP_START || tm2->clid >= ID_CUP_START) ?
+	    0 : misc_int_compare(league_from_clid(tm2->clid)->layer,
+				 league_from_clid(tm1->clid)->layer);
     else if(type == TEAM_COMPARE_OFFENSIVE)
     {
 	gint gf1 = team_get_table_value(tm1, TABLE_GF),
@@ -878,7 +778,8 @@ team_get_new(const Team *tm, gboolean fire)
 	bound2 = (fire) ? const_int("int_team_new_bound_lower") :
 	const_int("int_team_new_bound_upper");
     gint idx = -1;
-    GPtrArray *teams = team_get_sorted(team_compare_func, TEAM_COMPARE_LEAGUE_RANK, FALSE);
+    GPtrArray *teams = 
+	team_get_sorted(team_compare_func, TEAM_COMPARE_LEAGUE_RANK, FALSE);
     Team *return_value;
 
     for(i=0;i<teams->len;i++)
@@ -928,9 +829,8 @@ team_get_index(const Team *tm)
 		return i;
     }
 
-    g_warning("team_get_index: team %s not found.\n", tm->name);
-
-    main_exit_program(EXIT_INT_NOT_FOUND, NULL);
+    main_exit_program(EXIT_INT_NOT_FOUND, 
+		      "team_get_index: team %s not found.\n", tm->name);
 
     return -1;
 }
@@ -962,22 +862,26 @@ query_team_plays(const Team *tm, gint week_number, gint week_round_number)
 {
     gint i, j;
 
-    for(i=0;i<ligs->len;i++)
-	for(j=0;j<lig(i).fixtures->len;j++)
-	    if(g_array_index(lig(i).fixtures, Fixture, j).week_number == week_number && 
-	       g_array_index(lig(i).fixtures, Fixture, j).week_round_number == week_round_number &&
-	       (g_array_index(lig(i).fixtures, Fixture, j).teams[0] == tm ||
-		g_array_index(lig(i).fixtures, Fixture, j).teams[1] == tm))
-		return TRUE;
-
+    if(tm->clid < ID_CUP_START)
+	for(i=0;i<ligs->len;i++)
+	    if(lig(i).id == tm->clid)
+		for(j=0;j<lig(i).fixtures->len;j++)
+		    if(g_array_index(lig(i).fixtures, Fixture, j).week_number == week_number && 
+		       g_array_index(lig(i).fixtures, Fixture, j).week_round_number == week_round_number &&
+		       (g_array_index(lig(i).fixtures, Fixture, j).teams[0] == tm ||
+			g_array_index(lig(i).fixtures, Fixture, j).teams[1] == tm))
+			return TRUE;
+    
     for(i=0;i<acps->len;i++)
-	for(j=0;j<acp(i)->fixtures->len;j++)
-	    if(g_array_index(acp(i)->fixtures, Fixture, j).week_number == week_number && 
-	       g_array_index(acp(i)->fixtures, Fixture, j).week_round_number == week_round_number &&
-	       (g_array_index(acp(i)->fixtures, Fixture, j).teams[0] == tm ||
-		g_array_index(acp(i)->fixtures, Fixture, j).teams[1] == tm))
-		return TRUE;
-
+	if(query_cup_is_national(acp(i)->id) ||
+	   query_team_is_in_cup(tm, acp(i)))
+	    for(j=0;j<acp(i)->fixtures->len;j++)
+		if(g_array_index(acp(i)->fixtures, Fixture, j).week_number == week_number && 
+		   g_array_index(acp(i)->fixtures, Fixture, j).week_round_number == week_round_number &&
+		   (g_array_index(acp(i)->fixtures, Fixture, j).teams[0] == tm ||
+		    g_array_index(acp(i)->fixtures, Fixture, j).teams[1] == tm))
+		    return TRUE;
+    
     return FALSE;
 }
 
@@ -1196,7 +1100,6 @@ team_complete_def_sort(Team *tm)
 			 math_get_place(tm->structure, 2),
 			 math_get_place(tm->structure, 1)};
     Player player_tmp, player_tmp2;
-    gchar buf[SMALL];
     
     for(i=0;i<11;i++)
 	positions[g_array_index(tm->players, Player, i).pos]++;
@@ -1224,11 +1127,9 @@ team_complete_def_sort(Team *tm)
 	    }
 
 	    if(j == tm->players->len)
-	    {
-		sprintf(buf, "team_complete_def_sort (1): cannot sort according to structure %d (team %s).",
-			tm->structure, tm->name);
-		main_exit_program(EXIT_DEF_SORT, buf);
-	    }
+		main_exit_program(EXIT_DEF_SORT, 
+				  "team_complete_def_sort (1): cannot sort according to structure %d (team %s).",
+				  tm->structure, tm->name);
 	    
 	    positions[i]--;
 	    positions[player_tmp2.pos]++;
@@ -1248,11 +1149,9 @@ team_complete_def_sort(Team *tm)
 		}
 
 	    if(j == 11)
-	    {
-		sprintf(buf, "team_complete_def_sort (2): cannot sort according to structure %d (team %s).",
-			tm->structure, tm->name);
-		main_exit_program(EXIT_DEF_SORT, buf);
-	    }
+		main_exit_program(EXIT_DEF_SORT, 
+				  "team_complete_def_sort (2): cannot sort according to structure %d (team %s).",
+				  tm->structure, tm->name);
 
 	    for(j=10;j<tm->players->len;j++)
 		if(g_array_index(tm->players, Player, j).pos == i)
@@ -1263,11 +1162,9 @@ team_complete_def_sort(Team *tm)
 		}
 
 	    if(j == tm->players->len)
-	    {
-		sprintf(buf, "team_complete_def_sort (3): cannot sort according to structure %d (team %s).",
-			tm->structure, tm->name);
-		main_exit_program(EXIT_DEF_SORT, buf);
-	    }
+		main_exit_program(EXIT_DEF_SORT, 
+				  "team_complete_def_sort (3): cannot sort according to structure %d (team %s).",
+				  tm->structure, tm->name);
 	    
 	    positions[i]++;
 	    positions[player_tmp.pos]--;
