@@ -1,8 +1,35 @@
+/*
+   treeview.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "cup.h"
+#include "file.h"
 #include "finance.h"
 #include "fixture.h"
 #include "free.h"
 #include "game.h"
+#include "game_gui.h"
 #include "language.h"
 #include "league.h"
 #include "live_game.h"
@@ -100,6 +127,11 @@ treeview_set_up_team_selection_treeview(GtkTreeView *treeview)
     gtk_tree_view_set_headers_visible(treeview, TRUE);    
     gtk_tree_view_set_rules_hint(treeview, TRUE);
 
+    gtk_tree_view_set_search_column(treeview, 2);
+    gtk_tree_view_set_search_equal_func(treeview,
+					treeview_helper_search_equal,
+					NULL, NULL);
+
     /* Numbering the teams */
     col = gtk_tree_view_column_new();
     gtk_tree_view_append_column(treeview, col);
@@ -713,11 +745,19 @@ treeview_create_game_stats(LiveGame *live_game)
 			    G_TYPE_STRING,
 			    G_TYPE_STRING);
 
-    fixture_result_to_buf(live_game->fix, buf[0], FALSE);
+    if(live_game->fix != NULL)
+	fixture_result_to_buf(live_game->fix, buf[0], FALSE);
+    else
+	sprintf(
+	    buf[0], "%d : %d",
+	    g_array_index(live_game->units, LiveGameUnit, live_game->units->len - 1).
+	    result[0],
+	    g_array_index(live_game->units, LiveGameUnit, live_game->units->len - 1).
+	    result[1]);
     gtk_list_store_append(ls, &iter);
-    gtk_list_store_set(ls, &iter, 0, live_game->fix->teams[0]->name,
+    gtk_list_store_set(ls, &iter, 0, live_game->team_names[0],
 		       1, buf[0],
-		       2, live_game->fix->teams[1]->name,
+		       2, live_game->team_names[1],
 		       -1);
 
     for(k=0;k<LIVE_GAME_STAT_ARRAY_END;k++)
@@ -759,7 +799,7 @@ treeview_create_game_stats(LiveGame *live_game)
 	}
     }
 
-    misc_print_grouped_int(live_game->fix->attendance, buf[0]);
+    misc_print_grouped_int(live_game->attendance, buf[0]);
     sprintf(buf[1], _("Attendance\n%s"), buf[0]);
     gtk_list_store_append(ls, &iter);
     gtk_list_store_set(ls, &iter, 0, buf[1], 1, "", 2, "", -1);
@@ -906,14 +946,15 @@ treeview_create_fixture(const Fixture *fix, GtkListStore *ls)
     gchar *symbol[2] = {NULL, NULL};
     gchar buf_result[SMALL], buf[3][SMALL];
     gchar *colour_fg = NULL, *colour_bg = NULL;
+    gint user_idx = fixture_user_team_involved(fix);
 
     if(fix->clid >= ID_CUP_START &&
        query_cup_is_international(fix->clid))
 	for(i=0;i<2;i++)
 	    symbol[i] = fix->teams[i]->symbol;
     
-    if(fixture_user_team_involved(fix) != -1)
-	treeview_helper_set_user_colours(usr(fixture_user_team_involved(fix)).tm,
+    if(user_idx != -1)
+	treeview_helper_set_user_colours(usr(user_idx).tm->name,
 					 &colour_bg, &colour_fg);
     else
     {
@@ -1122,8 +1163,12 @@ treeview_create_single_table(GtkListStore *ls, const Table *table, gint number)
 		colour_bg, colour_fg, i + 1);
 
 	treeview_helper_get_table_element_colours(table, i, &colour_fg, &colour_bg, TRUE);
-	sprintf(buf[1], "<span background='%s' foreground='%s'>%s</span>", 
-		colour_bg, colour_fg, elem->team->name);
+	if(debug < 50)
+	    sprintf(buf[1], "<span background='%s' foreground='%s'>%s</span>", 
+		    colour_bg, colour_fg, elem->team->name);
+	else
+	    sprintf(buf[1], "<span background='%s' foreground='%s'>%s (%s)</span>", 
+		    colour_bg, colour_fg, elem->team->name, elem->team->strategy_sid);
 
 	gtk_list_store_set(ls, &iter, 1, buf[0], 3, buf[1], -1);
 
@@ -1306,7 +1351,8 @@ treeview_create_finances(const User* user)
     gchar *in_titles[MON_IN_TRANSFERS] =
 	{_("Prize money"),
 	 _("Ticket income"),
-	 _("Sponsorship")};
+	 _("Sponsorship"),
+	 _("Betting")};
     gchar *out_titles[MON_OUT_TRANSFERS] =
 	{_("Wages"),
 	 _("Physio"),
@@ -1315,7 +1361,10 @@ treeview_create_finances(const User* user)
 	 _("Youth academy"),
 	 _("Journey costs"),
 	 /* Money paid to players a user fired. */
-	 _("Compensations")};
+	 _("Compensations"),
+	 _("Betting"),
+	 /* Applying boost costs money. */
+	 _("Boost costs")};
 
     GtkTreeIter iter;
     GtkListStore *ls = 
@@ -1326,7 +1375,19 @@ treeview_create_finances(const User* user)
 
     gtk_list_store_append(ls, &iter);
     /* Finances balance. */
-    gtk_list_store_set(ls, &iter, 0, _("Bi-weekly balance"), 1, "", 2, "", -1);
+    if(week > 2)
+    {
+	if(week % 2 == 1)
+	    sprintf(buf, _("Bi-weekly balance\n(Week %d and %d)"),
+		    week - 2, week - 1);
+	else
+	    sprintf(buf, _("Bi-weekly balance\n(Week %d and %d)"),
+		    week - 3, week - 2);
+    }
+    else
+	strcpy(buf, _("Bi-weekly balance"));
+
+    gtk_list_store_set(ls, &iter, 0, buf, 1, "", 2, "", -1);
 
     for(i=0;i<MON_IN_TRANSFERS;i++)
 	if(in[i] != 0)
@@ -1545,6 +1606,8 @@ treeview_create_next_opponent(void)
     if(opp == NULL)
 	return NULL;
     
+    ls = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
+
     if(fix->clid < ID_CUP_START)
 	strcpy(buf, league_cup_get_name_string(fix->clid));
     else
@@ -1988,7 +2051,7 @@ treeview_create_user_history(void)
 	gtk_list_store_set(ls, &iter,
 			   0, g_array_index(current_user.history, UserHistory, i).season,
 			   1, g_array_index(current_user.history, UserHistory, i).week,
-			   2, team_of_id(g_array_index(current_user.history, UserHistory, i).team_id)->name,
+			   2, g_array_index(current_user.history, UserHistory, i).team_name,
 			   4, buf, -1);
 
     }
@@ -2077,9 +2140,10 @@ treeview_create_league_stats(GtkListStore *ls, const LeagueStat *league_stat)
     gchar *colour_fg = NULL, *colour_bg = NULL;
     
     gtk_list_store_append(ls, &iter);
-    treeview_helper_insert_icon(ls, &iter, 0, league_from_clid(league_stat->clid)->symbol);
+    treeview_helper_insert_icon(ls, &iter, 0, 
+				league_stat->league_symbol);
     gtk_list_store_set(ls, &iter, 1, const_int("int_treeview_helper_int_empty"),
-		       2, league_cup_get_name_string(league_stat->clid), 3, "", 4, "", 5, "", -1);
+		       2, league_stat->league_name, 3, "", 4, "", 5, "", -1);
 
     for(i=0;i<2;i++)
     {
@@ -2099,11 +2163,13 @@ treeview_create_league_stats(GtkListStore *ls, const LeagueStat *league_stat)
 		    g_array_index(teams[i], Stat, j).value1,
 		    g_array_index(teams[i], Stat, j).value2);
 	    
-	    treeview_helper_set_user_colours(team_of_id(g_array_index(teams[i], Stat, j).team_id),
-					     &colour_bg, &colour_fg);
+	    treeview_helper_set_user_colours(
+		g_array_index(teams[i], Stat, j).team_name,
+		&colour_bg, &colour_fg);
 
 	    sprintf(buf2, "<span background='%s' foreground='%s'>%s</span>",
-		    colour_bg, colour_fg, team_of_id(g_array_index(teams[i], Stat, j).team_id)->name);
+		    colour_bg, colour_fg, 
+		    g_array_index(teams[i], Stat, j).team_name);
 	    
 	    gtk_list_store_append(ls, &iter);
 	    gtk_list_store_set(ls, &iter, 0, NULL, 1, j + 1,
@@ -2141,12 +2207,13 @@ treeview_create_league_stats(GtkListStore *ls, const LeagueStat *league_stat)
 			100 * (1 - (gfloat)g_array_index(players[i], Stat, j).value1 /
 			       (gfloat)g_array_index(players[i], Stat, j).value3) : 0);
 
-	    treeview_helper_set_user_colours(team_of_id(g_array_index(players[i], Stat, j).team_id),
-					     &colour_bg, &colour_fg);
+	    treeview_helper_set_user_colours(
+		g_array_index(players[i], Stat, j).team_name,
+		&colour_bg, &colour_fg);
 	    sprintf(buf3, "<span background='%s' foreground='%s'>%s (%s)</span>",
 		    colour_bg, colour_fg,
 		    g_array_index(players[i], Stat, j).value_string,
-		    team_of_id(g_array_index(players[i], Stat, j).team_id)->name);
+		    g_array_index(players[i], Stat, j).team_name);
 	    sprintf(buf4, "%d", g_array_index(players[i], Stat, j).value1);
 
 	    gtk_list_store_append(ls, &iter);
@@ -2248,11 +2315,12 @@ treeview_create_season_history_champions(GtkListStore *ls, const GArray* league_
     }
 }
 
-/** Show the season history of the specified season
-    and the specified page. Page is either a page of league stats
+/** Show the season history with given index in the season_stats array
+    and the specified page. 
+    @param page Either a page of league stats
     (if != -1) or -1 which means we show the champions. */
 void
-treeview_show_season_history(gint page, gint season_number)
+treeview_show_season_history(gint page, gint idx)
 {
     gchar buf[SMALL];
     GtkTreeView *treeview = GTK_TREE_VIEW(lookup_widget(window.main, "treeview_right"));
@@ -2260,24 +2328,24 @@ treeview_show_season_history(gint page, gint season_number)
 	gtk_list_store_new(6, GDK_TYPE_PIXBUF, G_TYPE_INT, G_TYPE_STRING, G_TYPE_STRING,
 			   G_TYPE_STRING, G_TYPE_STRING);
     GtkTreeIter iter;
-    SeasonStat *stat = &g_array_index(season_stats, SeasonStat, season_number);
+    SeasonStat *stat = &g_array_index(season_stats, SeasonStat, idx);
 
     treeview_helper_clear(treeview);
 
     treeview_set_up_league_stats(treeview);
 
-    sprintf(buf, _("Season %d"), season_number + 1);
+    sprintf(buf, _("Season %d"), stat->season_number);
     gtk_list_store_append(model, &iter);
     gtk_list_store_set(model, &iter, 0, NULL,
 		       1, const_int("int_treeview_helper_int_empty"),
 		       2, buf, -1);
 
     if(page != -1)
-	treeview_create_league_stats(model, 
-				     &g_array_index(stat->league_stats, LeagueStat, page));
+	treeview_create_league_stats(
+	    model, &g_array_index(stat->league_stats, LeagueStat, page));
     else
-	treeview_create_season_history_champions(model, stat->league_champs,
-						 stat->cup_champs);
+	treeview_create_season_history_champions(
+	    model, stat->league_champs, stat->cup_champs);
 
     gtk_tree_view_set_model(treeview, GTK_TREE_MODEL(model));
     g_object_unref(model);
@@ -2310,9 +2378,10 @@ treeview_create_country_list(const GPtrArray *country_list)
 
 /** Show the list of contributors in the help window.*/
 void
-treeview_show_contributors(const OptionList *help_list)
+treeview_show_contributors(GtkTreeView *treeview)
 {
-    GtkTreeView *treeview = GTK_TREE_VIEW(lookup_widget(window.help, "treeview_contributors"));
+    gchar *help_file = file_find_support_file("bygfoot_help", TRUE);
+    OptionList help_list;
     GtkListStore *ls = gtk_list_store_new(1, G_TYPE_STRING);
     GtkTreeIter iter;
     GtkTreeViewColumn   *col;
@@ -2320,6 +2389,17 @@ treeview_show_contributors(const OptionList *help_list)
     gint i;
     gchar buf[SMALL];
 
+
+    if(help_file == NULL)
+    {
+	game_gui_show_warning(_("Didn't find file 'bygfoot_help'."));
+	return;
+    }
+
+    help_list.list = NULL;
+    help_list.datalist = NULL;
+    file_load_opt_file(help_file, &help_list);
+
     gtk_tree_selection_set_mode(gtk_tree_view_get_selection(treeview),
 				GTK_SELECTION_NONE);
     gtk_tree_view_set_rules_hint(treeview, FALSE);
@@ -2332,22 +2412,22 @@ treeview_show_contributors(const OptionList *help_list)
     gtk_tree_view_column_add_attribute(col, renderer,
 				       "markup", 0);
 
-    for(i=0;i<help_list->list->len;i++)
+    for(i=0;i<help_list.list->len;i++)
     {
 	gtk_list_store_append(ls, &iter);
 	
-	if(g_str_has_prefix(g_array_index(help_list->list, Option, i).name,
+	if(g_str_has_prefix(g_array_index(help_list.list, Option, i).name,
 			    "string_contrib_title"))
 	{
 	    sprintf(buf, "\n<span %s>%s</span>", 
 		    const_app("string_help_window_title_attribute"),
-		    g_array_index(help_list->list, Option, i).string_value);
+		    g_array_index(help_list.list, Option, i).string_value);
 	    gtk_list_store_set(ls, &iter, 0, buf, -1);
 	}
-	else if(g_str_has_prefix(g_array_index(help_list->list, Option, i).name,
+	else if(g_str_has_prefix(g_array_index(help_list.list, Option, i).name,
 				 "string_contrib_"))
 	{
-	    strcpy(buf, g_array_index(help_list->list, Option, i).string_value);
+	    strcpy(buf, g_array_index(help_list.list, Option, i).string_value);
 	    gtk_list_store_set(ls, &iter, 0, buf, -1);
 	}
 
@@ -2355,6 +2435,9 @@ treeview_show_contributors(const OptionList *help_list)
 
     gtk_tree_view_set_model(treeview, GTK_TREE_MODEL(ls));
     g_object_unref(ls);
+
+    g_free(help_file);
+    free_option_list(&help_list, FALSE);
 }
 
 GtkTreeModel*
