@@ -1,7 +1,34 @@
+/*
+   treeview_helper.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
+#include "bet.h"
 #include "cup.h"
 #include "file.h"
 #include "fixture.h"
 #include "free.h"
+#include "job.h"
 #include "league.h"
 #include "misc.h"
 #include "option.h"
@@ -243,7 +270,7 @@ treeview_helper_get_user_history_icon(gint history_type)
 	    return NULL;
 	case USER_HISTORY_START_GAME:
 	    return const_app("string_treeview_helper_user_history_symbol_start_game_icon");
-    	case USER_HISTORY_FIRE_FINANCES:
+    	case USER_HISTORY_FIRE_FINANCE:
 	    return const_app("string_treeview_helper_user_history_symbol_fire_finances_icon");
     	case  USER_HISTORY_FIRE_FAILURE:
 	    return const_app("string_treeview_helper_user_history_symbol_fire_failure_icon");
@@ -603,14 +630,15 @@ treeview_helper_get_table_element_colours(const Table *table, gint idx,
 /** Set the char pointers to the constant determining the background and foreground
     colours of user entries in treeviews if the team is a user team. */
 void
-treeview_helper_set_user_colours(const Team *tm, gchar **colour_bg, gchar **colour_fg)
+treeview_helper_set_user_colours(const gchar *team_name,
+				 gchar **colour_bg, gchar **colour_fg)
 {
-    if(tm == current_user.tm)
+    if(strcmp(team_name, current_user.tm->name) == 0)
     {
 	*colour_fg = const_app("string_treeview_current_user_fg");
 	*colour_bg = const_app("string_treeview_current_user_bg");
     }
-    else if(team_is_user(tm) != -1)
+    else if(team_name_is_user(team_name) != -1)
     {
 	*colour_fg = const_app("string_treeview_user_fg");
 	*colour_bg = const_app("string_treeview_user_bg");
@@ -646,7 +674,8 @@ treeview_helper_get_attributes_from_scout(gint scout)
 	attribute.on_off[PLAYER_LIST_ATTRIBUTE_AGE] = TRUE;
     if(scout < 1)
 	attribute.on_off[PLAYER_LIST_ATTRIBUTE_GAMES] =
-	    attribute.on_off[PLAYER_LIST_ATTRIBUTE_GOALS] = TRUE;
+	    attribute.on_off[PLAYER_LIST_ATTRIBUTE_GOALS] = 
+	    attribute.on_off[PLAYER_LIST_ATTRIBUTE_STATUS] = TRUE;
 
     return attribute;
 }
@@ -670,7 +699,10 @@ treeview_helper_team_selection(GtkTreeViewColumn *col,
 	g_object_set(renderer, "text", ((Team*)team_pointer)->name, NULL);
     else if(column == 4)
     {
-	sprintf(buf, "%.1f", team_get_average_skill((Team*)team_pointer, FALSE));
+	if(stat0 == STATUS_TEAM_SELECTION)
+	    strcpy(buf, "");
+	else
+	    sprintf(buf, "%.1f", team_get_average_skill((Team*)team_pointer, FALSE));
 	g_object_set(renderer, "text", buf, NULL);
     }
     else
@@ -962,7 +994,7 @@ treeview_helper_player_to_cell(GtkTreeViewColumn *col,
 			       gpointer           user_data)
 {
     gint column = treeview_helper_get_col_number_column(col);
-    gint attribute = GPOINTER_TO_INT(user_data);
+    gint attribute = GPOINTER_TO_INT(user_data), idx = -1;
     gchar  buf[SMALL];
     const Player *pl;
 
@@ -1035,10 +1067,16 @@ treeview_helper_player_to_cell(GtkTreeViewColumn *col,
 	    treeview_helper_player_contract_to_cell(renderer, buf, pl->contract);
 	    break;
 	case PLAYER_LIST_ATTRIBUTE_TEAM:
-	    sprintf(buf, "%s", pl->team->name);
+	    if(debug < 50)
+		sprintf(buf, "%s", pl->team->name);
+	    else
+		sprintf(buf, "%s (%s)", pl->team->name, pl->team->strategy_sid);
 	    break;
 	case PLAYER_LIST_ATTRIBUTE_LEAGUE_CUP:
-	    strcpy(buf, league_cup_get_name_string(pl->team->clid));
+	    idx = job_team_is_on_list(pl->team->id);
+	    strcpy(buf, (idx == -1) ?
+		   league_cup_get_name_string(pl->team->clid) :
+		   g_array_index(jobs, Job, idx).league_name);
 	    break;
     }
 
@@ -1361,7 +1399,7 @@ void
 treeview_helper_player_cskill_to_cell(GtkCellRenderer *renderer, gchar *buf, const Player *pl)
 {
     sprintf(buf, "%.*f", opt_int("int_opt_player_precision"),
-	    player_get_game_skill(pl, FALSE));
+	    player_get_game_skill(pl, FALSE, FALSE));
 	    
     if(pl->cskill < pl->skill)
 	g_object_set(renderer, "background", 
@@ -1561,3 +1599,108 @@ treeview_helper_season_results(GtkTreeViewColumn *col,
 
     g_object_set(renderer, "text", buf, NULL);
 }
+
+void
+treeview_helper_bet_odds(GtkTreeViewColumn *col,
+			 GtkCellRenderer   *renderer,
+			 GtkTreeModel      *model,
+			 GtkTreeIter       *iter,
+			 gpointer           user_data)
+{
+    gint column = treeview_helper_get_col_number_column(col);
+    gchar buf[SMALL];
+    const Fixture *fix = NULL;
+    const BetMatch *bet = NULL;
+    const BetUser *bet_user = NULL;
+
+    gtk_tree_model_get(model, iter, column, &bet, -1);
+
+    g_object_set(renderer, "background",
+		 const_app("string_treeview_helper_color_default_background"), 
+		 "foreground",
+		 const_app("string_treeview_helper_color_default_foreground"), 
+		 "text", "", NULL);
+
+    if(bet == NULL)
+	return;
+
+    strcpy(buf, "");
+    bet_user = bet_is_user(bet);
+    fix = fixture_from_id(bet->fix_id, TRUE);
+
+    if(fix->attendance == -1)
+	sprintf(buf, "%.2f", bet->odds[column - 1]);
+    else if(column == 2)
+	sprintf(buf, "%d - %d", fix->result[0][0],
+		fix->result[1][0]);
+    
+    if(fix->attendance == -1 &&
+       bet_user != NULL &&
+       bet_user->outcome == column - 1)
+	g_object_set(renderer, "background",
+		     const_app("string_treeview_helper_color_user_bet_bg"), 
+		     "foreground",
+		     const_app("string_treeview_helper_color_user_bet_fg"), NULL);
+
+    g_object_set(renderer, "text", buf, NULL);
+}
+
+gboolean
+treeview_helper_search_equal(GtkTreeModel *model,
+			     gint column,
+			     const gchar *key,
+			     GtkTreeIter *iter,
+			     gpointer search_data)
+{
+    const Team *tm = NULL;
+    gchar *name_lower = NULL;
+    gboolean return_value = TRUE;
+
+    gtk_tree_model_get(model, iter, column, &tm, -1);
+    
+    name_lower = g_utf8_strdown(tm->name, -1);
+
+    return_value = (g_strrstr(name_lower, key) == NULL);
+
+    return return_value;
+}
+
+void
+treeview_helper_job_exchange(GtkTreeViewColumn *col,
+			     GtkCellRenderer   *renderer,
+			     GtkTreeModel      *model,
+			     GtkTreeIter       *iter,
+			     gpointer           user_data)
+{
+    gint column = treeview_helper_get_col_number_column(col);
+    gchar buf[SMALL];
+    const Job *job = NULL;
+
+    gtk_tree_model_get(model, iter, column, &job, -1);
+    
+    if(job == NULL)
+	return;
+
+    g_object_set(renderer, "background",
+		 const_app("string_treeview_helper_color_default_background"), 
+		 "foreground",
+		 const_app("string_treeview_helper_color_default_foreground"), 
+		 NULL);
+
+    if(column == 3)
+    {
+	strcpy(buf, job->country_name);
+	if(job->type != JOB_TYPE_NATIONAL)
+	    g_object_set(renderer, "background",
+			 const_app("string_treeview_helper_color_job_international_bg"),
+			 "foreground",
+			 const_app("string_treeview_helper_color_job_international_fg"), 
+			 NULL);
+    }
+    else if(column == 4)
+	sprintf(buf, "%.1f", team_get_average_skill(job_get_team(job), FALSE));
+    else if(column == 5)
+	sprintf(buf, "%d", job->talent_percent);
+
+    g_object_set(renderer, "text", buf, NULL);
+}
