@@ -152,6 +152,9 @@ user_set_up_team(User *user)
 
     user->counters[COUNT_USER_NEW_SPONSOR] = 
 	(sett_int("int_opt_disable_finances")) ? -5 : 1;
+
+    option_set_int("int_opt_user_penalty_shooter",
+		   &user->options, -1);
 }
 
 
@@ -536,6 +539,9 @@ user_event_show_next(void)
 	    treeview_show_user_player_list();
 	    game_gui_show_warning(buf);
 	    break;
+	case EVENT_TYPE_CHARITY:
+	    game_gui_show_warning(_("The team owners are very satisfied with your financial management. Since the team's been earning a lot of money lately, they decide to donate half of it to charity."));
+	    break;
     }
 
     user_event_remove(&current_user, 0);
