@@ -1,17 +1,46 @@
+/*
+   window.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "callbacks.h"
+#include "debug.h"
 #include "file.h"
 #include "finance.h"
 #include "free.h"
 #include "game_gui.h"
 #include "gui.h"
 #include "interface.h"
+#include "language.h"
 #include "league.h"
 #include "live_game.h"
 #include "load_save.h"
 #include "main.h"
+#include "maths.h"
 #include "misc_callback_func.h"
 #include "misc_interface.h"
 #include "misc2_interface.h"
+#include "misc3_interface.h"
 #include "option.h"
 #include "option_gui.h"
 #include "options_interface.h"
@@ -23,22 +52,178 @@
 #include "user.h"
 #include "window.h"
 
-/** Show the window with the news. */
-/* void */
-/* window_show_news(void) */
-/* { */
-/*     GtkNotebook *nb = NULL; */
+/** Show the splash screen window. */
+void
+window_show_splash(void)
+{
+    window_create(WINDOW_SPLASH);
 
-/*     window_create(WINDOW_HELP); */
+    treeview_show_contributors(
+	GTK_TREE_VIEW(lookup_widget(window.splash, "treeview_splash_contributors")));
+    
+    window_load_hint_number();
+    window_splash_show_hint();
+}
 
-/*     nb = GTK_NOTEBOOK(lookup_widget(window.help, "notebook1")); */
+/** Show the hint determined by the hint counter in the splash window. */
+void
+window_splash_show_hint(void)
+{
+    gchar buf[SMALL];
 
-/*     gtk_notebook_remove_page(nb, 0); */
-/*     gtk_notebook_remove_page(nb, -1); */
+    gtk_label_set_text(
+	GTK_LABEL(lookup_widget(window.splash, "label_splash_hint")),
+	g_array_index(hints.list, Option, counters[COUNT_HINT_NUMBER]).string_value);
 
-/*     gtk_label_set_text(GTK_LABEL(lookup_widget(window.help, "label_contributors")), */
-/* 		       _("News")); */
-/* } */
+    sprintf(buf, "(%d/%d)", counters[COUNT_HINT_NUMBER] + 1,
+	    hints.list->len);
+
+    gtk_label_set_text(
+	GTK_LABEL(lookup_widget(window.splash, "label_splash_hintcounter")),
+	buf);    
+}
+
+/** Load the index of the hint to show in the splash screen. */
+void
+window_load_hint_number(void)
+{
+    gchar filename[SMALL];
+    gchar dir[SMALL];
+    FILE *fil;
+    
+    file_get_bygfoot_dir(dir);
+
+    sprintf(filename, "%s%shint_num",
+	    dir, G_DIR_SEPARATOR_S);
+
+    fil = fopen(filename, "r");
+
+    if(fil == NULL)
+    {
+	counters[COUNT_HINT_NUMBER] = 0;
+	return;
+    }
+
+    fscanf(fil, "%d", &counters[COUNT_HINT_NUMBER]);
+
+    fclose(fil);
+
+    if(counters[COUNT_HINT_NUMBER] < 0 ||
+       counters[COUNT_HINT_NUMBER] >= hints.list->len)
+    {
+	g_warning("Hint counter out of bounds: %d (bounds 0 and %d).\n",
+		  counters[COUNT_HINT_NUMBER], hints.list->len - 1);
+	counters[COUNT_HINT_NUMBER] = 0;
+    }
+}
+
+/** Save the index of the current hint. */
+void
+window_save_hint_number(void)
+{
+    gchar filename[SMALL];
+    gchar dir[SMALL];
+    FILE *fil;
+
+    file_get_bygfoot_dir(dir);
+
+    sprintf(filename, "%s%shint_num",
+	    dir, G_DIR_SEPARATOR_S);
+
+    fil = fopen(filename, "w");
+
+    if(fil == NULL)
+	return;
+
+    fprintf(fil, "%d", counters[COUNT_HINT_NUMBER]);
+
+    fclose(fil);
+}
+
+/** Show the window with the progress bar,
+    sometimes with a nice picture. */
+void
+window_show_progress(gint pictype)
+{
+    GPtrArray *pics = NULL;
+    const gchar *picdir = NULL;
+    gchar buf[SMALL];
+    gchar *buf2 = NULL;
+    GtkImage *image = NULL;
+
+    window_create(WINDOW_PROGRESS);
+
+    if(pictype == PIC_TYPE_NONE ||
+       !opt_int("int_opt_progressbar_pics"))
+	return;
+
+    image = GTK_IMAGE(lookup_widget(window.progress,
+				    "image_match"));
+
+    switch(pictype)
+    {
+	default:
+	    g_warning("window_show_progress: unknown picture type %d",
+		      pictype);
+	    break;
+	case PIC_TYPE_SAVE:
+	    gtk_image_set_from_stock(image, GTK_STOCK_FLOPPY,
+				     GTK_ICON_SIZE_DIALOG);
+	    break;
+	case PIC_TYPE_LOAD:
+	    gtk_image_set_from_stock(image, GTK_STOCK_OPEN,
+				     GTK_ICON_SIZE_DIALOG);
+	    break;
+	case PIC_TYPE_MATCHPIC:
+	    if(debug_egg_forwards_boost_style())
+	    {
+		buf2 = file_find_support_file("soccerbabes.jpg", FALSE);
+		if(buf2 != NULL)
+		{
+		    gtk_image_set_from_file(image, buf2);
+		    g_free(buf2);
+		}
+	    }
+
+	    if(buf2 == NULL)
+	    {
+		picdir = file_get_first_support_dir_suffix("pics");
+		if(picdir == NULL)
+		    return;
+		
+		pics = file_dir_get_contents(picdir, "match", "");
+		
+		if(pics->len != 0)
+		{	
+		    sprintf(buf, "%s%s%s", picdir, G_DIR_SEPARATOR_S,
+			    (gchar*)g_ptr_array_index(pics, math_rndi(0, pics->len - 1)));
+		    gtk_image_set_from_file(image, buf);
+		}
+		
+		free_gchar_array(&pics);
+	    }
+	    break;
+    }
+}
+
+/** Show the betting window. */
+void
+window_show_bets(void)
+{
+    window_create(WINDOW_BETS);
+
+    gtk_toggle_button_set_active(
+	GTK_TOGGLE_BUTTON(lookup_widget(window.bets, "checkbutton_bet_all_leagues")),
+	opt_user_int("int_opt_user_bet_show_all_leagues"));
+    gtk_toggle_button_set_active(
+	GTK_TOGGLE_BUTTON(lookup_widget(window.bets, "checkbutton_bet_cups")),
+	opt_user_int("int_opt_user_bet_show_cups"));
+    gtk_toggle_button_set_active(
+	GTK_TOGGLE_BUTTON(lookup_widget(window.bets, "checkbutton_bet_user_recent")),
+	opt_user_int("int_opt_user_bet_show_my_recent"));
+
+    treeview2_show_bets();
+}
 
 /** Show the help/about window. 
     @param page Which notebook page to display. */
@@ -46,32 +231,18 @@ void
 window_show_help(gint page)
 {
     gchar buf[SMALL];
-    gchar *help_file = file_find_support_file("bygfoot_help", TRUE);
-    OptionList help_list;
-
-    if(help_file == NULL)
-    {
-	game_gui_show_warning(_("Didn't find file 'bygfoot_help'."));
-	return;
-    }
-
-    help_list.list = NULL;
-    help_list.datalist = NULL;
-    file_load_opt_file(help_file, &help_list);
 
     window_create(WINDOW_HELP);
 
     sprintf(buf, "<span %s>Bygfoot Football Manager %s</span>\n(c) 2005 Győző Both (gyboth@bygfoot.com)\nhttp://bygfoot.sourceforge.net", const_app("string_help_window_program_name_attribute"), VERS);
     gtk_label_set_markup(GTK_LABEL(lookup_widget(window.help, "label_about")), buf);
 
-    treeview_show_contributors(&help_list);
+    treeview_show_contributors(
+	GTK_TREE_VIEW(lookup_widget(window.help, "treeview_contributors")));
 
     game_gui_set_help_labels();
 
     gtk_notebook_set_current_page(GTK_NOTEBOOK(lookup_widget(window.help, "notebook1")), page);
-
-    g_free(help_file);
-    free_option_list(&help_list, FALSE);
 }
 
 /**
@@ -92,7 +263,8 @@ window_show_startup(void)
     country_files = file_get_country_files();
 
     if(country_files->len == 0)
-	main_exit_program(EXIT_NO_COUNTRY_FILES, "Didn't find any country definition files in the support directories.");
+	main_exit_program(EXIT_NO_COUNTRY_FILES, 
+			  "Didn't find any country definition files in the support directories.");
 
     gtk_cell_layout_clear(GTK_CELL_LAYOUT(combo_country));
 
@@ -104,6 +276,7 @@ window_show_startup(void)
     gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combo_country), renderer, TRUE);
     gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(combo_country), renderer, "text", 1, NULL);
 
+    language_pick_country(country_files);
     model = treeview_create_country_list(country_files);
     gtk_combo_box_set_model(GTK_COMBO_BOX(combo_country), model);
     g_object_unref(model);
@@ -126,7 +299,7 @@ window_show_file_sel(void)
     window_create(WINDOW_FILE_CHOOSER);
 
     if(stat5 != STATUS_LOAD_GAME &&
-       stat5 != STATUS_LOAD_GAME_TEAM_SELECTION)
+       stat5 != STATUS_LOAD_GAME_SPLASH)
 	gtk_file_chooser_set_action(GTK_FILE_CHOOSER(window.file_chooser),
 				    GTK_FILE_CHOOSER_ACTION_SAVE);
     else
@@ -136,7 +309,7 @@ window_show_file_sel(void)
     filter = gtk_file_filter_new();
     if(stat5 == STATUS_SAVE_GAME || 
        stat5 == STATUS_LOAD_GAME ||
-       stat5 == STATUS_LOAD_GAME_TEAM_SELECTION)
+       stat5 == STATUS_LOAD_GAME_SPLASH)
     {
 	gtk_file_filter_set_name(filter, _("Bygfoot Save Files"));
 	gtk_file_filter_add_pattern(filter, "*.zip");
@@ -156,7 +329,7 @@ window_show_file_sel(void)
 
     if((stat5 == STATUS_SAVE_GAME || 
 	stat5 == STATUS_LOAD_GAME ||
-	stat5 == STATUS_LOAD_GAME_TEAM_SELECTION) &&
+	stat5 == STATUS_LOAD_GAME_SPLASH) &&
        save_file != NULL)
 	gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(window.file_chooser),
 				      save_file);
@@ -185,7 +358,7 @@ window_show_file_sel(void)
 
 	if(stat5 == STATUS_LOAD_GAME)
 	    load_save_load_game(filename, FALSE);
-	else if(stat5 == STATUS_LOAD_GAME_TEAM_SELECTION)
+	else if(stat5 == STATUS_LOAD_GAME_SPLASH)
 	    misc_callback_startup_load(filename);
 	else if(stat5 == STATUS_SAVE_GAME)
 	    load_save_save_game(filename);
@@ -220,7 +393,7 @@ window_show_file_sel(void)
 	    user_mm_export_file(filename);
 
 	if(stat5 == STATUS_LOAD_GAME ||
-	   stat5 == STATUS_LOAD_GAME_TEAM_SELECTION)
+	   stat5 == STATUS_LOAD_GAME_SPLASH)
 	{
 	    cur_user = 0;
 	    on_button_back_to_main_clicked(NULL, NULL);
@@ -230,7 +403,7 @@ window_show_file_sel(void)
 	g_free(filename);
     }
 
-    window_destroy(&window.file_chooser, FALSE);
+    window_destroy(&window.file_chooser);
 }
 
 /** Show window with memorable matches list. */
@@ -259,7 +432,7 @@ void
 window_show_menu_player(GdkEvent *event)
 {
     if(window.menu_player != NULL)
-	window_destroy(&window.menu_player, FALSE);
+	window_destroy(&window.menu_player);
 
     window.menu_player = create_menu_player();
 
@@ -272,7 +445,7 @@ void
 window_show_menu_youth(GdkEvent *event)
 {
     if(window.menu_youth != NULL)
-	window_destroy(&window.menu_youth, FALSE);
+	window_destroy(&window.menu_youth);
 
     window.menu_youth = create_menu_youth();
 
@@ -436,19 +609,14 @@ void
 window_main_save_geometry(void)
 {
     gchar filename[SMALL];
-    const gchar *home = g_get_home_dir();
-    gchar *pwd = g_get_current_dir();
+    gchar dir[SMALL];
     FILE *fil = NULL;
     gint width, height, pos_x, pos_y, paned_pos;
     
-    if(os_is_unix)
-	sprintf(filename, "%s%s%s%swindow_settings",
-		home, G_DIR_SEPARATOR_S, HOMEDIRNAME, G_DIR_SEPARATOR_S);
-    else
-	sprintf(filename, "%s%swindow_settings",
-		pwd, G_DIR_SEPARATOR_S);
+    file_get_bygfoot_dir(dir);
 
-    g_free(pwd);
+    sprintf(filename, "%s%swindow_settings",
+	    dir, G_DIR_SEPARATOR_S);
 
     if(window.main != NULL && file_my_fopen(filename, "w", &fil, FALSE))
     {
@@ -473,18 +641,13 @@ void
 window_main_load_geometry(void)
 {
     gchar filename[SMALL];
-    const gchar *home = g_get_home_dir();
-    gchar *pwd = g_get_current_dir();
+    gchar dir[SMALL];
     OptionList optionlist;
     
-    if(os_is_unix)
-	sprintf(filename, "%s%s%s%swindow_settings",
-		home, G_DIR_SEPARATOR_S, HOMEDIRNAME, G_DIR_SEPARATOR_S);
-    else
-	sprintf(filename, "%s%swindow_settings",
-		pwd, G_DIR_SEPARATOR_S);
+    file_get_bygfoot_dir(dir);
 
-    g_free(pwd);
+    sprintf(filename, "%s%swindow_settings",
+	    dir, G_DIR_SEPARATOR_S);
 
     if(g_file_test(filename, G_FILE_TEST_EXISTS))
     {
@@ -515,7 +678,6 @@ window_main_load_geometry(void)
 GtkWidget*
 window_create(gint window_type)
 {
-    gint old_popups_active = popups_active;
     gchar buf[SMALL];
     GtkWidget *wind = NULL;
     
@@ -524,8 +686,8 @@ window_create(gint window_type)
     switch(window_type)
     {
 	default:
-	    g_warning("window_create: unknown window type %d\n", window_type);
-	    main_exit_program(EXIT_INT_NOT_FOUND, NULL);
+	    main_exit_program(EXIT_INT_NOT_FOUND, 
+			      "window_create: unknown window type %d\n", window_type);
 	    break;
 	case WINDOW_MAIN:
 	    if(window.main == NULL)
@@ -533,6 +695,9 @@ window_create(gint window_type)
 		window.main = create_main_window();
 		wind = window.main;
 		window_main_load_geometry();
+		window.paned_pos = 
+		    gtk_paned_get_position(
+			GTK_PANED(lookup_widget(window.main, "hpaned2")));
 		game_gui_print_message(_("Welcome to Bygfoot %s"), VERS);
 		sprintf(buf, "Bygfoot Football Manager %s", VERS);
 	    }
@@ -545,21 +710,16 @@ window_create(gint window_type)
 	    if(window.startup != NULL)
 		g_warning("window_create: called on already existing window\n");
 	    else
-	    {
-		popups_active++;
 		window.startup = create_window_startup();
-	    }
 	    wind = window.startup;
 	    break;
 	case WINDOW_LIVE:
 	    if(window.live != NULL)
 		g_warning("window_create: called on already existing window\n");
 	    else
-	    {
-		popups_active++;
 		window.live = create_window_live();
-	    }
-	    strcpy(buf, league_cup_get_name_string(((LiveGame*)statp)->fix->clid));
+	    if(((LiveGame*)statp)->fix != NULL)
+		strcpy(buf, league_cup_get_name_string(((LiveGame*)statp)->fix->clid));
 	    wind = window.live;
 	    window_live_set_up();
 	    break;
@@ -583,10 +743,8 @@ window_create(gint window_type)
 	    if(window.digits != NULL)
 		g_warning("window_create: called on already existing window\n");
 	    else
-	    {
-		popups_active++;
 		window.digits = create_window_digits();
-	    }
+
 	    wind = window.digits;
 	    strcpy(buf, _("Numbers..."));
 	    break;
@@ -594,10 +752,7 @@ window_create(gint window_type)
 	    if(window.stadium != NULL)
 		g_warning("window_create: called on already existing window\n");
 	    else
-	    {
-		popups_active++;
 		window.stadium = create_window_stadium();
-	    }
 	    wind = window.stadium;
 	    strcpy(buf, _("Your stadium"));
 	    break;
@@ -605,10 +760,7 @@ window_create(gint window_type)
 	    if(window.job_offer != NULL)
 		g_warning("window_create: called on already existing window\n");
 	    else
-	    {
-		popups_active++;
 		window.job_offer = create_window_job_offer();
-	    }
 	    wind = window.job_offer;
 	    strcpy(buf, _("Job offer"));
 	    break;
@@ -616,10 +768,7 @@ window_create(gint window_type)
 	    if(window.yesno != NULL)
 		g_warning("window_create: called on already existing window\n");
 	    else
-	    {
-		popups_active++;
 		window.yesno = create_window_yesno();
-	    }
 	    wind = window.yesno;
 	    strcpy(buf, "???");
 	    break;
@@ -627,10 +776,7 @@ window_create(gint window_type)
 	    if(window.options != NULL)
 		g_warning("window_create: called on already existing window\n");
 	    else
-	    {
-		popups_active++;
 		window.options = create_window_options();
-	    }
 	    wind = window.options;
 	    strcpy(buf, _("Options"));
 	    break;
@@ -700,27 +846,35 @@ window_create(gint window_type)
 	    if(window.mmatches != NULL)
 		g_warning("window_create: called on already existing window\n");
 	    else
-	    {
 		window.mmatches = create_window_mmatches();
-		popups_active++;
-	    }
 	    wind = window.mmatches;
 	    strcpy(buf, _("Memorable matches"));
 	    break;
+	case WINDOW_BETS:
+	    if(window.bets != NULL)
+		g_warning("window_create: called on already existing window\n");
+	    else
+		window.bets = create_window_bets();
+	    wind = window.bets;
+	    strcpy(buf, _("Betting"));
+	    break;
+	case WINDOW_SPLASH:
+	    if(window.splash != NULL)
+		g_warning("window_create: called on already existing window\n");
+	    else
+		window.splash = create_window_splash();
+	    wind = window.splash;
+	    break;
     }
 
     if(window_type != WINDOW_FILE_CHOOSER)
 	gtk_window_set_title(GTK_WINDOW(wind), buf);
 
-    if(window_type != WINDOW_PROGRESS)
+    if(window_type != WINDOW_PROGRESS && window_type != WINDOW_SPLASH)
 	g_timeout_add(20, (GSourceFunc)window_show, (gpointer)wind);
     else
 	gtk_widget_show(wind);
 
-    if(popups_active != old_popups_active &&
-       window.main != NULL)
-	gtk_widget_set_sensitive(window.main, FALSE);
-
     return wind;
 }
 
@@ -730,17 +884,17 @@ window_create(gint window_type)
     @param count_popups Whether this window adds to the popup
     counter that determines when the main window gets (in)sensitive. */
 void
-window_destroy(GtkWidget **wind, gboolean count_popups)
+window_destroy(GtkWidget **wind)
 {
     if(*wind == NULL)
 	return;
 
-    if(*wind != window.main && count_popups)
+    if(*wind == window.splash)
     {
-	popups_active--;
+	counters[COUNT_HINT_NUMBER] = 
+	    (counters[COUNT_HINT_NUMBER] + 1) % hints.list->len;
 
-	if(popups_active == 0 && window.main != NULL)
-	    gtk_widget_set_sensitive(window.main, TRUE);
+	window_save_hint_number();
     }
 
     gtk_widget_destroy(*wind);
