@@ -1,3 +1,28 @@
+/*
+   xml_loadsave_live_game.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "cup.h"
 #include "file.h"
 #include "fixture.h"
@@ -14,6 +39,7 @@ enum
     TAG_LIVE_GAME = TAG_START_LIVE_GAME,
     TAG_LIVE_GAME_FIX_ID,
     TAG_LIVE_GAME_TEAM_NAME,
+    TAG_LIVE_GAME_ATTENDANCE,
     TAG_LIVE_GAME_UNIT,
     TAG_LIVE_GAME_UNIT_POSSESSION,
     TAG_LIVE_GAME_UNIT_AREA,
@@ -88,6 +114,7 @@ xml_loadsave_live_game_end_element    (GMarkupParseContext *context,
     
     if(tag == TAG_LIVE_GAME_FIX_ID ||
        tag == TAG_LIVE_GAME_TEAM_NAME ||
+       tag == TAG_LIVE_GAME_ATTENDANCE ||
        tag == TAG_LIVE_GAME_UNIT ||
        tag == TAG_LIVE_GAME_STAT)
     {
@@ -163,10 +190,12 @@ xml_loadsave_live_game_text         (GMarkupParseContext *context,
     if(state == TAG_LIVE_GAME_FIX_ID)
     {
 	lgame->fix_id = int_value;
-	lgame->fix = fixture_from_id(int_value);
+	lgame->fix = fixture_from_id(int_value, FALSE);
     }
     else if(state == TAG_LIVE_GAME_TEAM_NAME)
 	misc_string_assign(&lgame->team_names[team_name_idx], buf);
+    else if(state == TAG_LIVE_GAME_ATTENDANCE)
+	lgame->attendance = int_value;
     else if(state == TAG_LIVE_GAME_UNIT_POSSESSION)
 	new_unit.possession = int_value;
     else if(state == TAG_LIVE_GAME_UNIT_AREA)
@@ -206,7 +235,7 @@ xml_loadsave_live_game_read(const gchar *filename, LiveGame *live_game)
 			    xml_loadsave_live_game_text, NULL, NULL};
     GMarkupParseContext *context;
     gchar *file_contents;
-    guint length;
+    gsize length;
     GError *error = NULL;
 
     context = 
@@ -251,15 +280,16 @@ xml_loadsave_live_game_write(const gchar *filename, const LiveGame *live_game)
 
 	if(live_game->fix->id > 10000000)
 	    g_warning(
-		"xml_loadsave_live_game_write: suspicious fix id: %d. competition: %s",
-		live_game->fix->id, 
-		league_cup_get_name_string(live_game->fix->id));
-
-	for(i=0;i<2;i++)
-	    xml_write_string(fil, live_game->team_names[i], 
-			     TAG_LIVE_GAME_TEAM_NAME, I0);
+		"xml_loadsave_live_game_write: suspicious fix id: %d.",
+		live_game->fix->id);
     }
 
+    for(i=0;i<2;i++)
+	xml_write_string(fil, live_game->team_names[i], 
+			 TAG_LIVE_GAME_TEAM_NAME, I0);
+    
+    xml_write_int(fil, live_game->attendance, TAG_LIVE_GAME_ATTENDANCE, I0);
+
     for(i=0;i<live_game->units->len;i++)
 	xml_loadsave_live_game_write_unit(fil,
 					  &g_array_index(live_game->units,
