@@ -1,3 +1,28 @@
+/*
+   xml_loadsave_teams.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "file.h"
 #include "misc.h"
 #include "player.h"
@@ -15,6 +40,7 @@ enum
     TAG_TEAM_STYLE,
     TAG_TEAM_BOOST,
     TAG_TEAM_CLID,
+    TAG_TEAM_STRATEGY_SID,
     TAG_TEAM_STADIUM,
     TAG_TEAM_STADIUM_NAME,
     TAG_TEAM_STADIUM_CAPACITY,
@@ -90,6 +116,7 @@ xml_loadsave_teams_end_element    (GMarkupParseContext *context,
 	    tag == TAG_TEAM_NAMES_FILE ||
 	    tag == TAG_TEAM_ID ||
 	    tag == TAG_TEAM_CLID ||
+	    tag == TAG_TEAM_STRATEGY_SID ||
 	    tag == TAG_TEAM_STRUCTURE ||
 	    tag == TAG_TEAM_STYLE ||
 	    tag == TAG_TEAM_BOOST ||
@@ -138,6 +165,8 @@ xml_loadsave_teams_text         (GMarkupParseContext *context,
 	misc_string_assign(&new_team.names_file, buf);
     else if(state == TAG_TEAM_CLID)
 	new_team.clid = int_value;
+    else if(state == TAG_TEAM_STRATEGY_SID)
+	misc_string_assign(&new_team.strategy_sid, buf);
     else if(state == TAG_TEAM_ID)
 	new_team.id = int_value;
     else if(state == TAG_TEAM_STRUCTURE)
@@ -171,7 +200,7 @@ xml_loadsave_teams_read(const gchar *filename, GArray *teams)
 			    xml_loadsave_teams_text, NULL, NULL};
     GMarkupParseContext *context;
     gchar *file_contents;
-    guint length;
+    gsize length;
     GError *error = NULL;
 
     context = 
@@ -228,13 +257,14 @@ xml_loadsave_teams_write_team(FILE *fil, const Team* team)
     xml_write_string(fil, team->name, TAG_NAME, I1);
     xml_write_string(fil, team->symbol, TAG_SYMBOL, I1);
     xml_write_string(fil, team->names_file, TAG_TEAM_NAMES_FILE, I1);
-    
+    xml_write_string(fil, team->strategy_sid, TAG_TEAM_STRATEGY_SID, I1);
+       
     xml_write_int(fil, team->clid, TAG_TEAM_CLID, I1);
     xml_write_int(fil, team->id, TAG_TEAM_ID, I1);
     xml_write_int(fil, team->structure, TAG_TEAM_STRUCTURE, I1);
     xml_write_int(fil, team->style, TAG_TEAM_STYLE, I1);
     xml_write_int(fil, team->boost, TAG_TEAM_BOOST, I1);
-    
+
     fprintf(fil, "%s<_%d>\n", I1, TAG_TEAM_STADIUM);
 
     if(team->stadium.name != NULL)
