@@ -1,4 +1,31 @@
+/*
+   xml_loadsave_users.c
+
+   Bygfoot Football Manager -- a small and simple GTK2-based
+   football management game.
+
+   http://bygfoot.sourceforge.net
+
+   Copyright (C) 2005  Gyözö Both (gyboth@bygfoot.com)
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License
+   as published by the Free Software Foundation; either version 2
+   of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
+#include "bet_struct.h"
 #include "file.h"
+#include "fixture.h"
 #include "misc.h"
 #include "team.h"
 #include "user.h"
@@ -25,10 +52,8 @@ enum
     TAG_USER_HISTORY_SEASON,
     TAG_USER_HISTORY_WEEK,
     TAG_USER_HISTORY_TYPE,
-    TAG_USER_HISTORY_TEAM_ID,
-    TAG_USER_HISTORY_VALUE1,
-    TAG_USER_HISTORY_VALUE2,
-    TAG_USER_HISTORY_VALUE_STRING,
+    TAG_USER_HISTORY_TEAM_NAME,
+    TAG_USER_HISTORY_STRING,
     TAG_USER_EVENT,
     TAG_USER_EVENT_TYPE,
     TAG_USER_EVENT_VALUE1,
@@ -42,13 +67,20 @@ enum
     TAG_USER_YA_AV_COACH,
     TAG_USER_YA_AV_PERCENTAGE,
     TAG_USER_YA_COUNTER,
+    TAG_USER_BET0,
+    TAG_USER_BET1,
+    TAG_USER_BET_WAGER,
+    TAG_USER_BET_OUTCOME,
+    TAG_USER_BET_FIX_ID,
     TAG_END
 };
 
-gint state, idx_mon_in, idx_mon_out, idx;
+gint state, idx_mon_in, idx_mon_out, idx,
+    idx_bet, idx_cnt;
 User new_user;
 UserHistory new_history;
 Event new_event;
+BetUser new_bet;
 
 void
 xml_loadsave_users_start_element (GMarkupParseContext *context,
@@ -79,28 +111,35 @@ xml_loadsave_users_start_element (GMarkupParseContext *context,
     if(tag == TAG_USER)
     {
 	new_user = user_new();
-	idx = idx_mon_out = idx_mon_in = 0;
+	idx = idx_mon_out = idx_mon_in = idx_cnt = 0;
     }
-
-    if(tag >= TAG_START_PLAYERS && tag <= TAG_END_PLAYERS)
+    else if(tag >= TAG_START_PLAYERS && tag <= TAG_END_PLAYERS)
     {
 	state = TAG_START_PLAYERS;
 	valid_tag = TRUE;
 
 	if(tag == TAG_START_PLAYERS)
-	    new_user.youth_academy.players = g_array_new(FALSE, FALSE, sizeof(Player));
+	    new_user.youth_academy.players = 
+		g_array_new(FALSE, FALSE, sizeof(Player));
 
 	xml_loadsave_players_start_element(tag, new_user.tm);
     }
-
-    if(state == TAG_USER_MONEY_OUTS ||
-       state == TAG_USER_MONEY_INS)
+    else if(tag == TAG_USER_HISTORY)
+    {
 	idx = 0;
-
-    if(tag == TAG_USER_HISTORY)
-	new_history.value_string = NULL;
+	new_history.team_name =
+	    new_history.string[0] =
+	    new_history.string[1] =
+	    new_history.string[2] = NULL;
+    }
     else if(tag == TAG_USER_EVENT)
 	new_event.value_string = NULL;
+    else if(tag == TAG_USER_MONEY_OUTS ||
+	    tag == TAG_USER_MONEY_INS)
+	idx = 0;
+    else if(tag == TAG_USER_BET0 ||
+       tag == TAG_USER_BET1)
+	idx_bet = (tag == TAG_USER_BET1);
 
     if(!valid_tag)
 	g_warning("xml_loadsave_users_start_element: unknown tag: %s; I'm in state %d\n",
@@ -114,7 +153,7 @@ xml_loadsave_users_end_element    (GMarkupParseContext *context,
 				   GError             **error)
 {
     gint tag = xml_get_tag_from_name(element_name);
-    
+
     if(tag == TAG_USER)
     {
 	state = TAG_USERS;
@@ -138,11 +177,13 @@ xml_loadsave_users_end_element    (GMarkupParseContext *context,
 	    tag == TAG_USER_YA_PERCENTAGE ||
 	    tag == TAG_USER_YA_AV_COACH ||
 	    tag == TAG_USER_YA_AV_PERCENTAGE ||
-	    tag == TAG_USER_YA_COUNTER)
+	    tag == TAG_USER_YA_COUNTER ||
+	    tag == TAG_USER_BET0 ||
+	    tag == TAG_USER_BET1)
     {
 	state = TAG_USER;
 	if(tag == TAG_USER_COUNTER)
-	    idx++;
+	    idx_cnt++;
 	else if(tag == TAG_USER_MONEY_OUTS)
 	    idx_mon_out++;
 	else if(tag == TAG_USER_MONEY_INS)
@@ -151,6 +192,9 @@ xml_loadsave_users_end_element    (GMarkupParseContext *context,
 	    g_array_append_val(new_user.history, new_history);
 	else if(tag == TAG_USER_EVENT)
 	    g_array_append_val(new_user.events, new_event);
+	else if(tag == TAG_USER_BET0 ||
+		tag == TAG_USER_BET1)
+	    g_array_append_val(new_user.bets[idx_bet], new_bet);
     }
     else if(tag == TAG_USER_MONEY_OUT)
     {
@@ -165,16 +209,23 @@ xml_loadsave_users_end_element    (GMarkupParseContext *context,
     else if(tag == TAG_USER_HISTORY_SEASON ||
 	    tag == TAG_USER_HISTORY_WEEK ||
 	    tag == TAG_USER_HISTORY_TYPE ||
-	    tag == TAG_USER_HISTORY_TEAM_ID ||
-	    tag == TAG_USER_HISTORY_VALUE1 ||
-	    tag == TAG_USER_HISTORY_VALUE2 ||
-	    tag == TAG_USER_HISTORY_VALUE_STRING)
+	    tag == TAG_USER_HISTORY_TEAM_NAME ||
+	    tag == TAG_USER_HISTORY_STRING)
+    {
 	state = TAG_USER_HISTORY;
+	
+	if(tag == TAG_USER_HISTORY_STRING)
+	    idx++;
+    }
     else if(tag == TAG_USER_EVENT_TYPE ||
 	    tag == TAG_USER_EVENT_VALUE1 ||
 	    tag == TAG_USER_EVENT_VALUE2 ||
 	    tag == TAG_USER_EVENT_VALUE_STRING)
 	state = TAG_USER_EVENT;
+    else if(tag == TAG_USER_BET_FIX_ID ||
+	    tag == TAG_USER_BET_WAGER ||
+	    tag == TAG_USER_BET_OUTCOME)
+	state = (idx_bet == 0) ? TAG_USER_BET0 : TAG_USER_BET1;
     else if(tag >= TAG_START_PLAYERS && tag <= TAG_END_PLAYERS)
     {
 	xml_loadsave_players_end_element(tag, new_user.youth_academy.players);
@@ -229,7 +280,7 @@ xml_loadsave_users_text         (GMarkupParseContext *context,
     else if(state == TAG_USER_SPONSOR_BENEFIT)
 	new_user.sponsor.benefit = int_value;
     else if(state == TAG_USER_COUNTER)
-	new_user.counters[idx] = int_value;
+	new_user.counters[idx_cnt] = int_value;
     else if(state == TAG_USER_MONEY_IN)
 	new_user.money_in[idx_mon_in][idx] = int_value;
     else if(state == TAG_USER_MONEY_OUT)
@@ -240,14 +291,10 @@ xml_loadsave_users_text         (GMarkupParseContext *context,
 	new_history.week = int_value;
     else if(state == TAG_USER_HISTORY_TYPE)
 	new_history.type = int_value;
-    else if(state == TAG_USER_HISTORY_TEAM_ID)
-	new_history.team_id = int_value;
-    else if(state == TAG_USER_HISTORY_VALUE1)
-	new_history.value1 = int_value;
-    else if(state == TAG_USER_HISTORY_VALUE2)
-	new_history.value2 = int_value;
-    else if(state == TAG_USER_HISTORY_VALUE_STRING)
-	misc_string_assign(&new_history.value_string, buf);
+    else if(state == TAG_USER_HISTORY_TEAM_NAME)
+	new_history.team_name = g_strdup(buf);
+    else if(state == TAG_USER_HISTORY_STRING)	
+	new_history.string[idx] = (strlen(buf) == 0) ? NULL : g_strdup(buf);
     else if(state == TAG_USER_EVENT_TYPE)
 	new_event.type = int_value;
     else if(state == TAG_USER_EVENT_VALUE1)
@@ -255,7 +302,7 @@ xml_loadsave_users_text         (GMarkupParseContext *context,
     else if(state == TAG_USER_EVENT_VALUE2)
 	new_event.value2 = int_value;
     else if(state == TAG_USER_EVENT_VALUE_STRING)
-	misc_string_assign(&new_event.value_string, buf);
+	new_event.value_string = g_strdup(buf);
     else if(state == TAG_USER_YA_COACH)
 	new_user.youth_academy.coach = int_value;
     else if(state == TAG_USER_YA_PERCENTAGE)
@@ -266,6 +313,12 @@ xml_loadsave_users_text         (GMarkupParseContext *context,
 	new_user.youth_academy.av_percentage = float_value;
     else if(state == TAG_USER_YA_COUNTER)
 	new_user.youth_academy.counter_youth = float_value;
+    else if(state == TAG_USER_BET_WAGER)
+	new_bet.wager = int_value;
+    else if(state == TAG_USER_BET_OUTCOME)
+	new_bet.outcome = int_value;
+    else if(state == TAG_USER_BET_FIX_ID)
+	new_bet.fix_id = int_value;
     else if(state >= TAG_START_PLAYERS && state <= TAG_END_PLAYERS)
 	xml_loadsave_players_text(buf);
 }
@@ -278,11 +331,11 @@ xml_loadsave_users_read(const gchar *dirname, const gchar *basename)
 			    xml_loadsave_users_text, NULL, NULL};
     GMarkupParseContext *context;
     gchar *file_contents;
-    guint length;
+    gsize length;
     GError *error = NULL;
     gchar file[SMALL];
 
-    sprintf(file, "%s/%s___users.xml", dirname, basename);
+    sprintf(file, "%s%s%s___users.xml", dirname, G_DIR_SEPARATOR_S, basename);
 
     context = 
 	g_markup_parse_context_new(&parser, 0, NULL, NULL);
@@ -344,6 +397,10 @@ xml_loadsave_users_write(const gchar *prefix)
 	xml_write_int(fil, usr(i).sponsor.contract, TAG_USER_SPONSOR_CONTRACT, I1);
 	xml_write_int(fil, usr(i).sponsor.benefit, TAG_USER_SPONSOR_BENEFIT, I1);
 
+	xml_user_write_history(fil, usr(i).history);
+	xml_user_write_events(fil, usr(i).events);
+	xml_user_write_bets(fil, usr(i).bets);
+
 	for(j=0;j<COUNT_USER_END;j++)
 	    xml_write_int(fil, usr(i).counters[j], TAG_USER_COUNTER, I1);
 
@@ -359,52 +416,15 @@ xml_loadsave_users_write(const gchar *prefix)
 	{
 	    fprintf(fil, "%s<_%d>\n", I1, TAG_USER_MONEY_OUTS);
 	    for(k=0;k<MON_OUT_END;k++)
-		xml_write_int(fil, usr(i).money_out[j][k], TAG_USER_MONEY_OUT, I2);	    
+		xml_write_int(fil, usr(i).money_out[j][k], TAG_USER_MONEY_OUT, I2);
 	    fprintf(fil, "%s</_%d>\n", I1, TAG_USER_MONEY_OUTS);
 	}
 
-	for(j=0;j<usr(i).history->len;j++)
-	{
-	    fprintf(fil, "%s<_%d>\n", I1, TAG_USER_HISTORY);
-
-	    xml_write_int(fil, g_array_index(usr(i).history, UserHistory, j).season,
-			  TAG_USER_HISTORY_SEASON, I2);
-	    xml_write_int(fil, g_array_index(usr(i).history, UserHistory, j).week,
-			  TAG_USER_HISTORY_WEEK, I2);
-	    xml_write_int(fil, g_array_index(usr(i).history, UserHistory, j).type,
-			  TAG_USER_HISTORY_TYPE, I2);
-	    xml_write_int(fil, g_array_index(usr(i).history, UserHistory, j).team_id,
-			  TAG_USER_HISTORY_TEAM_ID, I2);
-	    xml_write_int(fil, g_array_index(usr(i).history, UserHistory, j).value1,
-			  TAG_USER_HISTORY_VALUE1, I2);
-	    xml_write_int(fil, g_array_index(usr(i).history, UserHistory, j).value2,
-			  TAG_USER_HISTORY_VALUE2, I2);
-	    xml_write_string(fil, g_array_index(usr(i).history, UserHistory, j).value_string,
-			     TAG_USER_HISTORY_VALUE_STRING, I2);
-
-	    fprintf(fil, "%s</_%d>\n", I1, TAG_USER_HISTORY);
-	}
-
-	for(j=0;j<usr(i).events->len;j++)
-	{
-	    fprintf(fil, "%s<_%d>\n", I1, TAG_USER_EVENT);
-
-	    xml_write_int(fil, g_array_index(usr(i).events, Event, j).type,
-			  TAG_USER_EVENT_TYPE, I2);
-	    xml_write_int(fil, g_array_index(usr(i).events, Event, j).value1,
-			  TAG_USER_EVENT_VALUE1, I2);
-	    xml_write_int(fil, g_array_index(usr(i).events, Event, j).value2,
-			  TAG_USER_EVENT_VALUE2, I2);
-	    xml_write_string(fil, g_array_index(usr(i).events, Event, j).value_string,
-			       TAG_USER_EVENT_VALUE_STRING, I2);
-
-	    fprintf(fil, "%s</_%d>\n", I1, TAG_USER_EVENT);
-	}
-
 	xml_write_int(fil, usr(i).youth_academy.coach, TAG_USER_YA_COACH, I1);
 	xml_write_int(fil, usr(i).youth_academy.percentage, TAG_USER_YA_PERCENTAGE, I1);
 	xml_write_float(fil, usr(i).youth_academy.av_coach, TAG_USER_YA_AV_COACH, I1);
-	xml_write_float(fil, usr(i).youth_academy.av_percentage, TAG_USER_YA_AV_PERCENTAGE, I1);
+	xml_write_float(fil, usr(i).youth_academy.av_percentage, 
+			TAG_USER_YA_AV_PERCENTAGE, I1);
 	xml_write_float(fil, usr(i).youth_academy.counter_youth, TAG_USER_YA_COUNTER, I1);
 
 	xml_loadsave_players_write(fil, usr(i).youth_academy.players);
@@ -416,3 +436,77 @@ xml_loadsave_users_write(const gchar *prefix)
 
     fclose(fil);
 }
+
+/** Write the history of a user into the file. */
+void
+xml_user_write_history(FILE *fil, const GArray *history)
+{
+    gint i, j;
+
+    for(i=0;i<history->len;i++)
+    {
+	fprintf(fil, "%s<_%d>\n", I1, TAG_USER_HISTORY);
+
+	xml_write_int(fil, g_array_index(history, UserHistory, i).season,
+		      TAG_USER_HISTORY_SEASON, I2);
+	xml_write_int(fil, g_array_index(history, UserHistory, i).week,
+		      TAG_USER_HISTORY_WEEK, I2);
+	xml_write_int(fil, g_array_index(history, UserHistory, i).type,
+		      TAG_USER_HISTORY_TYPE, I2);
+	xml_write_string(fil, g_array_index(history, UserHistory, i).team_name,
+			 TAG_USER_HISTORY_TEAM_NAME, I2);
+	for(j=0;j<3;j++)
+	    if(g_array_index(history, UserHistory, i).string[j] != NULL)
+		xml_write_string(fil, g_array_index(history, UserHistory, i).string[j],
+				 TAG_USER_HISTORY_STRING, I2);
+	    else
+		xml_write_string(fil, "", TAG_USER_HISTORY_STRING, I2);
+
+	fprintf(fil, "%s</_%d>\n", I1, TAG_USER_HISTORY);
+    }
+}
+
+/** Write the events of a user into the file. */
+void
+xml_user_write_events(FILE *fil, const GArray *events)
+{
+    gint i;
+
+    for(i=0;i<events->len;i++)
+    {
+	fprintf(fil, "%s<_%d>\n", I1, TAG_USER_EVENT);
+
+	xml_write_int(fil, g_array_index(events, Event, i).type,
+		      TAG_USER_EVENT_TYPE, I2);
+	xml_write_int(fil, g_array_index(events, Event, i).value1,
+		      TAG_USER_EVENT_VALUE1, I2);
+	xml_write_int(fil, g_array_index(events, Event, i).value2,
+		      TAG_USER_EVENT_VALUE2, I2);
+	xml_write_string(fil, g_array_index(events, Event, i).value_string,
+			 TAG_USER_EVENT_VALUE_STRING, I2);
+	
+	fprintf(fil, "%s</_%d>\n", I1, TAG_USER_EVENT);
+    }
+}
+
+/** Write the bets of a user into the file. */
+void
+xml_user_write_bets(FILE *fil, GArray **bets)
+{
+    gint i, j;
+
+    for(i=0;i<2;i++)
+	for(j=0;j<bets[i]->len;j++)
+	{
+	    fprintf(fil, "%s<_%d>\n", I1, 
+		    (i == 0) ? TAG_USER_BET0 : TAG_USER_BET1);
+	    xml_write_int(fil, g_array_index(bets[i], BetUser, j).wager,
+			  TAG_USER_BET_WAGER, I2);
+	    xml_write_int(fil, g_array_index(bets[i], BetUser, j).outcome,
+			  TAG_USER_BET_OUTCOME, I2);
+	    xml_write_int(fil, g_array_index(bets[i], BetUser, j).fix_id,
+			  TAG_USER_BET_FIX_ID, I2);
+	    fprintf(fil, "%s</_%d>\n", I1, 
+		    (i == 0) ? TAG_USER_BET0 : TAG_USER_BET1);
+	}
+}
